package com.alibaba.android.bindingx.core.internal;

import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Handler;
import android.os.HandlerThread;
import com.alibaba.android.bindingx.core.LogProxy;
import com.umeng.analytics.pro.bg;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

/* access modifiers changed from: package-private */
public class OrientationDetector implements SensorEventListener {
    private static final Set<Integer> DEVICE_ORIENTATION_SENSORS_A = Utils.newHashSet(15);
    private static final Set<Integer> DEVICE_ORIENTATION_SENSORS_B = Utils.newHashSet(11);
    private static final Set<Integer> DEVICE_ORIENTATION_SENSORS_C = Utils.newHashSet(1, 2);
    private static OrientationDetector sSingleton;
    private static final Object sSingletonLock = new Object();
    private final Set<Integer> mActiveSensors = new HashSet();
    private final Context mAppContext;
    private boolean mDeviceOrientationIsActive;
    private boolean mDeviceOrientationIsActiveWithBackupSensors;
    private Set<Integer> mDeviceOrientationSensors;
    private float[] mDeviceRotationMatrix;
    private Handler mHandler;
    private ArrayList<OnOrientationChangedListener> mListeners = new ArrayList<>();
    private float[] mMagneticFieldVector;
    private boolean mOrientationNotAvailable;
    private final List<Set<Integer>> mOrientationSensorSets;
    private double[] mRotationAngles;
    SensorManagerProxy mSensorManagerProxy;
    private HandlerThread mThread;
    private float[] mTruncatedRotationVector;

    /* access modifiers changed from: package-private */
    public interface OnOrientationChangedListener {
        void onOrientationChanged(double d, double d2, double d3);
    }

    private OrientationDetector(Context context) {
        this.mAppContext = context.getApplicationContext();
        this.mOrientationSensorSets = Utils.newArrayList(DEVICE_ORIENTATION_SENSORS_A, DEVICE_ORIENTATION_SENSORS_B, DEVICE_ORIENTATION_SENSORS_C);
    }

    static OrientationDetector getInstance(Context appContext) {
        OrientationDetector orientationDetector;
        synchronized (sSingletonLock) {
            if (sSingleton == null) {
                sSingleton = new OrientationDetector(appContext);
            }
            orientationDetector = sSingleton;
        }
        return orientationDetector;
    }

    /* access modifiers changed from: package-private */
    public void addOrientationChangedListener(OnOrientationChangedListener listener) {
        ArrayList<OnOrientationChangedListener> arrayList = this.mListeners;
        if (arrayList != null && !arrayList.contains(listener)) {
            this.mListeners.add(listener);
        }
    }

    /* access modifiers changed from: package-private */
    public boolean removeOrientationChangedListener(OnOrientationChangedListener listener) {
        ArrayList<OnOrientationChangedListener> arrayList = this.mListeners;
        if (arrayList == null) {
            return false;
        }
        if (listener != null) {
            return arrayList.remove(listener);
        }
        arrayList.clear();
        return true;
    }

    private boolean registerOrientationSensorsWithFallback(int rateInMicroseconds) {
        if (this.mOrientationNotAvailable) {
            return false;
        }
        if (this.mDeviceOrientationSensors != null) {
            String type = getOrientationSensorTypeUsed();
            LogProxy.d("[OrientationDetector] register sensor:" + type);
            return registerSensors(this.mDeviceOrientationSensors, rateInMicroseconds, true);
        }
        ensureRotationStructuresAllocated();
        for (Set<Integer> sensors : this.mOrientationSensorSets) {
            this.mDeviceOrientationSensors = sensors;
            if (registerSensors(sensors, rateInMicroseconds, true)) {
                String type2 = getOrientationSensorTypeUsed();
                LogProxy.d("[OrientationDetector] register sensor:" + type2);
                return true;
            }
        }
        this.mOrientationNotAvailable = true;
        this.mDeviceOrientationSensors = null;
        this.mDeviceRotationMatrix = null;
        this.mRotationAngles = null;
        return false;
    }

    private String getOrientationSensorTypeUsed() {
        if (this.mOrientationNotAvailable) {
            return "NOT_AVAILABLE";
        }
        Set<Integer> set = this.mDeviceOrientationSensors;
        if (set == DEVICE_ORIENTATION_SENSORS_A) {
            return "GAME_ROTATION_VECTOR";
        }
        if (set == DEVICE_ORIENTATION_SENSORS_B) {
            return "ROTATION_VECTOR";
        }
        if (set == DEVICE_ORIENTATION_SENSORS_C) {
            return "ACCELEROMETER_MAGNETIC";
        }
        return "NOT_AVAILABLE";
    }

    public boolean start(int rateInMicroseconds) {
        LogProxy.d("[OrientationDetector] sensor started");
        boolean success = registerOrientationSensorsWithFallback(rateInMicroseconds);
        if (success) {
            setEventTypeActive(true);
        }
        return success;
    }

    /* access modifiers changed from: package-private */
    public void stop() {
        LogProxy.d("[OrientationDetector] sensor stopped");
        unregisterSensors(new HashSet<>(this.mActiveSensors));
        setEventTypeActive(false);
    }

    public void onAccuracyChanged(Sensor sensor, int accuracy) {
    }

    public void onSensorChanged(SensorEvent event) {
        int type = event.sensor.getType();
        float[] values = event.values;
        if (type != 1) {
            if (type != 2) {
                if (type != 11) {
                    if (type != 15) {
                        LogProxy.e("unexpected sensor type:" + type);
                    } else if (this.mDeviceOrientationIsActive) {
                        convertRotationVectorToAngles(values, this.mRotationAngles);
                        double[] dArr = this.mRotationAngles;
                        gotOrientation(dArr[0], dArr[1], dArr[2]);
                    }
                } else if (this.mDeviceOrientationIsActive && this.mDeviceOrientationSensors == DEVICE_ORIENTATION_SENSORS_B) {
                    convertRotationVectorToAngles(values, this.mRotationAngles);
                    double[] dArr2 = this.mRotationAngles;
                    gotOrientation(dArr2[0], dArr2[1], dArr2[2]);
                }
            } else if (this.mDeviceOrientationIsActiveWithBackupSensors) {
                if (this.mMagneticFieldVector == null) {
                    this.mMagneticFieldVector = new float[3];
                }
                float[] fArr = this.mMagneticFieldVector;
                System.arraycopy(values, 0, fArr, 0, fArr.length);
            }
        } else if (this.mDeviceOrientationIsActiveWithBackupSensors) {
            getOrientationFromGeomagneticVectors(values, this.mMagneticFieldVector);
        }
    }

    private static double[] computeDeviceOrientationFromRotationMatrix(float[] matrixR, double[] values) {
        if (matrixR.length != 9) {
            return values;
        }
        if (matrixR[8] > 0.0f) {
            values[0] = Math.atan2((double) (-matrixR[1]), (double) matrixR[4]);
            values[1] = Math.asin((double) matrixR[7]);
            values[2] = Math.atan2((double) (-matrixR[6]), (double) matrixR[8]);
        } else if (matrixR[8] < 0.0f) {
            values[0] = Math.atan2((double) matrixR[1], (double) (-matrixR[4]));
            values[1] = -Math.asin((double) matrixR[7]);
            values[1] = values[1] + (values[1] >= 0.0d ? -3.141592653589793d : 3.141592653589793d);
            values[2] = Math.atan2((double) matrixR[6], (double) (-matrixR[8]));
        } else {
            double d = -1.5707963267948966d;
            if (matrixR[6] > 0.0f) {
                values[0] = Math.atan2((double) (-matrixR[1]), (double) matrixR[4]);
                values[1] = Math.asin((double) matrixR[7]);
                values[2] = -1.5707963267948966d;
            } else if (matrixR[6] < 0.0f) {
                values[0] = Math.atan2((double) matrixR[1], (double) (-matrixR[4]));
                values[1] = -Math.asin((double) matrixR[7]);
                values[1] = values[1] + (values[1] >= 0.0d ? -3.141592653589793d : 3.141592653589793d);
                values[2] = -1.5707963267948966d;
            } else {
                values[0] = Math.atan2((double) matrixR[3], (double) matrixR[0]);
                if (matrixR[7] > 0.0f) {
                    d = 1.5707963267948966d;
                }
                values[1] = d;
                values[2] = 0.0d;
            }
        }
        if (values[0] < 0.0d) {
            values[0] = values[0] + 6.283185307179586d;
        }
        return values;
    }

    private void convertRotationVectorToAngles(float[] rotationVector, double[] angles) {
        if (rotationVector.length > 4) {
            System.arraycopy(rotationVector, 0, this.mTruncatedRotationVector, 0, 4);
            SensorManager.getRotationMatrixFromVector(this.mDeviceRotationMatrix, this.mTruncatedRotationVector);
        } else {
            SensorManager.getRotationMatrixFromVector(this.mDeviceRotationMatrix, rotationVector);
        }
        computeDeviceOrientationFromRotationMatrix(this.mDeviceRotationMatrix, angles);
        for (int i = 0; i < 3; i++) {
            angles[i] = Math.toDegrees(angles[i]);
        }
    }

    private void getOrientationFromGeomagneticVectors(float[] acceleration, float[] magnetic) {
        if (acceleration != null && magnetic != null && SensorManager.getRotationMatrix(this.mDeviceRotationMatrix, null, acceleration, magnetic)) {
            computeDeviceOrientationFromRotationMatrix(this.mDeviceRotationMatrix, this.mRotationAngles);
            gotOrientation(Math.toDegrees(this.mRotationAngles[0]), Math.toDegrees(this.mRotationAngles[1]), Math.toDegrees(this.mRotationAngles[2]));
        }
    }

    private SensorManagerProxy getSensorManagerProxy() {
        SensorManagerProxy sensorManagerProxy = this.mSensorManagerProxy;
        if (sensorManagerProxy != null) {
            return sensorManagerProxy;
        }
        SensorManager sensorManager = (SensorManager) this.mAppContext.getSystemService(bg.ac);
        if (sensorManager != null) {
            this.mSensorManagerProxy = new SensorManagerProxyImpl(sensorManager);
        }
        return this.mSensorManagerProxy;
    }

    private void setEventTypeActive(boolean active) {
        this.mDeviceOrientationIsActive = active;
        this.mDeviceOrientationIsActiveWithBackupSensors = active && this.mDeviceOrientationSensors == DEVICE_ORIENTATION_SENSORS_C;
    }

    private void ensureRotationStructuresAllocated() {
        if (this.mDeviceRotationMatrix == null) {
            this.mDeviceRotationMatrix = new float[9];
        }
        if (this.mRotationAngles == null) {
            this.mRotationAngles = new double[3];
        }
        if (this.mTruncatedRotationVector == null) {
            this.mTruncatedRotationVector = new float[4];
        }
    }

    private boolean registerSensors(Set<Integer> sensorTypes, int rateInMicroseconds, boolean failOnMissingSensor) {
        Set<Integer> sensorsToActivate = new HashSet<>(sensorTypes);
        sensorsToActivate.removeAll(this.mActiveSensors);
        if (sensorsToActivate.isEmpty()) {
            return true;
        }
        boolean success = false;
        for (Integer sensorType : sensorsToActivate) {
            boolean result = registerForSensorType(sensorType.intValue(), rateInMicroseconds);
            if (!result && failOnMissingSensor) {
                unregisterSensors(sensorsToActivate);
                return false;
            } else if (result) {
                this.mActiveSensors.add(sensorType);
                success = true;
            }
        }
        return success;
    }

    private void unregisterSensors(Iterable<Integer> sensorTypes) {
        for (Integer sensorType : sensorTypes) {
            if (this.mActiveSensors.contains(sensorType)) {
                getSensorManagerProxy().unregisterListener(this, sensorType.intValue());
                this.mActiveSensors.remove(sensorType);
            }
        }
    }

    private boolean registerForSensorType(int type, int rateInMicroseconds) {
        SensorManagerProxy sensorManager = getSensorManagerProxy();
        if (sensorManager == null) {
            return false;
        }
        return sensorManager.registerListener(this, type, rateInMicroseconds, getHandler());
    }

    /* access modifiers changed from: package-private */
    public void gotOrientation(double alpha, double beta, double gamma) {
        ArrayList<OnOrientationChangedListener> arrayList = this.mListeners;
        if (arrayList != null) {
            try {
                Iterator<OnOrientationChangedListener> it = arrayList.iterator();
                while (it.hasNext()) {
                    it.next().onOrientationChanged(alpha, beta, gamma);
                }
            } catch (Throwable e) {
                LogProxy.e("[OrientationDetector] ", e);
            }
        }
    }

    private Handler getHandler() {
        if (this.mHandler == null) {
            HandlerThread handlerThread = new HandlerThread("DeviceOrientation");
            this.mThread = handlerThread;
            handlerThread.start();
            this.mHandler = new Handler(this.mThread.getLooper());
        }
        return this.mHandler;
    }
}
