package com.alibaba.android.bindingx.core.internal;

import android.content.Context;
import android.text.TextUtils;
import android.util.Pair;
import android.view.View;
import com.alibaba.android.bindingx.core.LogProxy;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public final class Utils {
    private Utils() {
    }

    public static Map<String, Object> toMap(JSONObject object) throws JSONException {
        if (object == null) {
            return Collections.emptyMap();
        }
        Map<String, Object> map = new HashMap<>();
        Iterator keys = object.keys();
        while (keys.hasNext()) {
            String key = keys.next();
            map.put(key, fromJson(object.get(key)));
        }
        return map;
    }

    public static List toList(JSONArray array) throws JSONException {
        if (array == null) {
            return Collections.emptyList();
        }
        List<Object> list = new ArrayList<>();
        for (int i = 0; i < array.length(); i++) {
            list.add(fromJson(array.get(i)));
        }
        return list;
    }

    private static Object fromJson(Object json) throws JSONException {
        if (json == JSONObject.NULL) {
            return null;
        }
        if (json instanceof JSONObject) {
            return toMap((JSONObject) json);
        }
        if (json instanceof JSONArray) {
            return toList((JSONArray) json);
        }
        return json;
    }

    public static String getStringValue(Map<String, Object> params, String key) {
        Object value = params.get(key);
        if (value == null) {
            return null;
        }
        if (value instanceof String) {
            return (String) value;
        }
        return value.toString();
    }

    public static List<Map<String, Object>> getRuntimeProps(Map<String, Object> params) {
        Object result = params.get(BindingXConstants.KEY_RUNTIME_PROPS);
        if (result == null) {
            return null;
        }
        try {
            return (List) result;
        } catch (Exception e) {
            return null;
        }
    }

    public static Map<String, ExpressionPair> getCustomInterceptors(Map<String, Object> params) {
        Object value = params.get(BindingXConstants.KEY_INTERCEPTORS);
        if (value == null || !(value instanceof Map)) {
            return null;
        }
        Map<String, ExpressionPair> interceptors = new HashMap<>(8);
        for (Map.Entry entry : ((Map) value).entrySet()) {
            Object k = entry.getKey();
            Object v = entry.getValue();
            if ((k instanceof String) && (v instanceof Map)) {
                ExpressionPair pair = null;
                try {
                    pair = getExpressionPair((Map) v, BindingXConstants.KEY_EXPRESSION);
                } catch (Exception e) {
                }
                if (pair != null) {
                    interceptors.put((String) k, pair);
                }
            }
        }
        return interceptors;
    }

    public static ExpressionPair getExpressionPair(Map<String, Object> params, String key) {
        Object value = params.get(key);
        if (value == null) {
            return null;
        }
        if (value instanceof String) {
            return ExpressionPair.create(null, (String) value);
        }
        if (!(value instanceof Map)) {
            return null;
        }
        JSONObject jsonObject = null;
        try {
            jsonObject = new JSONObject((Map) value);
        } catch (Throwable e) {
            LogProxy.e("unexpected json parse error.", e);
        }
        if (jsonObject == null) {
            return ExpressionPair.create(null, null);
        }
        String origin = jsonObject.optString("origin", null);
        String transformed = jsonObject.optString(BindingXConstants.KEY_TRANSFORMED, null);
        if (!TextUtils.isEmpty(origin) || !TextUtils.isEmpty(transformed)) {
            return ExpressionPair.create(origin, transformed);
        }
        return ExpressionPair.create(null, null);
    }

    @SafeVarargs
    public static <E> HashSet<E> newHashSet(E... elements) {
        HashSet<E> set = new HashSet<>(elements.length);
        Collections.addAll(set, elements);
        return set;
    }

    @SafeVarargs
    public static <E> ArrayList<E> newArrayList(E... elements) {
        ArrayList<E> list = new ArrayList<>(elements.length);
        Collections.addAll(list, elements);
        return list;
    }

    public static float normalizeRotation(float rotation) {
        float rotation2 = rotation % 360.0f;
        if (rotation2 >= 0.0f) {
            if (rotation2 < 0.0f || rotation2 > 180.0f) {
                return (rotation2 % 180.0f) - 180.0f;
            }
            return rotation2;
        } else if (rotation2 <= -180.0f || rotation2 >= 0.0f) {
            return (rotation2 % 180.0f) + 180.0f;
        } else {
            return rotation2;
        }
    }

    public static int normalizedPerspectiveValue(Context context, int raw) {
        return (int) (((float) raw) * context.getApplicationContext().getResources().getDisplayMetrics().density * 5.0f);
    }

    public static Pair<Float, Float> parseTransformOrigin(String value, View view) {
        int firstSpace;
        float pivotX;
        float pivotY;
        if (!TextUtils.isEmpty(value) && (firstSpace = value.indexOf(32)) != -1) {
            int i = firstSpace;
            while (i < value.length() && value.charAt(i) == ' ') {
                i++;
            }
            if (i < value.length() && value.charAt(i) != ' ') {
                String x = value.substring(0, firstSpace).trim();
                String y = value.substring(i, value.length()).trim();
                if ("left".equals(x)) {
                    pivotX = 0.0f;
                } else if ("right".equals(x)) {
                    pivotX = (float) view.getWidth();
                } else if ("center".equals(x)) {
                    pivotX = (float) (view.getWidth() / 2);
                } else {
                    pivotX = (float) (view.getWidth() / 2);
                }
                if ("top".equals(y)) {
                    pivotY = 0.0f;
                } else if ("bottom".equals(y)) {
                    pivotY = (float) view.getHeight();
                } else if ("center".equals(y)) {
                    pivotY = (float) (view.getHeight() / 2);
                } else {
                    pivotY = (float) (view.getHeight() / 2);
                }
                return new Pair<>(Float.valueOf(pivotX), Float.valueOf(pivotY));
            }
        }
        return null;
    }
}
