package com.alibaba.android.bindingx.plugin.weex;

import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.Handler;
import android.os.Looper;
import android.text.Layout;
import android.text.TextPaint;
import android.text.TextUtils;
import android.util.Pair;
import android.view.View;
import android.widget.TextView;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.alibaba.android.bindingx.core.WeakRunnable;
import com.alibaba.android.bindingx.core.internal.Utils;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.dom.transition.WXTransition;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXScroller;
import com.taobao.weex.ui.component.WXText;
import com.taobao.weex.ui.view.WXTextView;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.WXUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

final class WXViewUpdateService {
    private static final NOpUpdater EMPTY_INVOKER = new NOpUpdater();
    private static final List<String> LAYOUT_PROPERTIES = Arrays.asList("width", "height", LAYOUT_PROPERTY_MARGIN_LEFT, LAYOUT_PROPERTY_MARGIN_RIGHT, LAYOUT_PROPERTY_MARGIN_TOP, LAYOUT_PROPERTY_MARGIN_BOTTOM, "padding-left", "padding-right", LAYOUT_PROPERTY_PADDING_TOP, LAYOUT_PROPERTY_PADDING_BOTTOM);
    private static final String LAYOUT_PROPERTY_HEIGHT = "height";
    private static final String LAYOUT_PROPERTY_MARGIN_BOTTOM = "margin-bottom";
    private static final String LAYOUT_PROPERTY_MARGIN_LEFT = "margin-left";
    private static final String LAYOUT_PROPERTY_MARGIN_RIGHT = "margin-right";
    private static final String LAYOUT_PROPERTY_MARGIN_TOP = "margin-top";
    private static final String LAYOUT_PROPERTY_PADDING_BOTTOM = "padding-bottom";
    private static final String LAYOUT_PROPERTY_PADDING_LEFT = "padding-left";
    private static final String LAYOUT_PROPERTY_PADDING_RIGHT = "padding-right";
    private static final String LAYOUT_PROPERTY_PADDING_TOP = "padding-top";
    private static final String LAYOUT_PROPERTY_WIDTH = "width";
    private static final String PERSPECTIVE = "perspective";
    private static final String TRANSFORM_ORIGIN = "transformOrigin";
    private static final LayoutUpdater sLayoutUpdater = new LayoutUpdater();
    private static final Map<String, IWXViewUpdater> sTransformPropertyUpdaterMap;
    private static final Handler sUIHandler = new Handler(Looper.getMainLooper());

    WXViewUpdateService() {
    }

    static {
        HashMap hashMap = new HashMap();
        sTransformPropertyUpdaterMap = hashMap;
        hashMap.put("opacity", new OpacityUpdater());
        sTransformPropertyUpdaterMap.put("transform.translate", new TranslateUpdater());
        sTransformPropertyUpdaterMap.put("transform.translateX", new TranslateXUpdater());
        sTransformPropertyUpdaterMap.put("transform.translateY", new TranslateYUpdater());
        sTransformPropertyUpdaterMap.put("transform.scale", new ScaleUpdater());
        sTransformPropertyUpdaterMap.put("transform.scaleX", new ScaleXUpdater());
        sTransformPropertyUpdaterMap.put("transform.scaleY", new ScaleYUpdater());
        sTransformPropertyUpdaterMap.put("transform.rotate", new RotateUpdater());
        sTransformPropertyUpdaterMap.put("transform.rotateZ", new RotateUpdater());
        sTransformPropertyUpdaterMap.put("transform.rotateX", new RotateXUpdater());
        sTransformPropertyUpdaterMap.put("transform.rotateY", new RotateYUpdater());
        sTransformPropertyUpdaterMap.put("background-color", new BackgroundUpdater());
        sTransformPropertyUpdaterMap.put("color", new ColorUpdater());
        sTransformPropertyUpdaterMap.put("scroll.contentOffset", new ContentOffsetUpdater());
        sTransformPropertyUpdaterMap.put("scroll.contentOffsetX", new ContentOffsetXUpdater());
        sTransformPropertyUpdaterMap.put("scroll.contentOffsetY", new ContentOffsetYUpdater());
        sTransformPropertyUpdaterMap.put("border-top-left-radius", new BorderRadiusTopLeftUpdater());
        sTransformPropertyUpdaterMap.put("border-top-right-radius", new BorderRadiusTopRightUpdater());
        sTransformPropertyUpdaterMap.put("border-bottom-left-radius", new BorderRadiusBottomLeftUpdater());
        sTransformPropertyUpdaterMap.put("border-bottom-right-radius", new BorderRadiusBottomRightUpdater());
        sTransformPropertyUpdaterMap.put("border-radius", new BorderRadiusUpdater());
    }

    static IWXViewUpdater findUpdater(String prop) {
        IWXViewUpdater updater = sTransformPropertyUpdaterMap.get(prop);
        if (updater != null) {
            return updater;
        }
        if (LAYOUT_PROPERTIES.contains(prop)) {
            sLayoutUpdater.setPropertyName(prop);
            return sLayoutUpdater;
        }
        LogProxy.e("unknown property [" + prop + Operators.ARRAY_END_STR);
        return EMPTY_INVOKER;
    }

    /* access modifiers changed from: private */
    public static final class NOpUpdater implements IWXViewUpdater {
        private NOpUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, View targetView, Object cmd, PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
        }
    }

    /* access modifiers changed from: private */
    public static void runOnUIThread(Runnable runnable) {
        sUIHandler.post(new WeakRunnable(runnable));
    }

    public static void clearCallbacks() {
        sUIHandler.removeCallbacksAndMessages(null);
    }

    private static final class ContentOffsetUpdater implements IWXViewUpdater {
        private ContentOffsetUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            final View scrollView = WXViewUpdateService.findScrollTarget(component);
            if (scrollView != null) {
                if (cmd instanceof Double) {
                    final double val = ((Double) cmd).doubleValue();
                    WXViewUpdateService.runOnUIThread(new Runnable() {
                        /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ContentOffsetUpdater.AnonymousClass1 */

                        public void run() {
                            scrollView.setScrollX((int) WXViewUpdateService.getRealSize(val, translator));
                            scrollView.setScrollY((int) WXViewUpdateService.getRealSize(val, translator));
                        }
                    });
                } else if (cmd instanceof ArrayList) {
                    ArrayList<Object> l = (ArrayList) cmd;
                    if (l.size() >= 2 && (l.get(0) instanceof Double) && (l.get(1) instanceof Double)) {
                        final double x = ((Double) l.get(0)).doubleValue();
                        final double y = ((Double) l.get(1)).doubleValue();
                        WXViewUpdateService.runOnUIThread(new Runnable() {
                            /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ContentOffsetUpdater.AnonymousClass2 */

                            public void run() {
                                scrollView.setScrollX((int) WXViewUpdateService.getRealSize(x, translator));
                                scrollView.setScrollY((int) WXViewUpdateService.getRealSize(y, translator));
                            }
                        });
                    }
                }
            }
        }
    }

    private static final class ContentOffsetXUpdater implements IWXViewUpdater {
        private ContentOffsetXUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            final View scrollView = WXViewUpdateService.findScrollTarget(component);
            if (scrollView != null && (cmd instanceof Double)) {
                final double val = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ContentOffsetXUpdater.AnonymousClass1 */

                    public void run() {
                        scrollView.setScrollX((int) WXViewUpdateService.getRealSize(val, translator));
                    }
                });
            }
        }
    }

    private static final class ContentOffsetYUpdater implements IWXViewUpdater {
        private ContentOffsetYUpdater() {
        }

        /* JADX WARNING: Code restructure failed: missing block: B:3:0x0005, code lost:
            r0 = com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.findScrollTarget(r11);
         */
        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            final View scrollView;
            if ((cmd instanceof Double) && scrollView != null) {
                final double val = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ContentOffsetYUpdater.AnonymousClass1 */

                    public void run() {
                        scrollView.setScrollY((int) WXViewUpdateService.getRealSize(val, translator));
                    }
                });
            }
        }
    }

    private static final class OpacityUpdater implements IWXViewUpdater {
        private OpacityUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Double) {
                final float alpha = (float) ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.OpacityUpdater.AnonymousClass1 */

                    public void run() {
                        targetView.setAlpha(alpha);
                    }
                });
            }
        }
    }

    private static final class TranslateUpdater implements IWXViewUpdater {
        private TranslateUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof ArrayList) {
                ArrayList<Object> list = (ArrayList) cmd;
                if (list.size() >= 2 && (list.get(0) instanceof Double) && (list.get(1) instanceof Double)) {
                    final double x1 = ((Double) list.get(0)).doubleValue();
                    final double y1 = ((Double) list.get(1)).doubleValue();
                    WXViewUpdateService.runOnUIThread(new Runnable() {
                        /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.TranslateUpdater.AnonymousClass1 */

                        public void run() {
                            targetView.setTranslationX((float) WXViewUpdateService.getRealSize(x1, translator));
                            targetView.setTranslationY((float) WXViewUpdateService.getRealSize(y1, translator));
                        }
                    });
                }
            }
        }
    }

    private static final class TranslateXUpdater implements IWXViewUpdater {
        private TranslateXUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Double) {
                final double d = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.TranslateXUpdater.AnonymousClass1 */

                    public void run() {
                        targetView.setTranslationX((float) WXViewUpdateService.getRealSize(d, translator));
                    }
                });
            }
        }
    }

    private static final class TranslateYUpdater implements IWXViewUpdater {
        private TranslateYUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Double) {
                final double d = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.TranslateYUpdater.AnonymousClass1 */

                    public void run() {
                        targetView.setTranslationY((float) WXViewUpdateService.getRealSize(d, translator));
                    }
                });
            }
        }
    }

    private static final class ScaleUpdater implements IWXViewUpdater {
        private ScaleUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, final Object cmd, PlatformManager.IDeviceResolutionTranslator translator, final Map<String, Object> config) {
            WXViewUpdateService.runOnUIThread(new Runnable() {
                /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ScaleUpdater.AnonymousClass1 */

                public void run() {
                    int perspective = Utils.normalizedPerspectiveValue(targetView.getContext(), WXUtils.getInt(config.get("perspective")));
                    Pair<Float, Float> pivot = Utils.parseTransformOrigin(WXUtils.getString(config.get("transformOrigin"), null), targetView);
                    if (perspective != 0) {
                        targetView.setCameraDistance((float) perspective);
                    }
                    if (pivot != null) {
                        targetView.setPivotX(((Float) pivot.first).floatValue());
                        targetView.setPivotY(((Float) pivot.second).floatValue());
                    }
                    Object obj = cmd;
                    if (obj instanceof Double) {
                        double val = ((Double) obj).doubleValue();
                        targetView.setScaleX((float) val);
                        targetView.setScaleY((float) val);
                    } else if (obj instanceof ArrayList) {
                        ArrayList<Object> list = (ArrayList) obj;
                        if (list.size() >= 2 && (list.get(0) instanceof Double) && (list.get(1) instanceof Double)) {
                            double x = ((Double) list.get(0)).doubleValue();
                            double y = ((Double) list.get(1)).doubleValue();
                            targetView.setScaleX((float) x);
                            targetView.setScaleY((float) y);
                        }
                    }
                }
            });
        }
    }

    private static final class ScaleXUpdater implements IWXViewUpdater {
        private ScaleXUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, final Object cmd, PlatformManager.IDeviceResolutionTranslator translator, final Map<String, Object> config) {
            if (cmd instanceof Double) {
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ScaleXUpdater.AnonymousClass1 */

                    public void run() {
                        Pair<Float, Float> pivot = Utils.parseTransformOrigin(WXUtils.getString(config.get("transformOrigin"), null), targetView);
                        if (pivot != null) {
                            targetView.setPivotX(((Float) pivot.first).floatValue());
                            targetView.setPivotY(((Float) pivot.second).floatValue());
                        }
                        targetView.setScaleX((float) ((Double) cmd).doubleValue());
                    }
                });
            }
        }
    }

    private static final class ScaleYUpdater implements IWXViewUpdater {
        private ScaleYUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, final Object cmd, PlatformManager.IDeviceResolutionTranslator translator, final Map<String, Object> config) {
            if (cmd instanceof Double) {
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ScaleYUpdater.AnonymousClass1 */

                    public void run() {
                        Pair<Float, Float> pivot = Utils.parseTransformOrigin(WXUtils.getString(config.get("transformOrigin"), null), targetView);
                        if (pivot != null) {
                            targetView.setPivotX(((Float) pivot.first).floatValue());
                            targetView.setPivotY(((Float) pivot.second).floatValue());
                        }
                        targetView.setScaleY((float) ((Double) cmd).doubleValue());
                    }
                });
            }
        }
    }

    private static final class RotateUpdater implements IWXViewUpdater {
        private RotateUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, final Object cmd, PlatformManager.IDeviceResolutionTranslator translator, final Map<String, Object> config) {
            if (cmd instanceof Double) {
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.RotateUpdater.AnonymousClass1 */

                    public void run() {
                        int perspective = Utils.normalizedPerspectiveValue(targetView.getContext(), WXUtils.getInt(config.get("perspective")));
                        Pair<Float, Float> pivot = Utils.parseTransformOrigin(WXUtils.getString(config.get("transformOrigin"), null), targetView);
                        if (perspective != 0) {
                            targetView.setCameraDistance((float) perspective);
                        }
                        if (pivot != null) {
                            targetView.setPivotX(((Float) pivot.first).floatValue());
                            targetView.setPivotY(((Float) pivot.second).floatValue());
                        }
                        targetView.setRotation((float) ((Double) cmd).doubleValue());
                    }
                });
            }
        }
    }

    private static final class RotateXUpdater implements IWXViewUpdater {
        private RotateXUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, final Object cmd, PlatformManager.IDeviceResolutionTranslator translator, final Map<String, Object> config) {
            if (cmd instanceof Double) {
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.RotateXUpdater.AnonymousClass1 */

                    public void run() {
                        int perspective = Utils.normalizedPerspectiveValue(targetView.getContext(), WXUtils.getInt(config.get("perspective")));
                        Pair<Float, Float> pivot = Utils.parseTransformOrigin(WXUtils.getString(config.get("transformOrigin"), null), targetView);
                        if (perspective != 0) {
                            targetView.setCameraDistance((float) perspective);
                        }
                        if (pivot != null) {
                            targetView.setPivotX(((Float) pivot.first).floatValue());
                            targetView.setPivotY(((Float) pivot.second).floatValue());
                        }
                        targetView.setRotationX((float) ((Double) cmd).doubleValue());
                    }
                });
            }
        }
    }

    private static final class RotateYUpdater implements IWXViewUpdater {
        private RotateYUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, final Object cmd, PlatformManager.IDeviceResolutionTranslator translator, final Map<String, Object> config) {
            if (cmd instanceof Double) {
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.RotateYUpdater.AnonymousClass1 */

                    public void run() {
                        int perspective = Utils.normalizedPerspectiveValue(targetView.getContext(), WXUtils.getInt(config.get("perspective")));
                        Pair<Float, Float> pivot = Utils.parseTransformOrigin(WXUtils.getString(config.get("transformOrigin"), null), targetView);
                        if (perspective != 0) {
                            targetView.setCameraDistance((float) perspective);
                        }
                        if (pivot != null) {
                            targetView.setPivotX(((Float) pivot.first).floatValue());
                            targetView.setPivotY(((Float) pivot.second).floatValue());
                        }
                        targetView.setRotationY((float) ((Double) cmd).doubleValue());
                    }
                });
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static final class LayoutUpdater implements IWXViewUpdater {
        private String propertyName;

        LayoutUpdater() {
        }

        /* access modifiers changed from: package-private */
        public void setPropertyName(String propertyName2) {
            this.propertyName = propertyName2;
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, View targetView, Object cmd, PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if ((cmd instanceof Double) && !TextUtils.isEmpty(this.propertyName)) {
                double d = ((Double) cmd).doubleValue();
                String property = null;
                String str = this.propertyName;
                char c = 65535;
                switch (str.hashCode()) {
                    case -1502084711:
                        if (str.equals(WXViewUpdateService.LAYOUT_PROPERTY_PADDING_TOP)) {
                            c = '\b';
                            break;
                        }
                        break;
                    case -1221029593:
                        if (str.equals("height")) {
                            c = 1;
                            break;
                        }
                        break;
                    case -887955139:
                        if (str.equals(WXViewUpdateService.LAYOUT_PROPERTY_MARGIN_RIGHT)) {
                            c = 3;
                            break;
                        }
                        break;
                    case -396426912:
                        if (str.equals("padding-right")) {
                            c = 7;
                            break;
                        }
                        break;
                    case 113126854:
                        if (str.equals("width")) {
                            c = 0;
                            break;
                        }
                        break;
                    case 143541095:
                        if (str.equals(WXViewUpdateService.LAYOUT_PROPERTY_PADDING_BOTTOM)) {
                            c = '\t';
                            break;
                        }
                        break;
                    case 679766083:
                        if (str.equals("padding-left")) {
                            c = 6;
                            break;
                        }
                        break;
                    case 941004998:
                        if (str.equals(WXViewUpdateService.LAYOUT_PROPERTY_MARGIN_LEFT)) {
                            c = 2;
                            break;
                        }
                        break;
                    case 1970025654:
                        if (str.equals(WXViewUpdateService.LAYOUT_PROPERTY_MARGIN_TOP)) {
                            c = 4;
                            break;
                        }
                        break;
                    case 2086035242:
                        if (str.equals(WXViewUpdateService.LAYOUT_PROPERTY_MARGIN_BOTTOM)) {
                            c = 5;
                            break;
                        }
                        break;
                }
                switch (c) {
                    case 0:
                        property = "width";
                        break;
                    case 1:
                        property = "height";
                        break;
                    case 2:
                        property = Constants.Name.MARGIN_LEFT;
                        break;
                    case 3:
                        property = Constants.Name.MARGIN_RIGHT;
                        break;
                    case 4:
                        property = Constants.Name.MARGIN_TOP;
                        break;
                    case 5:
                        property = Constants.Name.MARGIN_BOTTOM;
                        break;
                    case 6:
                        property = Constants.Name.PADDING_LEFT;
                        break;
                    case 7:
                        property = Constants.Name.PADDING_RIGHT;
                        break;
                    case '\b':
                        property = Constants.Name.PADDING_TOP;
                        break;
                    case '\t':
                        property = Constants.Name.PADDING_BOTTOM;
                        break;
                }
                if (!TextUtils.isEmpty(property)) {
                    WXTransition.asynchronouslyUpdateLayout(component, property, (float) WXViewUpdateService.getRealSize(d, translator));
                    this.propertyName = null;
                }
            }
        }
    }

    private static final class BackgroundUpdater implements IWXViewUpdater {
        private BackgroundUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Integer) {
                final int d = ((Integer) cmd).intValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.BackgroundUpdater.AnonymousClass1 */

                    public void run() {
                        Drawable drawable = targetView.getBackground();
                        if (drawable == null) {
                            targetView.setBackgroundColor(d);
                        } else if (drawable instanceof BorderDrawable) {
                            ((BorderDrawable) drawable).setColor(d);
                        } else if (drawable instanceof ColorDrawable) {
                            ((ColorDrawable) drawable).setColor(d);
                        }
                    }
                });
            }
        }
    }

    private static final class ColorUpdater implements IWXViewUpdater {
        private ColorUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(final WXComponent component, final View targetView, Object cmd, PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Integer) {
                final int d = ((Integer) cmd).intValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.ColorUpdater.AnonymousClass1 */

                    public void run() {
                        View view = targetView;
                        if (view instanceof TextView) {
                            ((TextView) view).setTextColor(d);
                        } else if ((component instanceof WXText) && (view instanceof WXTextView)) {
                            try {
                                ((WXTextView) view).setTextColor(d);
                                targetView.invalidate();
                            } catch (Throwable e) {
                                LogProxy.e("can not update text color, try fallback to call the old API", e);
                                Layout layout = ((WXTextView) targetView).getTextLayout();
                                if (layout != null) {
                                    TextPaint paint = layout.getPaint();
                                    if (paint != null) {
                                        paint.setColor(d);
                                    }
                                    targetView.invalidate();
                                }
                            }
                        }
                    }
                });
            }
        }
    }

    private static final class BorderRadiusTopLeftUpdater implements IWXViewUpdater {
        private BorderRadiusTopLeftUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Double) {
                final double d = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.BorderRadiusTopLeftUpdater.AnonymousClass1 */

                    public void run() {
                        Drawable drawable = targetView.getBackground();
                        if (drawable != null && (drawable instanceof BorderDrawable)) {
                            ((BorderDrawable) drawable).setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_LEFT, (float) WXViewUpdateService.getRealSize(d, translator));
                        }
                    }
                });
            }
        }
    }

    private static final class BorderRadiusTopRightUpdater implements IWXViewUpdater {
        private BorderRadiusTopRightUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Double) {
                final double d = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.BorderRadiusTopRightUpdater.AnonymousClass1 */

                    public void run() {
                        Drawable drawable = targetView.getBackground();
                        if (drawable != null && (drawable instanceof BorderDrawable)) {
                            ((BorderDrawable) drawable).setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_RIGHT, (float) WXViewUpdateService.getRealSize(d, translator));
                        }
                    }
                });
            }
        }
    }

    private static final class BorderRadiusBottomLeftUpdater implements IWXViewUpdater {
        private BorderRadiusBottomLeftUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Double) {
                final double d = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.BorderRadiusBottomLeftUpdater.AnonymousClass1 */

                    public void run() {
                        Drawable drawable = targetView.getBackground();
                        if (drawable != null && (drawable instanceof BorderDrawable)) {
                            ((BorderDrawable) drawable).setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT, (float) WXViewUpdateService.getRealSize(d, translator));
                        }
                    }
                });
            }
        }
    }

    private static final class BorderRadiusBottomRightUpdater implements IWXViewUpdater {
        private BorderRadiusBottomRightUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof Double) {
                final double d = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.BorderRadiusBottomRightUpdater.AnonymousClass1 */

                    public void run() {
                        Drawable drawable = targetView.getBackground();
                        if (drawable != null && (drawable instanceof BorderDrawable)) {
                            ((BorderDrawable) drawable).setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT, (float) WXViewUpdateService.getRealSize(d, translator));
                        }
                    }
                });
            }
        }
    }

    private static final class BorderRadiusUpdater implements IWXViewUpdater {
        private BorderRadiusUpdater() {
        }

        @Override // com.alibaba.android.bindingx.plugin.weex.IWXViewUpdater
        public void update(WXComponent component, final View targetView, Object cmd, final PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> map) {
            if (cmd instanceof ArrayList) {
                final ArrayList<Object> l = (ArrayList) cmd;
                if (l.size() == 4) {
                    WXViewUpdateService.runOnUIThread(new Runnable() {
                        /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.BorderRadiusUpdater.AnonymousClass1 */

                        public void run() {
                            Drawable drawable = targetView.getBackground();
                            if (drawable != null && (drawable instanceof BorderDrawable)) {
                                double topLeft = 0.0d;
                                double topRight = 0.0d;
                                double bottomLeft = 0.0d;
                                double bottomRight = 0.0d;
                                if (l.get(0) instanceof Double) {
                                    topLeft = ((Double) l.get(0)).doubleValue();
                                }
                                if (l.get(1) instanceof Double) {
                                    topRight = ((Double) l.get(1)).doubleValue();
                                }
                                if (l.get(2) instanceof Double) {
                                    bottomLeft = ((Double) l.get(2)).doubleValue();
                                }
                                if (l.get(3) instanceof Double) {
                                    bottomRight = ((Double) l.get(3)).doubleValue();
                                }
                                BorderDrawable borderDrawable = (BorderDrawable) drawable;
                                borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_LEFT, (float) WXViewUpdateService.getRealSize(topLeft, translator));
                                borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_RIGHT, (float) WXViewUpdateService.getRealSize(topRight, translator));
                                borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT, (float) WXViewUpdateService.getRealSize(bottomLeft, translator));
                                borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT, (float) WXViewUpdateService.getRealSize(bottomRight, translator));
                            }
                        }
                    });
                }
            } else if (cmd instanceof Double) {
                final double value = ((Double) cmd).doubleValue();
                WXViewUpdateService.runOnUIThread(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.WXViewUpdateService.BorderRadiusUpdater.AnonymousClass2 */

                    public void run() {
                        Drawable drawable = targetView.getBackground();
                        if (drawable != null && (drawable instanceof BorderDrawable)) {
                            BorderDrawable borderDrawable = (BorderDrawable) drawable;
                            borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_LEFT, (float) WXViewUpdateService.getRealSize(value, translator));
                            borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_RIGHT, (float) WXViewUpdateService.getRealSize(value, translator));
                            borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT, (float) WXViewUpdateService.getRealSize(value, translator));
                            borderDrawable.setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT, (float) WXViewUpdateService.getRealSize(value, translator));
                        }
                    }
                });
            }
        }
    }

    /* access modifiers changed from: private */
    public static double getRealSize(double size, PlatformManager.IDeviceResolutionTranslator translator) {
        return translator.webToNative(size, new Object[0]);
    }

    /* access modifiers changed from: private */
    public static View findScrollTarget(WXComponent component) {
        if (component instanceof WXScroller) {
            return ((WXScroller) component).getInnerView();
        }
        LogProxy.e("scroll offset only support on Scroller Component");
        return null;
    }
}
