package com.facebook.common.callercontext;

import android.os.Parcel;
import android.os.Parcelable;
import com.facebook.common.internal.Objects;
import com.facebook.common.internal.Preconditions;
import com.xiaomi.mipush.sdk.Constants;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.Nullable;

public class ContextChain implements Parcelable {
    public static final Parcelable.Creator<ContextChain> CREATOR = new Parcelable.Creator<ContextChain>() {
        /* class com.facebook.common.callercontext.ContextChain.AnonymousClass1 */

        @Override // android.os.Parcelable.Creator
        public ContextChain createFromParcel(Parcel in) {
            return new ContextChain(in);
        }

        @Override // android.os.Parcelable.Creator
        public ContextChain[] newArray(int size) {
            return new ContextChain[size];
        }
    };
    private static final char PARENT_SEPARATOR = '/';
    public static final String TAG_INFRA = "i";
    public static final String TAG_PRODUCT = "p";
    public static final String TAG_PRODUCT_AND_INFRA = "pi";
    private static boolean sUseDeepEquals = false;
    @Nullable
    private Map<String, Object> mExtraData;
    private final int mLevel;
    private final String mName;
    @Nullable
    private final ContextChain mParent;
    @Nullable
    private String mSerializedString;
    private final String mTag;

    public static void setUseDeepEquals(boolean useDeepEquals) {
        sUseDeepEquals = useDeepEquals;
    }

    public ContextChain(String tag, String name, @Nullable Map<String, String> extraData, @Nullable ContextChain parent) {
        this.mTag = tag;
        this.mName = name;
        this.mLevel = parent != null ? parent.mLevel + 1 : 0;
        this.mParent = parent;
        Map<String, Object> parentExtraData = parent != null ? parent.getExtraData() : null;
        if (parentExtraData != null) {
            this.mExtraData = new HashMap(parentExtraData);
        }
        if (extraData != null) {
            if (this.mExtraData == null) {
                this.mExtraData = new HashMap();
            }
            this.mExtraData.putAll(extraData);
        }
    }

    public ContextChain(String tag, String name, @Nullable ContextChain parent) {
        this(tag, name, null, parent);
    }

    protected ContextChain(Parcel in) {
        this.mTag = in.readString();
        this.mName = in.readString();
        this.mLevel = in.readInt();
        this.mParent = (ContextChain) in.readParcelable(ContextChain.class.getClassLoader());
    }

    public String getName() {
        return this.mName;
    }

    public String getTag() {
        return this.mTag;
    }

    @Nullable
    public Map<String, Object> getExtraData() {
        return this.mExtraData;
    }

    @Nullable
    public ContextChain getParent() {
        return this.mParent;
    }

    public ContextChain getRootContextChain() {
        ContextChain contextChain = this.mParent;
        return contextChain == null ? this : contextChain.getRootContextChain();
    }

    @Nullable
    public String getStringExtra(String key) {
        Object val;
        Map<String, Object> map = this.mExtraData;
        if (map == null || (val = map.get(key)) == null) {
            return null;
        }
        return String.valueOf(val);
    }

    public void putObjectExtra(String key, Object value) {
        if (this.mExtraData == null) {
            this.mExtraData = new HashMap();
        }
        this.mExtraData.put(key, value);
    }

    public String toString() {
        if (this.mSerializedString == null) {
            this.mSerializedString = this.mTag + Constants.COLON_SEPARATOR + this.mName;
            if (this.mParent != null) {
                this.mSerializedString = this.mParent.toString() + PARENT_SEPARATOR + this.mSerializedString;
            }
        }
        return this.mSerializedString;
    }

    public String[] toStringArray() {
        String[] result = new String[(this.mLevel + 1)];
        ContextChain current = this;
        for (int i = this.mLevel; i >= 0; i += -1) {
            Preconditions.checkNotNull(current, "ContextChain level mismatch, this should not happen.");
            result[i] = current.mTag + Constants.COLON_SEPARATOR + current.mName;
            current = current.mParent;
        }
        return result;
    }

    public boolean equals(@Nullable Object obj) {
        if (!sUseDeepEquals) {
            return super.equals(obj);
        }
        if (this == obj) {
            return true;
        }
        if (obj == null || getClass() != obj.getClass()) {
            return false;
        }
        ContextChain other = (ContextChain) obj;
        if (Objects.equal(this.mTag, other.mTag) && Objects.equal(this.mName, other.mName) && this.mLevel == other.mLevel) {
            ContextChain contextChain = this.mParent;
            ContextChain contextChain2 = other.mParent;
            if (contextChain == contextChain2) {
                return true;
            }
            if (contextChain == null || !contextChain.equals(contextChain2)) {
                return false;
            }
            return true;
        }
        return false;
    }

    public int hashCode() {
        if (!sUseDeepEquals) {
            return super.hashCode();
        }
        int hashCode = super.hashCode() * 31;
        String str = this.mTag;
        int i = 0;
        int result = (hashCode + (str != null ? str.hashCode() : 0)) * 31;
        String str2 = this.mName;
        int result2 = (((result + (str2 != null ? str2.hashCode() : 0)) * 31) + this.mLevel) * 31;
        ContextChain contextChain = this.mParent;
        if (contextChain != null) {
            i = contextChain.hashCode();
        }
        return result2 + i;
    }

    public int describeContents() {
        return 0;
    }

    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(this.mTag);
        dest.writeString(this.mName);
        dest.writeInt(this.mLevel);
        dest.writeParcelable(this.mParent, flags);
    }
}
