package com.facebook.datasource;

import com.facebook.common.internal.Supplier;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.Executor;
import javax.annotation.Nullable;

public class DataSources {
    private DataSources() {
    }

    public static <T> DataSource<T> immediateFailedDataSource(Throwable failure) {
        SimpleDataSource<T> simpleDataSource = SimpleDataSource.create();
        simpleDataSource.setFailure(failure);
        return simpleDataSource;
    }

    public static <T> DataSource<T> immediateDataSource(T result) {
        SimpleDataSource<T> simpleDataSource = SimpleDataSource.create();
        simpleDataSource.setResult(result);
        return simpleDataSource;
    }

    public static <T> Supplier<DataSource<T>> getFailedDataSourceSupplier(final Throwable failure) {
        return new Supplier<DataSource<T>>() {
            /* class com.facebook.datasource.DataSources.AnonymousClass1 */

            @Override // com.facebook.common.internal.Supplier
            public DataSource<T> get() {
                return DataSources.immediateFailedDataSource(failure);
            }
        };
    }

    @Nullable
    public static <T> T waitForFinalResult(DataSource<T> dataSource) throws Throwable {
        final CountDownLatch latch = new CountDownLatch(1);
        final ValueHolder<T> resultHolder = new ValueHolder<>();
        final ValueHolder<Throwable> pendingException = new ValueHolder<>();
        dataSource.subscribe(new DataSubscriber<T>() {
            /* class com.facebook.datasource.DataSources.AnonymousClass2 */

            @Override // com.facebook.datasource.DataSubscriber
            public void onNewResult(DataSource<T> dataSource) {
                if (dataSource.isFinished()) {
                    try {
                        resultHolder.value = dataSource.getResult();
                    } finally {
                        latch.countDown();
                    }
                }
            }

            @Override // com.facebook.datasource.DataSubscriber
            public void onFailure(DataSource<T> dataSource) {
                try {
                    pendingException.value = (T) dataSource.getFailureCause();
                } finally {
                    latch.countDown();
                }
            }

            @Override // com.facebook.datasource.DataSubscriber
            public void onCancellation(DataSource<T> dataSource) {
                latch.countDown();
            }

            @Override // com.facebook.datasource.DataSubscriber
            public void onProgressUpdate(DataSource<T> dataSource) {
            }
        }, new Executor() {
            /* class com.facebook.datasource.DataSources.AnonymousClass3 */

            public void execute(Runnable command) {
                command.run();
            }
        });
        latch.await();
        if (pendingException.value == null) {
            return resultHolder.value;
        }
        throw pendingException.value;
    }

    private static class ValueHolder<T> {
        @Nullable
        public T value;

        private ValueHolder() {
            this.value = null;
        }
    }
}
