package com.facebook.drawee.backends.pipeline.info.internal;

import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.internal.Supplier;
import com.facebook.common.time.MonotonicClock;
import com.facebook.drawee.backends.pipeline.info.ImagePerfNotifier;
import com.facebook.drawee.backends.pipeline.info.ImagePerfState;
import com.facebook.fresco.ui.common.BaseControllerListener2;
import com.facebook.fresco.ui.common.ControllerListener2;
import com.facebook.fresco.ui.common.DimensionsInfo;
import com.facebook.fresco.ui.common.OnDrawControllerListener;
import com.facebook.imagepipeline.image.ImageInfo;
import java.io.Closeable;
import javax.annotation.Nullable;

public class ImagePerfControllerListener2 extends BaseControllerListener2<ImageInfo> implements OnDrawControllerListener<ImageInfo>, Closeable {
    private static final int WHAT_STATUS = 1;
    private static final int WHAT_VISIBILITY = 2;
    private final Supplier<Boolean> mAsyncLogging;
    private final MonotonicClock mClock;
    @Nullable
    private Handler mHandler;
    private final ImagePerfNotifier mImagePerfNotifier;
    private final ImagePerfState mImagePerfState;
    private final Supplier<Boolean> mUseNewState;

    /* access modifiers changed from: package-private */
    public static class LogHandler extends Handler {
        private final ImagePerfNotifier mNotifier;

        public LogHandler(Looper looper, ImagePerfNotifier notifier) {
            super(looper);
            this.mNotifier = notifier;
        }

        public void handleMessage(Message msg) {
            ImagePerfState state = (ImagePerfState) Preconditions.checkNotNull(msg.obj);
            int i = msg.what;
            if (i == 1) {
                this.mNotifier.notifyStatusUpdated(state, msg.arg1);
            } else if (i == 2) {
                this.mNotifier.notifyListenersOfVisibilityStateUpdate(state, msg.arg1);
            }
        }
    }

    public ImagePerfControllerListener2(MonotonicClock clock, ImagePerfState imagePerfState, ImagePerfNotifier imagePerfNotifier, Supplier<Boolean> asyncLogging, Supplier<Boolean> useNewState) {
        this.mClock = clock;
        this.mImagePerfState = imagePerfState;
        this.mImagePerfNotifier = imagePerfNotifier;
        this.mAsyncLogging = asyncLogging;
        this.mUseNewState = useNewState;
    }

    @Override // com.facebook.fresco.ui.common.ControllerListener2, com.facebook.fresco.ui.common.BaseControllerListener2
    public void onSubmit(String id, @Nullable Object callerContext, @Nullable ControllerListener2.Extras extraData) {
        long now = this.mClock.now();
        ImagePerfState state = obtainState();
        state.resetPointsTimestamps();
        state.setControllerSubmitTimeMs(now);
        state.setControllerId(id);
        state.setCallerContext(callerContext);
        state.setExtraData(extraData);
        updateStatus(state, 0);
        reportViewVisible(state, now);
    }

    public void onIntermediateImageSet(String id, @Nullable ImageInfo imageInfo) {
        long now = this.mClock.now();
        ImagePerfState state = obtainState();
        state.setControllerIntermediateImageSetTimeMs(now);
        state.setControllerId(id);
        state.setImageInfo(imageInfo);
        updateStatus(state, 2);
    }

    public void onFinalImageSet(String id, @Nullable ImageInfo imageInfo, @Nullable ControllerListener2.Extras extraData) {
        long now = this.mClock.now();
        ImagePerfState state = obtainState();
        state.setExtraData(extraData);
        state.setControllerFinalImageSetTimeMs(now);
        state.setImageRequestEndTimeMs(now);
        state.setControllerId(id);
        state.setImageInfo(imageInfo);
        updateStatus(state, 3);
    }

    @Override // com.facebook.fresco.ui.common.ControllerListener2, com.facebook.fresco.ui.common.BaseControllerListener2
    public void onFailure(String id, @Nullable Throwable throwable, @Nullable ControllerListener2.Extras extras) {
        long now = this.mClock.now();
        ImagePerfState state = obtainState();
        state.setExtraData(extras);
        state.setControllerFailureTimeMs(now);
        state.setControllerId(id);
        state.setErrorThrowable(throwable);
        updateStatus(state, 5);
        reportViewInvisible(state, now);
    }

    @Override // com.facebook.fresco.ui.common.ControllerListener2, com.facebook.fresco.ui.common.BaseControllerListener2
    public void onRelease(String id, @Nullable ControllerListener2.Extras extras) {
        long now = this.mClock.now();
        ImagePerfState state = obtainState();
        state.setExtraData(extras);
        state.setControllerId(id);
        int lastImageLoadStatus = state.getImageLoadStatus();
        if (!(lastImageLoadStatus == 3 || lastImageLoadStatus == 5 || lastImageLoadStatus == 6)) {
            state.setControllerCancelTimeMs(now);
            updateStatus(state, 4);
        }
        reportViewInvisible(state, now);
    }

    public void onImageDrawn(String id, ImageInfo info, DimensionsInfo dimensionsInfo) {
        ImagePerfState state = obtainState();
        state.setControllerId(id);
        state.setImageDrawTimeMs(this.mClock.now());
        state.setDimensionsInfo(dimensionsInfo);
        updateStatus(state, 6);
    }

    public void reportViewVisible(ImagePerfState state, long now) {
        state.setVisible(true);
        state.setVisibilityEventTimeMs(now);
        updateVisibility(state, 1);
    }

    public void resetState() {
        obtainState().reset();
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        resetState();
    }

    private void reportViewInvisible(ImagePerfState state, long time) {
        state.setVisible(false);
        state.setInvisibilityEventTimeMs(time);
        updateVisibility(state, 2);
    }

    private void updateStatus(ImagePerfState state, int imageLoadStatus) {
        if (shouldDispatchAsync()) {
            Message msg = ((Handler) Preconditions.checkNotNull(this.mHandler)).obtainMessage();
            msg.what = 1;
            msg.arg1 = imageLoadStatus;
            msg.obj = state;
            this.mHandler.sendMessage(msg);
            return;
        }
        this.mImagePerfNotifier.notifyStatusUpdated(state, imageLoadStatus);
    }

    private void updateVisibility(ImagePerfState state, int visibilityState) {
        if (shouldDispatchAsync()) {
            Message msg = ((Handler) Preconditions.checkNotNull(this.mHandler)).obtainMessage();
            msg.what = 2;
            msg.arg1 = visibilityState;
            msg.obj = state;
            this.mHandler.sendMessage(msg);
            return;
        }
        this.mImagePerfNotifier.notifyListenersOfVisibilityStateUpdate(state, visibilityState);
    }

    private synchronized void initHandler() {
        if (this.mHandler == null) {
            HandlerThread handlerThread = new HandlerThread("ImagePerfControllerListener2Thread");
            handlerThread.start();
            this.mHandler = new LogHandler((Looper) Preconditions.checkNotNull(handlerThread.getLooper()), this.mImagePerfNotifier);
        }
    }

    private boolean shouldDispatchAsync() {
        boolean enabled = this.mAsyncLogging.get().booleanValue();
        if (enabled && this.mHandler == null) {
            initHandler();
        }
        return enabled;
    }

    private ImagePerfState obtainState() {
        return this.mUseNewState.get().booleanValue() ? new ImagePerfState() : this.mImagePerfState;
    }
}
