package com.facebook.imagepipeline.cache;

import bolts.Task;
import com.facebook.binaryresource.BinaryResource;
import com.facebook.cache.common.CacheKey;
import com.facebook.cache.common.WriterCallback;
import com.facebook.cache.disk.FileCache;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import com.facebook.common.memory.PooledByteBuffer;
import com.facebook.common.memory.PooledByteBufferFactory;
import com.facebook.common.memory.PooledByteStreams;
import com.facebook.common.references.CloseableReference;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.instrumentation.FrescoInstrumenter;
import com.facebook.imagepipeline.systrace.FrescoSystrace;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.concurrent.Callable;
import java.util.concurrent.CancellationException;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicBoolean;
import javax.annotation.Nullable;

public class BufferedDiskCache {
    private static final Class<?> TAG = BufferedDiskCache.class;
    private final FileCache mFileCache;
    private final ImageCacheStatsTracker mImageCacheStatsTracker;
    private final PooledByteBufferFactory mPooledByteBufferFactory;
    private final PooledByteStreams mPooledByteStreams;
    private final Executor mReadExecutor;
    private final StagingArea mStagingArea = StagingArea.getInstance();
    private final Executor mWriteExecutor;

    public BufferedDiskCache(FileCache fileCache, PooledByteBufferFactory pooledByteBufferFactory, PooledByteStreams pooledByteStreams, Executor readExecutor, Executor writeExecutor, ImageCacheStatsTracker imageCacheStatsTracker) {
        this.mFileCache = fileCache;
        this.mPooledByteBufferFactory = pooledByteBufferFactory;
        this.mPooledByteStreams = pooledByteStreams;
        this.mReadExecutor = readExecutor;
        this.mWriteExecutor = writeExecutor;
        this.mImageCacheStatsTracker = imageCacheStatsTracker;
    }

    public boolean containsSync(CacheKey key) {
        return this.mStagingArea.containsKey(key) || this.mFileCache.hasKeySync(key);
    }

    public Task<Boolean> contains(CacheKey key) {
        if (containsSync(key)) {
            return Task.forResult(true);
        }
        return containsAsync(key);
    }

    private Task<Boolean> containsAsync(final CacheKey key) {
        try {
            final Object token = FrescoInstrumenter.onBeforeSubmitWork("BufferedDiskCache_containsAsync");
            return Task.call(new Callable<Boolean>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass1 */

                @Override // java.util.concurrent.Callable
                public Boolean call() throws Exception {
                    Object currentToken = FrescoInstrumenter.onBeginWork(token, null);
                    try {
                        Boolean valueOf = Boolean.valueOf(BufferedDiskCache.this.checkInStagingAreaAndFileCache(key));
                        FrescoInstrumenter.onEndWork(currentToken);
                        return valueOf;
                    } catch (Throwable th) {
                        FrescoInstrumenter.onEndWork(currentToken);
                        throw th;
                    }
                }
            }, this.mReadExecutor);
        } catch (Exception exception) {
            FLog.w(TAG, exception, "Failed to schedule disk-cache read for %s", key.getUriString());
            return Task.forError(exception);
        }
    }

    public boolean diskCheckSync(CacheKey key) {
        if (containsSync(key)) {
            return true;
        }
        return checkInStagingAreaAndFileCache(key);
    }

    public Task<EncodedImage> get(CacheKey key, AtomicBoolean isCancelled) {
        try {
            if (FrescoSystrace.isTracing()) {
                FrescoSystrace.beginSection("BufferedDiskCache#get");
            }
            EncodedImage pinnedImage = this.mStagingArea.get(key);
            if (pinnedImage != null) {
                return foundPinnedImage(key, pinnedImage);
            }
            Task<EncodedImage> async = getAsync(key, isCancelled);
            if (FrescoSystrace.isTracing()) {
                FrescoSystrace.endSection();
            }
            return async;
        } finally {
            if (FrescoSystrace.isTracing()) {
                FrescoSystrace.endSection();
            }
        }
    }

    public Task<Void> probe(final CacheKey key) {
        Preconditions.checkNotNull(key);
        try {
            final Object token = FrescoInstrumenter.onBeforeSubmitWork("BufferedDiskCache_probe");
            return Task.call(new Callable<Void>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass2 */

                @Override // java.util.concurrent.Callable
                public Void call() throws Exception {
                    Object currentToken = FrescoInstrumenter.onBeginWork(token, null);
                    try {
                        BufferedDiskCache.this.mFileCache.probe(key);
                        return null;
                    } finally {
                        FrescoInstrumenter.onEndWork(currentToken);
                    }
                }
            }, this.mWriteExecutor);
        } catch (Exception exception) {
            FLog.w(TAG, exception, "Failed to schedule disk-cache probe for %s", key.getUriString());
            return Task.forError(exception);
        }
    }

    public void addKeyForAsyncProbing(CacheKey key) {
        Preconditions.checkNotNull(key);
        this.mFileCache.probe(key);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean checkInStagingAreaAndFileCache(CacheKey key) {
        EncodedImage result = this.mStagingArea.get(key);
        if (result != null) {
            result.close();
            FLog.v(TAG, "Found image for %s in staging area", key.getUriString());
            this.mImageCacheStatsTracker.onStagingAreaHit(key);
            return true;
        }
        FLog.v(TAG, "Did not find image for %s in staging area", key.getUriString());
        this.mImageCacheStatsTracker.onStagingAreaMiss(key);
        try {
            return this.mFileCache.hasKey(key);
        } catch (Exception e) {
            return false;
        }
    }

    private Task<EncodedImage> getAsync(final CacheKey key, final AtomicBoolean isCancelled) {
        try {
            final Object token = FrescoInstrumenter.onBeforeSubmitWork("BufferedDiskCache_getAsync");
            return Task.call(new Callable<EncodedImage>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass3 */

                @Override // java.util.concurrent.Callable
                @Nullable
                public EncodedImage call() throws Exception {
                    Object currentToken = FrescoInstrumenter.onBeginWork(token, null);
                    try {
                        if (!isCancelled.get()) {
                            EncodedImage result = BufferedDiskCache.this.mStagingArea.get(key);
                            if (result != null) {
                                FLog.v(BufferedDiskCache.TAG, "Found image for %s in staging area", key.getUriString());
                                BufferedDiskCache.this.mImageCacheStatsTracker.onStagingAreaHit(key);
                            } else {
                                FLog.v(BufferedDiskCache.TAG, "Did not find image for %s in staging area", key.getUriString());
                                BufferedDiskCache.this.mImageCacheStatsTracker.onStagingAreaMiss(key);
                                try {
                                    PooledByteBuffer buffer = BufferedDiskCache.this.readFromDiskCache(key);
                                    if (buffer == null) {
                                        FrescoInstrumenter.onEndWork(currentToken);
                                        return null;
                                    }
                                    CloseableReference<PooledByteBuffer> ref = CloseableReference.of(buffer);
                                    try {
                                        result = new EncodedImage(ref);
                                    } finally {
                                        CloseableReference.closeSafely(ref);
                                    }
                                } catch (Exception e) {
                                    FrescoInstrumenter.onEndWork(currentToken);
                                    return null;
                                }
                            }
                            if (Thread.interrupted()) {
                                FLog.v(BufferedDiskCache.TAG, "Host thread was interrupted, decreasing reference count");
                                if (result != null) {
                                    result.close();
                                }
                                throw new InterruptedException();
                            }
                            FrescoInstrumenter.onEndWork(currentToken);
                            return result;
                        }
                        throw new CancellationException();
                    } catch (Throwable th) {
                        FrescoInstrumenter.onEndWork(currentToken);
                        throw th;
                    }
                }
            }, this.mReadExecutor);
        } catch (Exception exception) {
            FLog.w(TAG, exception, "Failed to schedule disk-cache read for %s", key.getUriString());
            return Task.forError(exception);
        }
    }

    public void put(final CacheKey key, EncodedImage encodedImage) {
        try {
            if (FrescoSystrace.isTracing()) {
                FrescoSystrace.beginSection("BufferedDiskCache#put");
            }
            Preconditions.checkNotNull(key);
            Preconditions.checkArgument(Boolean.valueOf(EncodedImage.isValid(encodedImage)));
            this.mStagingArea.put(key, encodedImage);
            final EncodedImage finalEncodedImage = EncodedImage.cloneOrNull(encodedImage);
            try {
                final Object token = FrescoInstrumenter.onBeforeSubmitWork("BufferedDiskCache_putAsync");
                this.mWriteExecutor.execute(new Runnable() {
                    /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass4 */

                    public void run() {
                        Object currentToken = FrescoInstrumenter.onBeginWork(token, null);
                        try {
                            BufferedDiskCache.this.writeToDiskCache(key, finalEncodedImage);
                            BufferedDiskCache.this.mStagingArea.remove(key, finalEncodedImage);
                            EncodedImage.closeSafely(finalEncodedImage);
                            FrescoInstrumenter.onEndWork(currentToken);
                        } catch (Throwable th) {
                            BufferedDiskCache.this.mStagingArea.remove(key, finalEncodedImage);
                            EncodedImage.closeSafely(finalEncodedImage);
                            FrescoInstrumenter.onEndWork(currentToken);
                            throw th;
                        }
                    }
                });
            } catch (Exception exception) {
                FLog.w(TAG, exception, "Failed to schedule disk-cache write for %s", key.getUriString());
                this.mStagingArea.remove(key, encodedImage);
                EncodedImage.closeSafely(finalEncodedImage);
            }
        } finally {
            if (FrescoSystrace.isTracing()) {
                FrescoSystrace.endSection();
            }
        }
    }

    public Task<Void> remove(final CacheKey key) {
        Preconditions.checkNotNull(key);
        this.mStagingArea.remove(key);
        try {
            final Object token = FrescoInstrumenter.onBeforeSubmitWork("BufferedDiskCache_remove");
            return Task.call(new Callable<Void>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass5 */

                @Override // java.util.concurrent.Callable
                public Void call() throws Exception {
                    Object currentToken = FrescoInstrumenter.onBeginWork(token, null);
                    try {
                        BufferedDiskCache.this.mStagingArea.remove(key);
                        BufferedDiskCache.this.mFileCache.remove(key);
                        FrescoInstrumenter.onEndWork(currentToken);
                        return null;
                    } catch (Throwable th) {
                        FrescoInstrumenter.onEndWork(currentToken);
                        throw th;
                    }
                }
            }, this.mWriteExecutor);
        } catch (Exception exception) {
            FLog.w(TAG, exception, "Failed to schedule disk-cache remove for %s", key.getUriString());
            return Task.forError(exception);
        }
    }

    public Task<Void> clearAll() {
        this.mStagingArea.clearAll();
        final Object token = FrescoInstrumenter.onBeforeSubmitWork("BufferedDiskCache_clearAll");
        try {
            return Task.call(new Callable<Void>() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass6 */

                @Override // java.util.concurrent.Callable
                public Void call() throws Exception {
                    Object currentToken = FrescoInstrumenter.onBeginWork(token, null);
                    try {
                        BufferedDiskCache.this.mStagingArea.clearAll();
                        BufferedDiskCache.this.mFileCache.clearAll();
                        FrescoInstrumenter.onEndWork(currentToken);
                        return null;
                    } catch (Throwable th) {
                        FrescoInstrumenter.onEndWork(currentToken);
                        throw th;
                    }
                }
            }, this.mWriteExecutor);
        } catch (Exception exception) {
            FLog.w(TAG, exception, "Failed to schedule disk-cache clear", new Object[0]);
            return Task.forError(exception);
        }
    }

    public long getSize() {
        return this.mFileCache.getSize();
    }

    private Task<EncodedImage> foundPinnedImage(CacheKey key, EncodedImage pinnedImage) {
        FLog.v(TAG, "Found image for %s in staging area", key.getUriString());
        this.mImageCacheStatsTracker.onStagingAreaHit(key);
        return Task.forResult(pinnedImage);
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @Nullable
    private PooledByteBuffer readFromDiskCache(CacheKey key) throws IOException {
        try {
            FLog.v(TAG, "Disk cache read for %s", key.getUriString());
            BinaryResource diskCacheResource = this.mFileCache.getResource(key);
            if (diskCacheResource == null) {
                FLog.v(TAG, "Disk cache miss for %s", key.getUriString());
                this.mImageCacheStatsTracker.onDiskCacheMiss(key);
                return null;
            }
            FLog.v(TAG, "Found entry in disk cache for %s", key.getUriString());
            this.mImageCacheStatsTracker.onDiskCacheHit(key);
            InputStream is = diskCacheResource.openStream();
            try {
                PooledByteBuffer byteBuffer = this.mPooledByteBufferFactory.newByteBuffer(is, (int) diskCacheResource.size());
                is.close();
                FLog.v(TAG, "Successful read from disk cache for %s", key.getUriString());
                return byteBuffer;
            } catch (Throwable th) {
                is.close();
                throw th;
            }
        } catch (IOException ioe) {
            FLog.w(TAG, ioe, "Exception reading from cache for %s", key.getUriString());
            this.mImageCacheStatsTracker.onDiskCacheGetFail(key);
            throw ioe;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void writeToDiskCache(CacheKey key, final EncodedImage encodedImage) {
        FLog.v(TAG, "About to write to disk-cache for key %s", key.getUriString());
        try {
            this.mFileCache.insert(key, new WriterCallback() {
                /* class com.facebook.imagepipeline.cache.BufferedDiskCache.AnonymousClass7 */

                @Override // com.facebook.cache.common.WriterCallback
                public void write(OutputStream os) throws IOException {
                    InputStream inputStream = encodedImage.getInputStream();
                    Preconditions.checkNotNull(inputStream);
                    BufferedDiskCache.this.mPooledByteStreams.copy(inputStream, os);
                }
            });
            this.mImageCacheStatsTracker.onDiskCachePut(key);
            FLog.v(TAG, "Successful disk-cache write for key %s", key.getUriString());
        } catch (IOException ioe) {
            FLog.w(TAG, ioe, "Failed to write to disk-cache for key %s", key.getUriString());
        }
    }
}
