package com.facebook.imagepipeline.platform;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapRegionDecoder;
import android.graphics.ColorSpace;
import android.graphics.Rect;
import android.os.Build;
import androidx.core.util.Pools;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import com.facebook.common.references.CloseableReference;
import com.facebook.common.streams.LimitedInputStream;
import com.facebook.common.streams.TailAppendingInputStream;
import com.facebook.imagepipeline.bitmaps.SimpleBitmapReleaser;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.memory.BitmapPool;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import javax.annotation.Nullable;

public abstract class DefaultDecoder implements PlatformDecoder {
    private static final int DECODE_BUFFER_SIZE = 16384;
    private static final byte[] EOI_TAIL = {-1, -39};
    private static final Class<?> TAG = DefaultDecoder.class;
    private final BitmapPool mBitmapPool;
    final Pools.SynchronizedPool<ByteBuffer> mDecodeBuffers;
    @Nullable
    private final PreverificationHelper mPreverificationHelper;

    public abstract int getBitmapSize(int i, int i2, BitmapFactory.Options options);

    public DefaultDecoder(BitmapPool bitmapPool, int maxNumThreads, Pools.SynchronizedPool decodeBuffers) {
        this.mPreverificationHelper = Build.VERSION.SDK_INT >= 26 ? new PreverificationHelper() : null;
        this.mBitmapPool = bitmapPool;
        this.mDecodeBuffers = decodeBuffers;
        for (int i = 0; i < maxNumThreads; i++) {
            this.mDecodeBuffers.release(ByteBuffer.allocate(16384));
        }
    }

    @Override // com.facebook.imagepipeline.platform.PlatformDecoder
    public CloseableReference<Bitmap> decodeFromEncodedImage(EncodedImage encodedImage, Bitmap.Config bitmapConfig, @Nullable Rect regionToDecode) {
        return decodeFromEncodedImageWithColorSpace(encodedImage, bitmapConfig, regionToDecode, null);
    }

    @Override // com.facebook.imagepipeline.platform.PlatformDecoder
    public CloseableReference<Bitmap> decodeJPEGFromEncodedImage(EncodedImage encodedImage, Bitmap.Config bitmapConfig, @Nullable Rect regionToDecode, int length) {
        return decodeJPEGFromEncodedImageWithColorSpace(encodedImage, bitmapConfig, regionToDecode, length, null);
    }

    @Override // com.facebook.imagepipeline.platform.PlatformDecoder
    public CloseableReference<Bitmap> decodeFromEncodedImageWithColorSpace(EncodedImage encodedImage, Bitmap.Config bitmapConfig, @Nullable Rect regionToDecode, @Nullable ColorSpace colorSpace) {
        BitmapFactory.Options options = getDecodeOptionsForStream(encodedImage, bitmapConfig);
        boolean retryOnFail = options.inPreferredConfig != Bitmap.Config.ARGB_8888;
        try {
            return decodeFromStream((InputStream) Preconditions.checkNotNull(encodedImage.getInputStream()), options, regionToDecode, colorSpace);
        } catch (RuntimeException re) {
            if (retryOnFail) {
                return decodeFromEncodedImageWithColorSpace(encodedImage, Bitmap.Config.ARGB_8888, regionToDecode, colorSpace);
            }
            throw re;
        }
    }

    @Override // com.facebook.imagepipeline.platform.PlatformDecoder
    public CloseableReference<Bitmap> decodeJPEGFromEncodedImageWithColorSpace(EncodedImage encodedImage, Bitmap.Config bitmapConfig, @Nullable Rect regionToDecode, int length, @Nullable ColorSpace colorSpace) {
        InputStream jpegDataStream;
        boolean isJpegComplete = encodedImage.isCompleteAt(length);
        BitmapFactory.Options options = getDecodeOptionsForStream(encodedImage, bitmapConfig);
        InputStream jpegDataStream2 = encodedImage.getInputStream();
        Preconditions.checkNotNull(jpegDataStream2);
        if (encodedImage.getSize() > length) {
            jpegDataStream2 = new LimitedInputStream(jpegDataStream2, length);
        }
        if (!isJpegComplete) {
            jpegDataStream = new TailAppendingInputStream(jpegDataStream2, EOI_TAIL);
        } else {
            jpegDataStream = jpegDataStream2;
        }
        boolean retryOnFail = options.inPreferredConfig != Bitmap.Config.ARGB_8888;
        try {
            CloseableReference<Bitmap> decodeFromStream = decodeFromStream(jpegDataStream, options, regionToDecode, colorSpace);
            try {
                jpegDataStream.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
            return decodeFromStream;
        } catch (RuntimeException re) {
            if (retryOnFail) {
                CloseableReference<Bitmap> decodeJPEGFromEncodedImageWithColorSpace = decodeJPEGFromEncodedImageWithColorSpace(encodedImage, Bitmap.Config.ARGB_8888, regionToDecode, length, colorSpace);
                try {
                    jpegDataStream.close();
                } catch (IOException e2) {
                    e2.printStackTrace();
                }
                return decodeJPEGFromEncodedImageWithColorSpace;
            }
            throw re;
        } catch (Throwable e3) {
            try {
                jpegDataStream.close();
            } catch (IOException e4) {
                e4.printStackTrace();
            }
            throw e3;
        }
    }

    /* access modifiers changed from: protected */
    public CloseableReference<Bitmap> decodeStaticImageFromStream(InputStream inputStream, BitmapFactory.Options options, @Nullable Rect regionToDecode) {
        return decodeFromStream(inputStream, options, regionToDecode, null);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00a7, code lost:
        if (r13 != null) goto L_0x00a9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:43:0x00a9, code lost:
        r13.recycle();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:0x00bb, code lost:
        if (r13 == null) goto L_0x00c5;
     */
    private CloseableReference<Bitmap> decodeFromStream(InputStream inputStream, BitmapFactory.Options options, @Nullable Rect regionToDecode, @Nullable ColorSpace colorSpace) {
        int targetHeight;
        int targetHeight2;
        Bitmap bitmapToReuse;
        ByteBuffer byteBuffer;
        Preconditions.checkNotNull(inputStream);
        int targetWidth = options.outWidth;
        int targetHeight3 = options.outHeight;
        if (regionToDecode != null) {
            int targetWidth2 = regionToDecode.width() / options.inSampleSize;
            targetHeight = regionToDecode.height() / options.inSampleSize;
            targetHeight2 = targetWidth2;
        } else {
            targetHeight = targetHeight3;
            targetHeight2 = targetWidth;
        }
        boolean shouldUseHardwareBitmapConfig = false;
        if (Build.VERSION.SDK_INT >= 26) {
            PreverificationHelper preverificationHelper = this.mPreverificationHelper;
            shouldUseHardwareBitmapConfig = preverificationHelper != null && preverificationHelper.shouldUseHardwareBitmapConfig(options.inPreferredConfig);
        }
        if (regionToDecode != null || !shouldUseHardwareBitmapConfig) {
            if (regionToDecode != null && shouldUseHardwareBitmapConfig) {
                options.inPreferredConfig = Bitmap.Config.ARGB_8888;
            }
            Bitmap bitmapToReuse2 = (Bitmap) this.mBitmapPool.get(getBitmapSize(targetHeight2, targetHeight, options));
            if (bitmapToReuse2 != null) {
                bitmapToReuse = bitmapToReuse2;
            } else {
                throw new NullPointerException("BitmapPool.get returned null");
            }
        } else {
            options.inMutable = false;
            bitmapToReuse = null;
        }
        options.inBitmap = bitmapToReuse;
        if (Build.VERSION.SDK_INT >= 26) {
            options.inPreferredColorSpace = colorSpace == null ? ColorSpace.get(ColorSpace.Named.SRGB) : colorSpace;
        }
        Bitmap decodedBitmap = null;
        ByteBuffer byteBuffer2 = this.mDecodeBuffers.acquire();
        if (byteBuffer2 == null) {
            byteBuffer = ByteBuffer.allocate(16384);
        } else {
            byteBuffer = byteBuffer2;
        }
        try {
            options.inTempStorage = byteBuffer.array();
            if (!(Build.VERSION.SDK_INT < 19 || regionToDecode == null || bitmapToReuse == null)) {
                BitmapRegionDecoder bitmapRegionDecoder = null;
                try {
                    bitmapToReuse.reconfigure(targetHeight2, targetHeight, options.inPreferredConfig);
                    bitmapRegionDecoder = BitmapRegionDecoder.newInstance(inputStream, true);
                    decodedBitmap = bitmapRegionDecoder.decodeRegion(regionToDecode, options);
                } catch (IOException e) {
                    FLog.e(TAG, "Could not decode region %s, decoding full bitmap instead.", regionToDecode);
                } catch (Throwable th) {
                    if (bitmapRegionDecoder != null) {
                        bitmapRegionDecoder.recycle();
                    }
                    throw th;
                }
            }
            if (decodedBitmap == null) {
                decodedBitmap = BitmapFactory.decodeStream(inputStream, null, options);
            }
            this.mDecodeBuffers.release(byteBuffer);
            if (bitmapToReuse == null || bitmapToReuse == decodedBitmap) {
                return CloseableReference.of(decodedBitmap, this.mBitmapPool);
            }
            this.mBitmapPool.release(bitmapToReuse);
            decodedBitmap.recycle();
            throw new IllegalStateException();
        } catch (IllegalArgumentException e2) {
            if (bitmapToReuse != null) {
                this.mBitmapPool.release(bitmapToReuse);
            }
            try {
                inputStream.reset();
                Bitmap naiveDecodedBitmap = BitmapFactory.decodeStream(inputStream);
                if (naiveDecodedBitmap != null) {
                    CloseableReference<Bitmap> of = CloseableReference.of(naiveDecodedBitmap, SimpleBitmapReleaser.getInstance());
                    this.mDecodeBuffers.release(byteBuffer);
                    return of;
                }
                throw e2;
            } catch (IOException e3) {
                throw e2;
            }
        } catch (RuntimeException re) {
            if (bitmapToReuse != null) {
                this.mBitmapPool.release(bitmapToReuse);
            }
            throw re;
        } catch (Throwable th2) {
            this.mDecodeBuffers.release(byteBuffer);
            throw th2;
        }
    }

    private static BitmapFactory.Options getDecodeOptionsForStream(EncodedImage encodedImage, Bitmap.Config bitmapConfig) {
        BitmapFactory.Options options = new BitmapFactory.Options();
        options.inSampleSize = encodedImage.getSampleSize();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeStream(encodedImage.getInputStream(), null, options);
        if (options.outWidth == -1 || options.outHeight == -1) {
            throw new IllegalArgumentException();
        }
        options.inJustDecodeBounds = false;
        options.inDither = true;
        options.inPreferredConfig = bitmapConfig;
        options.inMutable = true;
        return options;
    }
}
