package com.facebook.soloader;

import android.content.Context;
import android.os.Parcel;
import android.os.StrictMode;
import android.util.Log;
import java.io.Closeable;
import java.io.DataInput;
import java.io.DataOutput;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.Nullable;

public abstract class UnpackingSoSource extends DirectorySoSource {
    private static final String DEPS_FILE_NAME = "dso_deps";
    private static final String LOCK_FILE_NAME = "dso_lock";
    private static final String MANIFEST_FILE_NAME = "dso_manifest";
    private static final byte MANIFEST_VERSION = 1;
    private static final byte STATE_CLEAN = 1;
    private static final byte STATE_DIRTY = 0;
    private static final String STATE_FILE_NAME = "dso_state";
    private static final String TAG = "fb-UnpackingSoSource";
    @Nullable
    private String[] mAbis;
    protected final Context mContext;
    @Nullable
    protected String mCorruptedLib;
    private final Map<String, Object> mLibsBeingLoaded = new HashMap();

    /* access modifiers changed from: protected */
    public abstract Unpacker makeUnpacker() throws IOException;

    protected UnpackingSoSource(Context context, String name) {
        super(getSoStorePath(context, name), 1);
        this.mContext = context;
    }

    protected UnpackingSoSource(Context context, File storePath) {
        super(storePath, 1);
        this.mContext = context;
    }

    public static File getSoStorePath(Context context, String name) {
        return new File(context.getApplicationInfo().dataDir + "/" + name);
    }

    @Override // com.facebook.soloader.SoSource
    public String[] getSoSourceAbis() {
        String[] strArr = this.mAbis;
        if (strArr == null) {
            return super.getSoSourceAbis();
        }
        return strArr;
    }

    public void setSoSourceAbis(String[] abis) {
        this.mAbis = abis;
    }

    public static class Dso {
        public final String hash;
        public final String name;

        public Dso(String name2, String hash2) {
            this.name = name2;
            this.hash = hash2;
        }
    }

    public static final class DsoManifest {
        public final Dso[] dsos;

        public DsoManifest(Dso[] dsos2) {
            this.dsos = dsos2;
        }

        static final DsoManifest read(DataInput xdi) throws IOException {
            if (xdi.readByte() == 1) {
                int nrDso = xdi.readInt();
                if (nrDso >= 0) {
                    Dso[] dsos2 = new Dso[nrDso];
                    for (int i = 0; i < nrDso; i++) {
                        dsos2[i] = new Dso(xdi.readUTF(), xdi.readUTF());
                    }
                    return new DsoManifest(dsos2);
                }
                throw new RuntimeException("illegal number of shared libraries");
            }
            throw new RuntimeException("wrong dso manifest version");
        }

        public final void write(DataOutput xdo) throws IOException {
            xdo.writeByte(1);
            xdo.writeInt(this.dsos.length);
            int i = 0;
            while (true) {
                Dso[] dsoArr = this.dsos;
                if (i < dsoArr.length) {
                    xdo.writeUTF(dsoArr[i].name);
                    xdo.writeUTF(this.dsos[i].hash);
                    i++;
                } else {
                    return;
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public static final class InputDso implements Closeable {
        public final InputStream content;
        public final Dso dso;

        public InputDso(Dso dso2, InputStream content2) {
            this.dso = dso2;
            this.content = content2;
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
            this.content.close();
        }
    }

    /* access modifiers changed from: protected */
    public static abstract class InputDsoIterator implements Closeable {
        public abstract boolean hasNext();

        public abstract InputDso next() throws IOException;

        protected InputDsoIterator() {
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
        }
    }

    /* access modifiers changed from: protected */
    public static abstract class Unpacker implements Closeable {
        /* access modifiers changed from: protected */
        public abstract DsoManifest getDsoManifest() throws IOException;

        /* access modifiers changed from: protected */
        public abstract InputDsoIterator openDsoIterator() throws IOException;

        protected Unpacker() {
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() throws IOException {
        }
    }

    /* access modifiers changed from: private */
    /* JADX WARNING: Code restructure failed: missing block: B:10:?, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0028, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0029, code lost:
        r1.addSuppressed(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x002c, code lost:
        throw r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:8:0x0023, code lost:
        r2 = move-exception;
     */
    public static void writeState(File stateFileName, byte state) throws IOException {
        RandomAccessFile stateFile = new RandomAccessFile(stateFileName, "rw");
        stateFile.seek(0);
        stateFile.write(state);
        stateFile.setLength(stateFile.getFilePointer());
        stateFile.getFD().sync();
        stateFile.close();
    }

    private void deleteUnmentionedFiles(Dso[] dsos) throws IOException {
        String[] existingFiles = this.soDirectory.list();
        if (existingFiles != null) {
            for (String fileName : existingFiles) {
                if (!fileName.equals(STATE_FILE_NAME) && !fileName.equals(LOCK_FILE_NAME) && !fileName.equals(DEPS_FILE_NAME) && !fileName.equals(MANIFEST_FILE_NAME)) {
                    boolean found = false;
                    int j = 0;
                    while (!found && j < dsos.length) {
                        if (dsos[j].name.equals(fileName)) {
                            found = true;
                        }
                        j++;
                    }
                    if (!found) {
                        File fileNameToDelete = new File(this.soDirectory, fileName);
                        Log.v(TAG, "deleting unaccounted-for file " + fileNameToDelete);
                        SysUtil.dumbDeleteRecursive(fileNameToDelete);
                    }
                }
            }
            return;
        }
        throw new IOException("unable to list directory " + this.soDirectory);
    }

    private void extractDso(InputDso iDso, byte[] ioBuffer) throws IOException {
        boolean writable;
        Log.i(TAG, "extracting DSO " + iDso.dso.name);
        try {
            if (this.soDirectory.setWritable(true)) {
                extractDsoImpl(iDso, ioBuffer);
                if (writable) {
                    return;
                }
                return;
            }
            throw new IOException("cannot make directory writable for us: " + this.soDirectory);
        } finally {
            if (!this.soDirectory.setWritable(false)) {
                Log.w(TAG, "error removing " + this.soDirectory.getCanonicalPath() + " write permission");
            }
        }
    }

    private void extractDsoImpl(InputDso iDso, byte[] ioBuffer) throws IOException {
        RandomAccessFile dsoFile;
        File dsoFileName = new File(this.soDirectory, iDso.dso.name);
        RandomAccessFile dsoFile2 = null;
        try {
            if (dsoFileName.exists() && !dsoFileName.setWritable(true)) {
                Log.w(TAG, "error adding write permission to: " + dsoFileName);
            }
            try {
                dsoFile = new RandomAccessFile(dsoFileName, "rw");
            } catch (IOException ex) {
                Log.w(TAG, "error overwriting " + dsoFileName + " trying to delete and start over", ex);
                SysUtil.dumbDeleteRecursive(dsoFileName);
                dsoFile = new RandomAccessFile(dsoFileName, "rw");
            }
            int sizeHint = iDso.content.available();
            if (sizeHint > 1) {
                SysUtil.fallocateIfSupported(dsoFile.getFD(), (long) sizeHint);
            }
            SysUtil.copyBytes(dsoFile, iDso.content, Integer.MAX_VALUE, ioBuffer);
            dsoFile.setLength(dsoFile.getFilePointer());
            if (dsoFileName.setExecutable(true, false)) {
                if (!dsoFileName.setWritable(false)) {
                    Log.w(TAG, "error removing " + dsoFileName + " write permission");
                }
                dsoFile.close();
                return;
            }
            throw new IOException("cannot make file executable: " + dsoFileName);
        } catch (IOException e) {
            SysUtil.dumbDeleteRecursive(dsoFileName);
            throw e;
        } catch (Throwable th) {
            if (!dsoFileName.setWritable(false)) {
                Log.w(TAG, "error removing " + dsoFileName + " write permission");
            }
            if (0 != 0) {
                dsoFile2.close();
            }
            throw th;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:46:0x00c9, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:?, code lost:
        r2.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:0x00ce, code lost:
        r4 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:50:0x00cf, code lost:
        r1.addSuppressed(r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:51:0x00d2, code lost:
        throw r3;
     */
    private void regenerate(byte state, DsoManifest desiredManifest, InputDsoIterator dsoIterator) throws IOException {
        Log.v(TAG, "regenerating DSO store " + getClass().getName());
        RandomAccessFile manifestFile = new RandomAccessFile(new File(this.soDirectory, MANIFEST_FILE_NAME), "rw");
        DsoManifest existingManifest = null;
        if (state == 1) {
            try {
                existingManifest = DsoManifest.read(manifestFile);
            } catch (Exception ex) {
                Log.i(TAG, "error reading existing DSO manifest", ex);
            }
        }
        if (existingManifest == null) {
            existingManifest = new DsoManifest(new Dso[0]);
        }
        deleteUnmentionedFiles(desiredManifest.dsos);
        byte[] ioBuffer = new byte[32768];
        while (dsoIterator.hasNext()) {
            InputDso iDso = dsoIterator.next();
            boolean obsolete = true;
            int i = 0;
            while (obsolete) {
                try {
                    if (i >= existingManifest.dsos.length) {
                        break;
                    }
                    if (existingManifest.dsos[i].name.equals(iDso.dso.name) && existingManifest.dsos[i].hash.equals(iDso.dso.hash)) {
                        obsolete = false;
                    }
                    i++;
                } catch (Throwable th) {
                    if (iDso != null) {
                        try {
                            iDso.close();
                        } catch (Throwable th2) {
                            th.addSuppressed(th2);
                        }
                    }
                    throw th;
                }
            }
            if (obsolete) {
                extractDso(iDso, ioBuffer);
            }
            if (iDso != null) {
                iDso.close();
            }
        }
        manifestFile.close();
        Log.v(TAG, "Finished regenerating DSO store " + getClass().getName());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x003d, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:?, code lost:
        r0.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0043, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0044, code lost:
        r0.addSuppressed(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0048, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x004a, code lost:
        r4 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x00f1, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x00f3, code lost:
        if (r4 != null) goto L_0x00f5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:66:?, code lost:
        r4.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:67:0x00f9, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:68:0x00fa, code lost:
        r0.addSuppressed(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:69:0x00fe, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:0x0102, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x0104, code lost:
        if (r1 != null) goto L_0x0106;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:78:?, code lost:
        r1.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:79:0x010a, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:80:0x010b, code lost:
        r0.addSuppressed(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:81:0x010f, code lost:
        throw r0;
     */
    private boolean refreshLocked(final FileLocker lock, int flags, final byte[] deps) throws IOException {
        Throwable th;
        Throwable th2;
        byte state;
        final DsoManifest desiredManifest;
        final File stateFileName = new File(this.soDirectory, STATE_FILE_NAME);
        RandomAccessFile stateFile = new RandomAccessFile(stateFileName, "rw");
        byte state2 = stateFile.readByte();
        if (state2 != 1) {
            Log.v(TAG, "dso store " + this.soDirectory + " regeneration interrupted: wiping clean");
            state2 = 0;
        }
        byte state3 = state2;
        stateFile.close();
        final File depsFileName = new File(this.soDirectory, DEPS_FILE_NAME);
        RandomAccessFile depsFile = new RandomAccessFile(depsFileName, "rw");
        try {
            byte[] existingDeps = new byte[((int) depsFile.length())];
            if (depsFile.read(existingDeps) != existingDeps.length) {
                Log.v(TAG, "short read of so store deps file: marking unclean");
                state3 = 0;
            }
            try {
                if (!Arrays.equals(existingDeps, deps)) {
                    Log.v(TAG, "deps mismatch on deps store: regenerating");
                    state = 0;
                } else {
                    state = state3;
                }
                if (state == 0 || (flags & 2) != 0) {
                    try {
                        Log.v(TAG, "so store dirty: regenerating");
                        writeState(stateFileName, (byte) 0);
                        Unpacker u = makeUnpacker();
                        DsoManifest desiredManifest2 = u.getDsoManifest();
                        InputDsoIterator idi = u.openDsoIterator();
                        regenerate(state, desiredManifest2, idi);
                        if (idi != null) {
                            idi.close();
                        }
                        if (u != null) {
                            u.close();
                        }
                        desiredManifest = desiredManifest2;
                    } catch (Throwable th3) {
                        th = th3;
                        try {
                            throw th;
                        } catch (Throwable th4) {
                            th.addSuppressed(th4);
                        }
                    }
                } else {
                    desiredManifest = null;
                }
                depsFile.close();
                if (desiredManifest == null) {
                    return false;
                }
                Runnable syncer = new Runnable() {
                    /* class com.facebook.soloader.UnpackingSoSource.AnonymousClass1 */

                    /* JADX WARNING: Code restructure failed: missing block: B:15:0x006c, code lost:
                        r6 = move-exception;
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:17:?, code lost:
                        r5.close();
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0071, code lost:
                        r7 = move-exception;
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0072, code lost:
                        r5.addSuppressed(r7);
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0075, code lost:
                        throw r6;
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0078, code lost:
                        r5 = move-exception;
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:26:?, code lost:
                        r4.close();
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:27:0x007d, code lost:
                        r6 = move-exception;
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:28:0x007e, code lost:
                        r2.addSuppressed(r6);
                     */
                    /* JADX WARNING: Code restructure failed: missing block: B:29:0x0081, code lost:
                        throw r5;
                     */
                    public void run() {
                        try {
                            Log.v(UnpackingSoSource.TAG, "starting syncer worker");
                            RandomAccessFile depsFile = new RandomAccessFile(depsFileName, "rw");
                            depsFile.write(deps);
                            depsFile.setLength(depsFile.getFilePointer());
                            depsFile.close();
                            RandomAccessFile manifestFile = new RandomAccessFile(new File(UnpackingSoSource.this.soDirectory, UnpackingSoSource.MANIFEST_FILE_NAME), "rw");
                            desiredManifest.write(manifestFile);
                            manifestFile.close();
                            SysUtil.fsyncRecursive(UnpackingSoSource.this.soDirectory);
                            UnpackingSoSource.writeState(stateFileName, (byte) 1);
                            try {
                            } catch (IOException ex) {
                                throw new RuntimeException(ex);
                            }
                        } finally {
                            Log.v(UnpackingSoSource.TAG, "releasing dso store lock for " + UnpackingSoSource.this.soDirectory + " (from syncer thread)");
                            lock.close();
                        }
                    }
                };
                if ((flags & 1) != 0) {
                    new Thread(syncer, "SoSync:" + this.soDirectory.getName()).start();
                } else {
                    syncer.run();
                }
                return true;
            } catch (Throwable th5) {
                th2 = th5;
                th = th2;
                throw th;
            }
        } catch (Throwable th6) {
            th2 = th6;
            th = th2;
            throw th;
        }
        throw th;
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x003a, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x003b, code lost:
        if (r1 != null) goto L_0x003d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:?, code lost:
        r1.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0041, code lost:
        r4 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0042, code lost:
        r2.addSuppressed(r4);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0045, code lost:
        throw r3;
     */
    public byte[] getDepsBlock() throws IOException {
        Parcel parcel = Parcel.obtain();
        Unpacker u = makeUnpacker();
        Dso[] dsos = u.getDsoManifest().dsos;
        parcel.writeByte((byte) 1);
        parcel.writeInt(dsos.length);
        for (int i = 0; i < dsos.length; i++) {
            parcel.writeString(dsos[i].name);
            parcel.writeString(dsos[i].hash);
        }
        if (u != null) {
            u.close();
        }
        byte[] depsBlock = parcel.marshall();
        parcel.recycle();
        return depsBlock;
    }

    /* access modifiers changed from: protected */
    @Override // com.facebook.soloader.SoSource
    public void prepare(int flags) throws IOException {
        SysUtil.mkdirOrThrow(this.soDirectory);
        FileLocker lock = FileLocker.lock(new File(this.soDirectory, LOCK_FILE_NAME));
        try {
            Log.v(TAG, "locked dso store " + this.soDirectory);
            if (refreshLocked(lock, flags, getDepsBlock())) {
                lock = null;
            } else {
                Log.i(TAG, "dso store is up-to-date: " + this.soDirectory);
            }
            if (lock == null) {
                Log.v(TAG, "not releasing dso store lock for " + this.soDirectory + " (syncer thread started)");
            }
        } finally {
            if (lock != null) {
                Log.v(TAG, "releasing dso store lock for " + this.soDirectory);
                lock.close();
            } else {
                Log.v(TAG, "not releasing dso store lock for " + this.soDirectory + " (syncer thread started)");
            }
        }
    }

    private Object getLibraryLock(String soName) {
        Object lock;
        synchronized (this.mLibsBeingLoaded) {
            lock = this.mLibsBeingLoaded.get(soName);
            if (lock == null) {
                lock = new Object();
                this.mLibsBeingLoaded.put(soName, lock);
            }
        }
        return lock;
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0012, code lost:
        r1 = th;
     */
    public synchronized void prepare(String soName) throws IOException {
        synchronized (getLibraryLock(soName)) {
            this.mCorruptedLib = soName;
            prepare(2);
        }
        return;
        while (true) {
        }
    }

    @Override // com.facebook.soloader.DirectorySoSource, com.facebook.soloader.SoSource
    public int loadLibrary(String soName, int loadFlags, StrictMode.ThreadPolicy threadPolicy) throws IOException {
        int loadLibraryFrom;
        synchronized (getLibraryLock(soName)) {
            loadLibraryFrom = loadLibraryFrom(soName, loadFlags, this.soDirectory, threadPolicy);
        }
        return loadLibraryFrom;
    }
}
