package com.github.faucamp.simplertmp;

import android.os.Handler;
import android.os.Message;
import java.io.IOException;
import java.lang.ref.WeakReference;
import java.net.SocketException;

public class RtmpHandler extends Handler {
    private static final int MSG_RTMP_AUDIO_BITRATE_CHANGED = 8;
    private static final int MSG_RTMP_AUDIO_STREAMING = 3;
    private static final int MSG_RTMP_CONNECTED = 1;
    private static final int MSG_RTMP_CONNECTING = 0;
    private static final int MSG_RTMP_DISCONNECTED = 5;
    private static final int MSG_RTMP_ILLEGAL_ARGUMENT_EXCEPTION = 11;
    private static final int MSG_RTMP_ILLEGAL_STATE_EXCEPTION = 12;
    private static final int MSG_RTMP_IO_EXCEPTION = 10;
    private static final int MSG_RTMP_SOCKET_EXCEPTION = 9;
    private static final int MSG_RTMP_STOPPED = 4;
    private static final int MSG_RTMP_VIDEO_BITRATE_CHANGED = 7;
    private static final int MSG_RTMP_VIDEO_FPS_CHANGED = 6;
    private static final int MSG_RTMP_VIDEO_STREAMING = 2;
    private WeakReference<RtmpListener> mWeakListener;

    public interface RtmpListener {
        void onRtmpAudioBitrateChanged(double d);

        void onRtmpAudioStreaming();

        void onRtmpConnected(String str);

        void onRtmpConnecting(String str);

        void onRtmpDisconnected();

        void onRtmpIOException(IOException iOException);

        void onRtmpIllegalArgumentException(IllegalArgumentException illegalArgumentException);

        void onRtmpIllegalStateException(IllegalStateException illegalStateException);

        void onRtmpSocketException(SocketException socketException);

        void onRtmpStopped();

        void onRtmpVideoBitrateChanged(double d);

        void onRtmpVideoFpsChanged(double d);

        void onRtmpVideoStreaming();
    }

    public RtmpHandler(RtmpListener listener) {
        this.mWeakListener = new WeakReference<>(listener);
    }

    public void notifyRtmpConnecting(String msg) {
        obtainMessage(0, msg).sendToTarget();
    }

    public void notifyRtmpConnected(String msg) {
        obtainMessage(1, msg).sendToTarget();
    }

    public void notifyRtmpVideoStreaming() {
        sendEmptyMessage(2);
    }

    public void notifyRtmpAudioStreaming() {
        sendEmptyMessage(3);
    }

    public void notifyRtmpStopped() {
        sendEmptyMessage(4);
    }

    public void notifyRtmpDisconnected() {
        sendEmptyMessage(5);
    }

    public void notifyRtmpVideoFpsChanged(double fps) {
        obtainMessage(6, Double.valueOf(fps)).sendToTarget();
    }

    public void notifyRtmpVideoBitrateChanged(double bitrate) {
        obtainMessage(7, Double.valueOf(bitrate)).sendToTarget();
    }

    public void notifyRtmpAudioBitrateChanged(double bitrate) {
        obtainMessage(8, Double.valueOf(bitrate)).sendToTarget();
    }

    public void notifyRtmpSocketException(SocketException e) {
        obtainMessage(9, e).sendToTarget();
    }

    public void notifyRtmpIOException(IOException e) {
        obtainMessage(10, e).sendToTarget();
    }

    public void notifyRtmpIllegalArgumentException(IllegalArgumentException e) {
        obtainMessage(11, e).sendToTarget();
    }

    public void notifyRtmpIllegalStateException(IllegalStateException e) {
        obtainMessage(12, e).sendToTarget();
    }

    public void handleMessage(Message msg) {
        RtmpListener listener = this.mWeakListener.get();
        if (listener != null) {
            switch (msg.what) {
                case 0:
                    listener.onRtmpConnecting((String) msg.obj);
                    return;
                case 1:
                    listener.onRtmpConnected((String) msg.obj);
                    return;
                case 2:
                    listener.onRtmpVideoStreaming();
                    return;
                case 3:
                    listener.onRtmpAudioStreaming();
                    return;
                case 4:
                    listener.onRtmpStopped();
                    return;
                case 5:
                    listener.onRtmpDisconnected();
                    return;
                case 6:
                    listener.onRtmpVideoFpsChanged(((Double) msg.obj).doubleValue());
                    return;
                case 7:
                    listener.onRtmpVideoBitrateChanged(((Double) msg.obj).doubleValue());
                    return;
                case 8:
                    listener.onRtmpAudioBitrateChanged(((Double) msg.obj).doubleValue());
                    return;
                case 9:
                    listener.onRtmpSocketException((SocketException) msg.obj);
                    return;
                case 10:
                    listener.onRtmpIOException((IOException) msg.obj);
                    return;
                case 11:
                    listener.onRtmpIllegalArgumentException((IllegalArgumentException) msg.obj);
                    return;
                case 12:
                    listener.onRtmpIllegalStateException((IllegalStateException) msg.obj);
                    return;
                default:
                    throw new RuntimeException("unknown msg " + msg.what);
            }
        }
    }
}
