package com.github.faucamp.simplertmp.io;

import android.util.Log;
import com.github.faucamp.simplertmp.RtmpHandler;
import com.github.faucamp.simplertmp.RtmpPublisher;
import com.github.faucamp.simplertmp.amf.AmfMap;
import com.github.faucamp.simplertmp.amf.AmfNull;
import com.github.faucamp.simplertmp.amf.AmfNumber;
import com.github.faucamp.simplertmp.amf.AmfObject;
import com.github.faucamp.simplertmp.amf.AmfString;
import com.github.faucamp.simplertmp.packets.Abort;
import com.github.faucamp.simplertmp.packets.Audio;
import com.github.faucamp.simplertmp.packets.Command;
import com.github.faucamp.simplertmp.packets.Data;
import com.github.faucamp.simplertmp.packets.Handshake;
import com.github.faucamp.simplertmp.packets.RtmpHeader;
import com.github.faucamp.simplertmp.packets.RtmpPacket;
import com.github.faucamp.simplertmp.packets.SetPeerBandwidth;
import com.github.faucamp.simplertmp.packets.UserControl;
import com.github.faucamp.simplertmp.packets.Video;
import com.github.faucamp.simplertmp.packets.WindowAckSize;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.net.SocketException;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class RtmpConnection implements RtmpPublisher {
    private static final String TAG = "RtmpConnection";
    private static final Pattern rtmpUrlPattern = Pattern.compile("^rtmp://([^/:]+)(:(\\d+))*/([^/]+)(/(.*))*$");
    private String appName;
    private int audioDataLength;
    private int audioFrameCount;
    private long audioLastTimeMillis;
    private volatile boolean connected = false;
    private final Object connectingLock = new Object();
    private int currentStreamId = 0;
    private String host;
    private BufferedInputStream inputStream;
    private RtmpHandler mHandler;
    private BufferedOutputStream outputStream;
    private String pageUrl;
    private int port;
    private final Object publishLock = new Object();
    private volatile boolean publishPermitted = false;
    private String publishType;
    private RtmpDecoder rtmpDecoder;
    private RtmpSessionInfo rtmpSessionInfo;
    private Thread rxPacketHandler;
    private AmfString serverId;
    private AmfString serverIpAddr;
    private AmfNumber serverPid;
    private Socket socket;
    private String socketExceptionCause = "";
    private String srsServerInfo = "";
    private String streamName;
    private String swfUrl;
    private String tcUrl;
    private int transactionIdCounter = 0;
    private int videoDataLength;
    private AtomicInteger videoFrameCacheNumber = new AtomicInteger(0);
    private int videoFrameCount;
    private int videoHeight;
    private long videoLastTimeMillis;
    private int videoWidth;

    public RtmpConnection(RtmpHandler handler) {
        this.mHandler = handler;
    }

    private void handshake(InputStream in, OutputStream out) throws IOException {
        Handshake handshake = new Handshake();
        handshake.writeC0(out);
        handshake.writeC1(out);
        out.flush();
        handshake.readS0(in);
        handshake.readS1(in);
        handshake.writeC2(out);
        out.flush();
        handshake.readS2(in);
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public boolean connect(String url) {
        Matcher matcher = rtmpUrlPattern.matcher(url);
        if (matcher.matches()) {
            this.tcUrl = url.substring(0, url.lastIndexOf(47));
            this.swfUrl = "";
            this.pageUrl = "";
            this.host = matcher.group(1);
            String portStr = matcher.group(3);
            this.port = portStr != null ? Integer.parseInt(portStr) : 1935;
            this.appName = matcher.group(4);
            String group = matcher.group(6);
            this.streamName = group;
            if (this.appName == null || group == null) {
                this.mHandler.notifyRtmpIllegalArgumentException(new IllegalArgumentException("Invalid RTMP URL. Must be in format: rtmp://host[:port]/application/streamName"));
                return false;
            }
            Log.d(TAG, "connect() called. Host: " + this.host + ", port: " + this.port + ", appName: " + this.appName + ", publishPath: " + this.streamName);
            RtmpSessionInfo rtmpSessionInfo2 = new RtmpSessionInfo();
            this.rtmpSessionInfo = rtmpSessionInfo2;
            this.rtmpDecoder = new RtmpDecoder(rtmpSessionInfo2);
            this.socket = new Socket();
            try {
                this.socket.connect(new InetSocketAddress(this.host, this.port), 3000);
                this.inputStream = new BufferedInputStream(this.socket.getInputStream(), 1024);
                this.outputStream = new BufferedOutputStream(this.socket.getOutputStream(), 1024);
                Log.d(TAG, "connect(): socket connection established, doing handhake...");
                handshake(this.inputStream, this.outputStream);
                Log.d(TAG, "connect(): handshake done");
                Thread thread = new Thread(new Runnable() {
                    /* class com.github.faucamp.simplertmp.io.RtmpConnection.AnonymousClass1 */

                    public void run() {
                        try {
                            Log.d(RtmpConnection.TAG, "starting main rx handler loop");
                            RtmpConnection.this.handleRxPacketLoop();
                        } catch (IOException ex) {
                            Logger.getLogger(RtmpConnection.class.getName()).log(Level.SEVERE, (String) null, (Throwable) ex);
                        }
                    }
                });
                this.rxPacketHandler = thread;
                thread.start();
                return rtmpConnect();
            } catch (IOException e) {
                e.printStackTrace();
                this.mHandler.notifyRtmpIOException(e);
                return false;
            }
        } else {
            this.mHandler.notifyRtmpIllegalArgumentException(new IllegalArgumentException("Invalid RTMP URL. Must be in format: rtmp://host[:port]/application/streamName"));
            return false;
        }
    }

    private boolean rtmpConnect() {
        if (this.connected) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Already connected to RTMP server"));
            return false;
        }
        ChunkStreamInfo.markSessionTimestampTx();
        Log.d(TAG, "rtmpConnect(): Building 'connect' invoke packet");
        ChunkStreamInfo chunkStreamInfo = this.rtmpSessionInfo.getChunkStreamInfo(3);
        int i = this.transactionIdCounter + 1;
        this.transactionIdCounter = i;
        Command invoke = new Command("connect", i, chunkStreamInfo);
        invoke.getHeader().setMessageStreamId(0);
        AmfObject args = new AmfObject();
        args.setProperty("app", this.appName);
        args.setProperty("flashVer", "LNX 11,2,202,233");
        args.setProperty("swfUrl", this.swfUrl);
        args.setProperty("tcUrl", this.tcUrl);
        args.setProperty("fpad", false);
        args.setProperty("capabilities", 239);
        args.setProperty("audioCodecs", 3575);
        args.setProperty("videoCodecs", 252);
        args.setProperty("videoFunction", 1);
        args.setProperty("pageUrl", this.pageUrl);
        args.setProperty("objectEncoding", 0);
        invoke.addData(args);
        sendRtmpPacket(invoke);
        this.mHandler.notifyRtmpConnecting("Connecting");
        synchronized (this.connectingLock) {
            try {
                this.connectingLock.wait(5000);
            } catch (InterruptedException e) {
            }
        }
        if (!this.connected) {
            shutdown();
        }
        return this.connected;
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public boolean publish(String type) {
        if (type == null) {
            this.mHandler.notifyRtmpIllegalArgumentException(new IllegalArgumentException("No publish type specified"));
            return false;
        }
        this.publishType = type;
        return createStream();
    }

    private boolean createStream() {
        if (!this.connected) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not connected to RTMP server"));
            return false;
        } else if (this.currentStreamId != 0) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Current stream object has existed"));
            return false;
        } else {
            Log.d(TAG, "createStream(): Sending releaseStream command...");
            int i = this.transactionIdCounter + 1;
            this.transactionIdCounter = i;
            Command releaseStream = new Command("releaseStream", i);
            releaseStream.getHeader().setChunkStreamId(5);
            releaseStream.addData(new AmfNull());
            releaseStream.addData(this.streamName);
            sendRtmpPacket(releaseStream);
            Log.d(TAG, "createStream(): Sending FCPublish command...");
            int i2 = this.transactionIdCounter + 1;
            this.transactionIdCounter = i2;
            Command FCPublish = new Command("FCPublish", i2);
            FCPublish.getHeader().setChunkStreamId(5);
            FCPublish.addData(new AmfNull());
            FCPublish.addData(this.streamName);
            sendRtmpPacket(FCPublish);
            Log.d(TAG, "createStream(): Sending createStream command...");
            ChunkStreamInfo chunkStreamInfo = this.rtmpSessionInfo.getChunkStreamInfo(3);
            int i3 = this.transactionIdCounter + 1;
            this.transactionIdCounter = i3;
            Command createStream = new Command("createStream", i3, chunkStreamInfo);
            createStream.addData(new AmfNull());
            sendRtmpPacket(createStream);
            synchronized (this.publishLock) {
                try {
                    this.publishLock.wait(5000);
                } catch (InterruptedException e) {
                }
            }
            if (this.publishPermitted) {
                RtmpHandler rtmpHandler = this.mHandler;
                rtmpHandler.notifyRtmpConnected("Connected" + this.srsServerInfo);
            } else {
                shutdown();
            }
            return this.publishPermitted;
        }
    }

    private void fmlePublish() {
        if (!this.connected) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not connected to RTMP server"));
        } else if (this.currentStreamId == 0) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("No current stream object exists"));
        } else {
            Log.d(TAG, "fmlePublish(): Sending publish command...");
            Command publish = new Command("publish", 0);
            publish.getHeader().setChunkStreamId(5);
            publish.getHeader().setMessageStreamId(this.currentStreamId);
            publish.addData(new AmfNull());
            publish.addData(this.streamName);
            publish.addData(this.publishType);
            sendRtmpPacket(publish);
        }
    }

    private void onMetaData() {
        if (!this.connected) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not connected to RTMP server"));
        } else if (this.currentStreamId == 0) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("No current stream object exists"));
        } else {
            Log.d(TAG, "onMetaData(): Sending empty onMetaData...");
            Data metadata = new Data("@setDataFrame");
            metadata.getHeader().setMessageStreamId(this.currentStreamId);
            metadata.addData("onMetaData");
            AmfMap ecmaArray = new AmfMap();
            ecmaArray.setProperty("duration", 0);
            ecmaArray.setProperty("width", this.videoWidth);
            ecmaArray.setProperty("height", this.videoHeight);
            ecmaArray.setProperty("videodatarate", 0);
            ecmaArray.setProperty("framerate", 0);
            ecmaArray.setProperty("audiodatarate", 0);
            ecmaArray.setProperty("audiosamplerate", 44100);
            ecmaArray.setProperty("audiosamplesize", 16);
            ecmaArray.setProperty("stereo", true);
            ecmaArray.setProperty("filesize", 0);
            metadata.addData(ecmaArray);
            sendRtmpPacket(metadata);
        }
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public void close() {
        if (this.socket != null) {
            closeStream();
        }
        try {
            shutdown();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void closeStream() {
        if (!this.connected) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not connected to RTMP server"));
        } else if (this.currentStreamId == 0) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("No current stream object exists"));
        } else if (!this.publishPermitted) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not get _result(Netstream.Publish.Start)"));
        } else {
            Log.d(TAG, "closeStream(): setting current stream ID to 0");
            Command closeStream = new Command("closeStream", 0);
            closeStream.getHeader().setChunkStreamId(5);
            closeStream.getHeader().setMessageStreamId(this.currentStreamId);
            closeStream.addData(new AmfNull());
            sendRtmpPacket(closeStream);
            this.mHandler.notifyRtmpStopped();
        }
    }

    private void shutdown() {
        Socket socket2 = this.socket;
        if (socket2 != null) {
            try {
                socket2.shutdownInput();
                this.socket.shutdownOutput();
            } catch (IOException ioe) {
                ioe.printStackTrace();
            }
            Thread thread = this.rxPacketHandler;
            if (thread != null) {
                thread.interrupt();
                try {
                    this.rxPacketHandler.join();
                } catch (InterruptedException e) {
                    this.rxPacketHandler.interrupt();
                }
                this.rxPacketHandler = null;
            }
            try {
                this.socket.close();
                Log.d(TAG, "socket closed");
            } catch (Exception ex) {
                Log.e(TAG, "shutdown(): failed to close socket", ex);
            }
            this.mHandler.notifyRtmpDisconnected();
        }
        reset();
    }

    private void reset() {
        this.connected = false;
        this.publishPermitted = false;
        this.tcUrl = null;
        this.swfUrl = null;
        this.pageUrl = null;
        this.appName = null;
        this.streamName = null;
        this.publishType = null;
        this.currentStreamId = 0;
        this.transactionIdCounter = 0;
        this.videoFrameCacheNumber.set(0);
        this.socketExceptionCause = "";
        this.serverIpAddr = null;
        this.serverPid = null;
        this.serverId = null;
        this.socket = null;
        this.rtmpSessionInfo = null;
        this.rtmpDecoder = null;
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public void publishAudioData(byte[] data, int size, int dts) {
        if (data == null || data.length == 0 || dts < 0) {
            this.mHandler.notifyRtmpIllegalArgumentException(new IllegalArgumentException("Invalid Audio Data"));
        } else if (!this.connected) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not connected to RTMP server"));
        } else if (this.currentStreamId == 0) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("No current stream object exists"));
        } else if (!this.publishPermitted) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not get _result(Netstream.Publish.Start)"));
        } else {
            Audio audio = new Audio();
            audio.setData(data, size);
            audio.getHeader().setAbsoluteTimestamp(dts);
            audio.getHeader().setMessageStreamId(this.currentStreamId);
            sendRtmpPacket(audio);
            calcAudioBitrate(audio.getHeader().getPacketLength());
            this.mHandler.notifyRtmpAudioStreaming();
        }
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public void publishVideoData(byte[] data, int size, int dts) {
        if (data == null || data.length == 0 || dts < 0) {
            this.mHandler.notifyRtmpIllegalArgumentException(new IllegalArgumentException("Invalid Video Data"));
        } else if (!this.connected) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not connected to RTMP server"));
        } else if (this.currentStreamId == 0) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("No current stream object exists"));
        } else if (!this.publishPermitted) {
            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Not get _result(Netstream.Publish.Start)"));
        } else {
            Video video = new Video();
            video.setData(data, size);
            video.getHeader().setAbsoluteTimestamp(dts);
            video.getHeader().setMessageStreamId(this.currentStreamId);
            sendRtmpPacket(video);
            this.videoFrameCacheNumber.decrementAndGet();
            calcVideoFpsAndBitrate(video.getHeader().getPacketLength());
            this.mHandler.notifyRtmpVideoStreaming();
        }
    }

    private void calcVideoFpsAndBitrate(int length) {
        this.videoDataLength += length;
        int i = this.videoFrameCount;
        if (i == 0) {
            this.videoLastTimeMillis = System.nanoTime() / 1000000;
            this.videoFrameCount++;
            return;
        }
        int i2 = i + 1;
        this.videoFrameCount = i2;
        if (i2 >= 48) {
            long diffTimeMillis = (System.nanoTime() / 1000000) - this.videoLastTimeMillis;
            this.mHandler.notifyRtmpVideoFpsChanged((((double) this.videoFrameCount) * 1000.0d) / ((double) diffTimeMillis));
            this.mHandler.notifyRtmpVideoBitrateChanged(((((double) this.videoDataLength) * 8.0d) * 1000.0d) / ((double) diffTimeMillis));
            this.videoFrameCount = 0;
            this.videoDataLength = 0;
        }
    }

    private void calcAudioBitrate(int length) {
        this.audioDataLength += length;
        int i = this.audioFrameCount;
        if (i == 0) {
            this.audioLastTimeMillis = System.nanoTime() / 1000000;
            this.audioFrameCount++;
            return;
        }
        int i2 = i + 1;
        this.audioFrameCount = i2;
        if (i2 >= 48) {
            this.mHandler.notifyRtmpAudioBitrateChanged(((((double) this.audioDataLength) * 8.0d) * 1000.0d) / ((double) ((System.nanoTime() / 1000000) - this.audioLastTimeMillis)));
            this.audioFrameCount = 0;
            this.audioDataLength = 0;
        }
    }

    private void sendRtmpPacket(RtmpPacket rtmpPacket) {
        try {
            ChunkStreamInfo chunkStreamInfo = this.rtmpSessionInfo.getChunkStreamInfo(rtmpPacket.getHeader().getChunkStreamId());
            chunkStreamInfo.setPrevHeaderTx(rtmpPacket.getHeader());
            if (!(rtmpPacket instanceof Video) && !(rtmpPacket instanceof Audio)) {
                rtmpPacket.getHeader().setAbsoluteTimestamp((int) chunkStreamInfo.markAbsoluteTimestampTx());
            }
            rtmpPacket.writeTo(this.outputStream, this.rtmpSessionInfo.getTxChunkSize(), chunkStreamInfo);
            if (rtmpPacket instanceof Command) {
                this.rtmpSessionInfo.addInvokedCommand(((Command) rtmpPacket).getTransactionId(), ((Command) rtmpPacket).getCommandName());
            }
            this.outputStream.flush();
        } catch (SocketException se) {
            if (!this.socketExceptionCause.contentEquals(se.getMessage())) {
                this.socketExceptionCause = se.getMessage();
                Log.e(TAG, "Caught SocketException during write loop, shutting down: " + se.getMessage());
                this.mHandler.notifyRtmpSocketException(se);
            }
        } catch (IOException ioe) {
            Log.e(TAG, "Caught IOException during write loop, shutting down: " + ioe.getMessage());
            this.mHandler.notifyRtmpIOException(ioe);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleRxPacketLoop() throws IOException {
        while (!Thread.interrupted()) {
            try {
                RtmpPacket rtmpPacket = this.rtmpDecoder.readPacket(this.inputStream);
                if (rtmpPacket != null) {
                    int i = AnonymousClass2.$SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$MessageType[rtmpPacket.getHeader().getMessageType().ordinal()];
                    if (i == 1) {
                        this.rtmpSessionInfo.getChunkStreamInfo(((Abort) rtmpPacket).getChunkStreamId()).clearStoredChunks();
                    } else if (i == 2) {
                        UserControl user = (UserControl) rtmpPacket;
                        int i2 = AnonymousClass2.$SwitchMap$com$github$faucamp$simplertmp$packets$UserControl$Type[user.getType().ordinal()];
                        if (i2 != 1) {
                            if (i2 == 2) {
                                ChunkStreamInfo channelInfo = this.rtmpSessionInfo.getChunkStreamInfo(2);
                                Log.d(TAG, "handleRxPacketLoop(): Sending PONG reply..");
                                sendRtmpPacket(new UserControl(user, channelInfo));
                            } else if (i2 == 3) {
                                Log.i(TAG, "handleRxPacketLoop(): Stream EOF reached, closing RTMP writer...");
                            }
                        } else if (this.currentStreamId != user.getFirstEventData()) {
                            this.mHandler.notifyRtmpIllegalStateException(new IllegalStateException("Current stream ID error!"));
                        }
                    } else if (i == 3) {
                        int size = ((WindowAckSize) rtmpPacket).getAcknowledgementWindowSize();
                        Log.d(TAG, "handleRxPacketLoop(): Setting acknowledgement window size: " + size);
                        this.rtmpSessionInfo.setAcknowledgmentWindowSize(size);
                    } else if (i == 4) {
                        this.rtmpSessionInfo.setAcknowledgmentWindowSize(((SetPeerBandwidth) rtmpPacket).getAcknowledgementWindowSize());
                        int acknowledgementWindowsize = this.rtmpSessionInfo.getAcknowledgementWindowSize();
                        ChunkStreamInfo chunkStreamInfo = this.rtmpSessionInfo.getChunkStreamInfo(2);
                        Log.d(TAG, "handleRxPacketLoop(): Send acknowledgement window size: " + acknowledgementWindowsize);
                        sendRtmpPacket(new WindowAckSize(acknowledgementWindowsize, chunkStreamInfo));
                        this.socket.setSendBufferSize(acknowledgementWindowsize);
                    } else if (i != 5) {
                        Log.w(TAG, "handleRxPacketLoop(): Not handling unimplemented/unknown packet of type: " + rtmpPacket.getHeader().getMessageType());
                    } else {
                        handleRxInvoke((Command) rtmpPacket);
                    }
                }
            } catch (EOFException e) {
                Thread.currentThread().interrupt();
            } catch (SocketException se) {
                Log.e(TAG, "Caught SocketException while reading/decoding packet, shutting down: " + se.getMessage());
                this.mHandler.notifyRtmpSocketException(se);
            } catch (IOException ioe) {
                Log.e(TAG, "Caught exception while reading/decoding packet, shutting down: " + ioe.getMessage());
                this.mHandler.notifyRtmpIOException(ioe);
            }
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.github.faucamp.simplertmp.io.RtmpConnection$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$MessageType;
        static final /* synthetic */ int[] $SwitchMap$com$github$faucamp$simplertmp$packets$UserControl$Type;

        static {
            int[] iArr = new int[RtmpHeader.MessageType.values().length];
            $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$MessageType = iArr;
            try {
                iArr[RtmpHeader.MessageType.ABORT.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$MessageType[RtmpHeader.MessageType.USER_CONTROL_MESSAGE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$MessageType[RtmpHeader.MessageType.WINDOW_ACKNOWLEDGEMENT_SIZE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$MessageType[RtmpHeader.MessageType.SET_PEER_BANDWIDTH.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$MessageType[RtmpHeader.MessageType.COMMAND_AMF0.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            int[] iArr2 = new int[UserControl.Type.values().length];
            $SwitchMap$com$github$faucamp$simplertmp$packets$UserControl$Type = iArr2;
            try {
                iArr2[UserControl.Type.STREAM_BEGIN.ordinal()] = 1;
            } catch (NoSuchFieldError e6) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$UserControl$Type[UserControl.Type.PING_REQUEST.ordinal()] = 2;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$UserControl$Type[UserControl.Type.STREAM_EOF.ordinal()] = 3;
            } catch (NoSuchFieldError e8) {
            }
        }
    }

    private void handleRxInvoke(Command invoke) throws IOException {
        String commandName = invoke.getCommandName();
        if (commandName.equals("_result")) {
            String method = this.rtmpSessionInfo.takeInvokedCommand(invoke.getTransactionId());
            Log.d(TAG, "handleRxInvoke: Got result for invoked method: " + method);
            if ("connect".equals(method)) {
                this.srsServerInfo = onSrsServerInfo(invoke);
                this.connected = true;
                synchronized (this.connectingLock) {
                    this.connectingLock.notifyAll();
                }
            } else if ("createStream".contains(method)) {
                this.currentStreamId = (int) ((AmfNumber) invoke.getData().get(1)).getValue();
                Log.d(TAG, "handleRxInvoke(): Stream ID to publish: " + this.currentStreamId);
                if (this.streamName != null && this.publishType != null) {
                    fmlePublish();
                }
            } else if ("releaseStream".contains(method)) {
                Log.d(TAG, "handleRxInvoke(): 'releaseStream'");
            } else if ("FCPublish".contains(method)) {
                Log.d(TAG, "handleRxInvoke(): 'FCPublish'");
            } else {
                Log.w(TAG, "handleRxInvoke(): '_result' message received for unknown method: " + method);
            }
        } else if (commandName.equals("onBWDone")) {
            Log.d(TAG, "handleRxInvoke(): 'onBWDone'");
        } else if (commandName.equals("onFCPublish")) {
            Log.d(TAG, "handleRxInvoke(): 'onFCPublish'");
        } else if (commandName.equals("onStatus")) {
            String code = ((AmfString) ((AmfObject) invoke.getData().get(1)).getProperty("code")).getValue();
            Log.d(TAG, "handleRxInvoke(): onStatus " + code);
            if (code.equals("NetStream.Publish.Start")) {
                onMetaData();
                this.publishPermitted = true;
                synchronized (this.publishLock) {
                    this.publishLock.notifyAll();
                }
            }
        } else {
            Log.e(TAG, "handleRxInvoke(): Unknown/unhandled server invoke: " + invoke);
        }
    }

    private String onSrsServerInfo(Command invoke) {
        String str;
        String str2;
        AmfObject objData = (AmfObject) invoke.getData().get(1);
        if (objData.getProperty("data") instanceof AmfObject) {
            AmfObject objData2 = (AmfObject) objData.getProperty("data");
            this.serverIpAddr = (AmfString) objData2.getProperty("srs_server_ip");
            this.serverPid = (AmfNumber) objData2.getProperty("srs_pid");
            if (objData2.getProperty("srs_id") instanceof AmfString) {
                this.serverId = (AmfString) objData2.getProperty("srs_id");
            } else if (objData2.getProperty("srs_id") instanceof AmfNumber) {
                this.serverId = new AmfString(String.valueOf((int) ((AmfNumber) objData2.getProperty("srs_id")).getValue()));
            }
        }
        StringBuilder sb = new StringBuilder();
        sb.append("");
        String str3 = "";
        if (this.serverIpAddr == null) {
            str = str3;
        } else {
            str = " ip: " + this.serverIpAddr.getValue();
        }
        sb.append(str);
        String info = sb.toString();
        StringBuilder sb2 = new StringBuilder();
        sb2.append(info);
        if (this.serverPid == null) {
            str2 = str3;
        } else {
            str2 = " pid: " + ((int) this.serverPid.getValue());
        }
        sb2.append(str2);
        String info2 = sb2.toString();
        StringBuilder sb3 = new StringBuilder();
        sb3.append(info2);
        if (this.serverId != null) {
            str3 = " id: " + this.serverId.getValue();
        }
        sb3.append(str3);
        return sb3.toString();
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public AtomicInteger getVideoFrameCacheNumber() {
        return this.videoFrameCacheNumber;
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public final String getServerIpAddr() {
        AmfString amfString = this.serverIpAddr;
        if (amfString == null) {
            return null;
        }
        return amfString.getValue();
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public final int getServerPid() {
        AmfNumber amfNumber = this.serverPid;
        if (amfNumber == null) {
            return 0;
        }
        return (int) amfNumber.getValue();
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public final int getServerId() {
        AmfString amfString = this.serverId;
        if (amfString == null) {
            return 0;
        }
        return Integer.parseInt(amfString.getValue());
    }

    @Override // com.github.faucamp.simplertmp.RtmpPublisher
    public void setVideoResolution(int width, int height) {
        this.videoWidth = width;
        this.videoHeight = height;
    }
}
