package com.github.faucamp.simplertmp.packets;

import android.util.Log;
import com.github.faucamp.simplertmp.Crypto;
import com.github.faucamp.simplertmp.Util;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Random;
import org.mozilla.universalchardet.prober.HebrewProber;

public final class Handshake {
    private static final int DIGEST_OFFSET_INDICATOR_POS = 772;
    private static final byte[] GENUINE_FP_KEY = {71, 101, 110, 117, 105, 110, 101, HebrewProber.SPACE, 65, 100, 111, 98, 101, HebrewProber.SPACE, 70, 108, 97, 115, 104, HebrewProber.SPACE, 80, 108, 97, 121, 101, 114, HebrewProber.SPACE, 48, 48, 49, -16, -18, -62, 74, Byte.MIN_VALUE, 104, -66, -24, 46, 0, -48, -47, 2, -98, 126, 87, 110, -20, 93, 45, 41, Byte.MIN_VALUE, 111, -85, -109, -72, -26, 54, -49, -21, 49, -82};
    private static final int HANDSHAKE_SIZE = 1536;
    private static final int PROTOCOL_VERSION = 3;
    private static final int SHA256_DIGEST_SIZE = 32;
    private static final String TAG = "Handshake";
    private byte[] s1;

    public final void writeC0(OutputStream out) throws IOException {
        Log.d(TAG, "writeC0");
        out.write(3);
    }

    public final void readS0(InputStream in) throws IOException {
        Log.d(TAG, "readS0");
        byte s0 = (byte) in.read();
        if (s0 == 3) {
            return;
        }
        if (s0 == -1) {
            throw new IOException("InputStream closed");
        }
        throw new IOException("Invalid RTMP protocol version; expected 3, got " + ((int) s0));
    }

    public final void writeC1(OutputStream out) throws IOException {
        Log.d(TAG, "writeC1");
        Log.d(TAG, "writeC1(): Calculating digest offset");
        Random random = new Random();
        int digestOffset = random.nextInt(720);
        int absoluteDigestOffset = (digestOffset % 728) + DIGEST_OFFSET_INDICATOR_POS + 4;
        Log.d(TAG, "writeC1(): (real value of) digestOffset: " + digestOffset);
        Log.d(TAG, "writeC1(): recalculated digestOffset: " + absoluteDigestOffset);
        int remaining = digestOffset;
        byte[] digestOffsetBytes = new byte[4];
        for (int i = 3; i >= 0; i--) {
            if (remaining > 255) {
                digestOffsetBytes[i] = -1;
                remaining -= 255;
            } else {
                digestOffsetBytes[i] = (byte) remaining;
                remaining -= remaining;
            }
        }
        Log.d(TAG, "writeC1(): digestOffsetBytes: " + Util.toHexString(digestOffsetBytes));
        byte[] partBeforeDigest = new byte[absoluteDigestOffset];
        Log.d(TAG, "partBeforeDigest(): size: " + partBeforeDigest.length);
        random.nextBytes(partBeforeDigest);
        Log.d(TAG, "writeC1(): Writing timestamp and Flash Player version");
        System.arraycopy(Util.unsignedInt32ToByteArray((int) (System.currentTimeMillis() / 1000)), 0, partBeforeDigest, 0, 4);
        System.arraycopy(new byte[]{Byte.MIN_VALUE, 0, 7, 2}, 0, partBeforeDigest, 4, 4);
        byte[] partAfterDigest = new byte[((1536 - absoluteDigestOffset) - 32)];
        Log.d(TAG, "partAfterDigest(): size: " + partAfterDigest.length);
        random.nextBytes(partAfterDigest);
        Log.d(TAG, "copying digest offset bytes in partBeforeDigest");
        System.arraycopy(digestOffsetBytes, 0, partBeforeDigest, DIGEST_OFFSET_INDICATOR_POS, 4);
        Log.d(TAG, "writeC1(): Calculating digest");
        byte[] tempBuffer = new byte[1504];
        System.arraycopy(partBeforeDigest, 0, tempBuffer, 0, partBeforeDigest.length);
        System.arraycopy(partAfterDigest, 0, tempBuffer, partBeforeDigest.length, partAfterDigest.length);
        byte[] digest = new Crypto().calculateHmacSHA256(tempBuffer, GENUINE_FP_KEY, 30);
        Log.d(TAG, "writeC1(): writing C1 packet");
        out.write(partBeforeDigest);
        out.write(digest);
        out.write(partAfterDigest);
    }

    public final void readS1(InputStream in) throws IOException {
        Log.d(TAG, "readS1");
        this.s1 = new byte[HANDSHAKE_SIZE];
        int totalBytesRead = 0;
        do {
            int read = in.read(this.s1, totalBytesRead, 1536 - totalBytesRead);
            if (read != -1) {
                totalBytesRead += read;
                continue;
            }
        } while (totalBytesRead < HANDSHAKE_SIZE);
        if (totalBytesRead == HANDSHAKE_SIZE) {
            Log.d(TAG, "readS1(): S1 total bytes read OK");
            return;
        }
        throw new IOException("Unexpected EOF while reading S1, expected 1536 bytes, but only read " + totalBytesRead + " bytes");
    }

    public final void writeC2(OutputStream out) throws IOException {
        Log.d(TAG, "writeC2");
        byte[] bArr = this.s1;
        if (bArr != null) {
            out.write(bArr);
            return;
        }
        throw new IllegalStateException("C2 cannot be written without S1 being read first");
    }

    public final void readS2(InputStream in) throws IOException {
        int read;
        Log.d(TAG, "readS2");
        byte[] sr_serverTime = new byte[4];
        byte[] s2_serverVersion = new byte[4];
        byte[] s2_rest = new byte[1528];
        int totalBytesRead = 0;
        do {
            int read2 = in.read(sr_serverTime, totalBytesRead, 4 - totalBytesRead);
            if (read2 != -1) {
                totalBytesRead += read2;
            } else {
                throw new IOException("Unexpected EOF while reading S2 bytes 0-3");
            }
        } while (totalBytesRead < 4);
        int totalBytesRead2 = 0;
        do {
            int read3 = in.read(s2_serverVersion, totalBytesRead2, 4 - totalBytesRead2);
            if (read3 != -1) {
                totalBytesRead2 += read3;
            } else {
                throw new IOException("Unexpected EOF while reading S2 bytes 4-7");
            }
        } while (totalBytesRead2 < 4);
        int totalBytesRead3 = 0;
        do {
            read = in.read(s2_rest, totalBytesRead3, 1528 - totalBytesRead3);
            if (read != -1) {
                totalBytesRead3 += read;
            }
            if (totalBytesRead3 >= 1528) {
                break;
            }
        } while (read != -1);
        if (totalBytesRead3 == 1528) {
            Log.d(TAG, "readS2(): S2 total bytes read OK");
            return;
        }
        throw new IOException("Unexpected EOF while reading remainder of S2, expected 1528 bytes, but only read " + totalBytesRead3 + " bytes");
    }
}
