package com.github.faucamp.simplertmp.packets;

import com.github.faucamp.simplertmp.Util;
import com.github.faucamp.simplertmp.io.ChunkStreamInfo;
import com.github.faucamp.simplertmp.io.RtmpSessionInfo;
import io.dcloud.common.DHInterface.IApp;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;

public class RtmpHeader {
    private static final String TAG = "RtmpHeader";
    private int absoluteTimestamp;
    private int chunkStreamId;
    private ChunkType chunkType;
    private int extendedTimestamp;
    private int messageStreamId;
    private MessageType messageType;
    private int packetLength;
    private int timestampDelta = -1;

    public enum MessageType {
        SET_CHUNK_SIZE(1),
        ABORT(2),
        ACKNOWLEDGEMENT(3),
        USER_CONTROL_MESSAGE(4),
        WINDOW_ACKNOWLEDGEMENT_SIZE(5),
        SET_PEER_BANDWIDTH(6),
        AUDIO(8),
        VIDEO(9),
        DATA_AMF3(15),
        SHARED_OBJECT_AMF3(16),
        COMMAND_AMF3(17),
        DATA_AMF0(18),
        COMMAND_AMF0(20),
        SHARED_OBJECT_AMF0(19),
        AGGREGATE_MESSAGE(22);
        
        private static final Map<Byte, MessageType> quickLookupMap = new HashMap();
        private byte value;

        static {
            MessageType[] values = values();
            for (MessageType messageTypId : values) {
                quickLookupMap.put(Byte.valueOf(messageTypId.getValue()), messageTypId);
            }
        }

        private MessageType(int value2) {
            this.value = (byte) value2;
        }

        public byte getValue() {
            return this.value;
        }

        public static MessageType valueOf(byte messageTypeId) {
            if (quickLookupMap.containsKey(Byte.valueOf(messageTypeId))) {
                return quickLookupMap.get(Byte.valueOf(messageTypeId));
            }
            throw new IllegalArgumentException("Unknown message type byte: " + Util.toHexString(messageTypeId));
        }
    }

    public enum ChunkType {
        TYPE_0_FULL(0),
        TYPE_1_RELATIVE_LARGE(1),
        TYPE_2_RELATIVE_TIMESTAMP_ONLY(2),
        TYPE_3_RELATIVE_SINGLE_BYTE(3);
        
        private static final Map<Byte, ChunkType> quickLookupMap = new HashMap();
        private byte value;

        static {
            ChunkType[] values = values();
            for (ChunkType messageTypId : values) {
                quickLookupMap.put(Byte.valueOf(messageTypId.getValue()), messageTypId);
            }
        }

        private ChunkType(int byteValue) {
            this.value = (byte) byteValue;
        }

        public byte getValue() {
            return this.value;
        }

        public static ChunkType valueOf(byte chunkHeaderType) {
            if (quickLookupMap.containsKey(Byte.valueOf(chunkHeaderType))) {
                return quickLookupMap.get(Byte.valueOf(chunkHeaderType));
            }
            throw new IllegalArgumentException("Unknown chunk header type byte: " + Util.toHexString(chunkHeaderType));
        }
    }

    public RtmpHeader() {
    }

    public RtmpHeader(ChunkType chunkType2, int chunkStreamId2, MessageType messageType2) {
        this.chunkType = chunkType2;
        this.chunkStreamId = chunkStreamId2;
        this.messageType = messageType2;
    }

    public static RtmpHeader readHeader(InputStream in, RtmpSessionInfo rtmpSessionInfo) throws IOException {
        RtmpHeader rtmpHeader = new RtmpHeader();
        rtmpHeader.readHeaderImpl(in, rtmpSessionInfo);
        return rtmpHeader;
    }

    private void readHeaderImpl(InputStream in, RtmpSessionInfo rtmpSessionInfo) throws IOException {
        int basicHeaderByte = in.read();
        if (basicHeaderByte != -1) {
            parseBasicHeader((byte) basicHeaderByte);
            int i = AnonymousClass1.$SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$ChunkType[this.chunkType.ordinal()];
            int i2 = 16777215;
            int i3 = 0;
            if (i == 1) {
                this.absoluteTimestamp = Util.readUnsignedInt24(in);
                this.timestampDelta = 0;
                this.packetLength = Util.readUnsignedInt24(in);
                this.messageType = MessageType.valueOf((byte) in.read());
                byte[] messageStreamIdBytes = new byte[4];
                Util.readBytesUntilFull(in, messageStreamIdBytes);
                this.messageStreamId = Util.toUnsignedInt32LittleEndian(messageStreamIdBytes);
                if (this.absoluteTimestamp >= 16777215) {
                    i3 = Util.readUnsignedInt32(in);
                }
                this.extendedTimestamp = i3;
                if (i3 != 0) {
                    this.absoluteTimestamp = i3;
                }
            } else if (i == 2) {
                this.timestampDelta = Util.readUnsignedInt24(in);
                this.packetLength = Util.readUnsignedInt24(in);
                this.messageType = MessageType.valueOf((byte) in.read());
                this.extendedTimestamp = this.timestampDelta >= 16777215 ? Util.readUnsignedInt32(in) : 0;
                RtmpHeader prevHeader = rtmpSessionInfo.getChunkStreamInfo(this.chunkStreamId).prevHeaderRx();
                if (prevHeader != null) {
                    this.messageStreamId = prevHeader.messageStreamId;
                    int i4 = this.extendedTimestamp;
                    if (i4 == 0) {
                        i4 = prevHeader.absoluteTimestamp + this.timestampDelta;
                    }
                    this.absoluteTimestamp = i4;
                    return;
                }
                this.messageStreamId = 0;
                int i5 = this.extendedTimestamp;
                if (i5 == 0) {
                    i5 = this.timestampDelta;
                }
                this.absoluteTimestamp = i5;
            } else if (i == 3) {
                int readUnsignedInt24 = Util.readUnsignedInt24(in);
                this.timestampDelta = readUnsignedInt24;
                if (readUnsignedInt24 >= 16777215) {
                    i3 = Util.readUnsignedInt32(in);
                }
                this.extendedTimestamp = i3;
                RtmpHeader prevHeader2 = rtmpSessionInfo.getChunkStreamInfo(this.chunkStreamId).prevHeaderRx();
                this.packetLength = prevHeader2.packetLength;
                this.messageType = prevHeader2.messageType;
                this.messageStreamId = prevHeader2.messageStreamId;
                int i6 = this.extendedTimestamp;
                if (i6 == 0) {
                    i6 = prevHeader2.absoluteTimestamp + this.timestampDelta;
                }
                this.absoluteTimestamp = i6;
            } else if (i == 4) {
                RtmpHeader prevHeader3 = rtmpSessionInfo.getChunkStreamInfo(this.chunkStreamId).prevHeaderRx();
                if (prevHeader3.timestampDelta >= 16777215) {
                    i3 = Util.readUnsignedInt32(in);
                }
                this.extendedTimestamp = i3;
                if (i3 == 0) {
                    i2 = prevHeader3.timestampDelta;
                }
                this.timestampDelta = i2;
                this.packetLength = prevHeader3.packetLength;
                this.messageType = prevHeader3.messageType;
                this.messageStreamId = prevHeader3.messageStreamId;
                int i7 = this.extendedTimestamp;
                if (i7 == 0) {
                    i7 = prevHeader3.absoluteTimestamp + i2;
                }
                this.absoluteTimestamp = i7;
            } else {
                throw new IOException("Invalid chunk type; basic header byte was: " + Util.toHexString((byte) basicHeaderByte));
            }
        } else {
            throw new EOFException("Unexpected EOF while reading RTMP packet basic header");
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.github.faucamp.simplertmp.packets.RtmpHeader$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$ChunkType;

        static {
            int[] iArr = new int[ChunkType.values().length];
            $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$ChunkType = iArr;
            try {
                iArr[ChunkType.TYPE_0_FULL.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$ChunkType[ChunkType.TYPE_1_RELATIVE_LARGE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$ChunkType[ChunkType.TYPE_2_RELATIVE_TIMESTAMP_ONLY.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$ChunkType[ChunkType.TYPE_3_RELATIVE_SINGLE_BYTE.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    public void writeTo(OutputStream out, ChunkType chunkType2, ChunkStreamInfo chunkStreamInfo) throws IOException {
        out.write(((byte) (chunkType2.getValue() << 6)) | this.chunkStreamId);
        int i = AnonymousClass1.$SwitchMap$com$github$faucamp$simplertmp$packets$RtmpHeader$ChunkType[chunkType2.ordinal()];
        if (i == 1) {
            chunkStreamInfo.markDeltaTimestampTx();
            int i2 = this.absoluteTimestamp;
            if (i2 >= 16777215) {
                i2 = 16777215;
            }
            Util.writeUnsignedInt24(out, i2);
            Util.writeUnsignedInt24(out, this.packetLength);
            out.write(this.messageType.getValue());
            Util.writeUnsignedInt32LittleEndian(out, this.messageStreamId);
            int i3 = this.absoluteTimestamp;
            if (i3 >= 16777215) {
                this.extendedTimestamp = i3;
                Util.writeUnsignedInt32(out, i3);
            }
        } else if (i == 2) {
            this.timestampDelta = (int) chunkStreamInfo.markDeltaTimestampTx();
            int absoluteTimestamp2 = chunkStreamInfo.getPrevHeaderTx().getAbsoluteTimestamp();
            int i4 = this.timestampDelta;
            int i5 = absoluteTimestamp2 + i4;
            this.absoluteTimestamp = i5;
            if (i5 >= 16777215) {
                i4 = 16777215;
            }
            Util.writeUnsignedInt24(out, i4);
            Util.writeUnsignedInt24(out, this.packetLength);
            out.write(this.messageType.getValue());
            int i6 = this.absoluteTimestamp;
            if (i6 >= 16777215) {
                this.extendedTimestamp = i6;
                Util.writeUnsignedInt32(out, i6);
            }
        } else if (i == 3) {
            this.timestampDelta = (int) chunkStreamInfo.markDeltaTimestampTx();
            int absoluteTimestamp3 = chunkStreamInfo.getPrevHeaderTx().getAbsoluteTimestamp();
            int i7 = this.timestampDelta;
            int i8 = absoluteTimestamp3 + i7;
            this.absoluteTimestamp = i8;
            if (i8 >= 16777215) {
                i7 = 16777215;
            }
            Util.writeUnsignedInt24(out, i7);
            int i9 = this.absoluteTimestamp;
            if (i9 >= 16777215) {
                this.extendedTimestamp = i9;
                Util.writeUnsignedInt32(out, i9);
            }
        } else if (i == 4) {
            int i10 = this.extendedTimestamp;
            if (i10 > 0) {
                Util.writeUnsignedInt32(out, i10);
            }
        } else {
            throw new IOException("Invalid chunk type: " + chunkType2);
        }
    }

    private void parseBasicHeader(byte basicHeaderByte) {
        this.chunkType = ChunkType.valueOf((byte) ((basicHeaderByte & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) >>> 6));
        this.chunkStreamId = basicHeaderByte & 63;
    }

    public int getChunkStreamId() {
        return this.chunkStreamId;
    }

    public ChunkType getChunkType() {
        return this.chunkType;
    }

    public int getPacketLength() {
        return this.packetLength;
    }

    public int getMessageStreamId() {
        return this.messageStreamId;
    }

    public MessageType getMessageType() {
        return this.messageType;
    }

    public int getAbsoluteTimestamp() {
        return this.absoluteTimestamp;
    }

    public void setAbsoluteTimestamp(int absoluteTimestamp2) {
        this.absoluteTimestamp = absoluteTimestamp2;
    }

    public int getTimestampDelta() {
        return this.timestampDelta;
    }

    public void setTimestampDelta(int timestampDelta2) {
        this.timestampDelta = timestampDelta2;
    }

    public void setChunkStreamId(int channelId) {
        this.chunkStreamId = channelId;
    }

    public void setChunkType(ChunkType chunkType2) {
        this.chunkType = chunkType2;
    }

    public void setMessageStreamId(int messageStreamId2) {
        this.messageStreamId = messageStreamId2;
    }

    public void setMessageType(MessageType messageType2) {
        this.messageType = messageType2;
    }

    public void setPacketLength(int packetLength2) {
        this.packetLength = packetLength2;
    }
}
