package com.googlecode.mp4parser.authoring.adaptivestreaming;

import com.coremedia.iso.boxes.OriginalFormatBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.sampleentry.AudioSampleEntry;
import com.coremedia.iso.boxes.sampleentry.SampleEntry;
import com.coremedia.iso.boxes.sampleentry.VisualSampleEntry;
import com.googlecode.mp4parser.authoring.Movie;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.authoring.builder.FragmentIntersectionFinder;
import com.googlecode.mp4parser.util.CastUtils;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Arrays;
import java.util.logging.Logger;

public abstract class AbstractManifestWriter implements ManifestWriter {
    private static final Logger LOG = Logger.getLogger(AbstractManifestWriter.class.getName());
    protected long[] audioFragmentsDurations;
    private FragmentIntersectionFinder intersectionFinder;
    protected long[] videoFragmentsDurations;

    protected AbstractManifestWriter(FragmentIntersectionFinder intersectionFinder2) {
        this.intersectionFinder = intersectionFinder2;
    }

    @Override // com.googlecode.mp4parser.authoring.adaptivestreaming.ManifestWriter
    public long[] calculateFragmentDurations(Track track, Movie movie) {
        long[] startSamples = this.intersectionFinder.sampleNumbers(track, movie);
        long[] durations = new long[startSamples.length];
        int currentFragment = 0;
        int currentSample = 1;
        for (TimeToSampleBox.Entry entry : track.getDecodingTimeEntries()) {
            int max = CastUtils.l2i(entry.getCount()) + currentSample;
            while (currentSample < max) {
                if (currentFragment != startSamples.length - 1 && ((long) currentSample) == startSamples[currentFragment + 1]) {
                    currentFragment++;
                }
                durations[currentFragment] = durations[currentFragment] + entry.getDelta();
                currentSample++;
            }
        }
        return durations;
    }

    @Override // com.googlecode.mp4parser.authoring.adaptivestreaming.ManifestWriter
    public long getBitrate(Track track) {
        long bitrate = 0;
        for (ByteBuffer sample : track.getSamples()) {
            bitrate += (long) sample.limit();
        }
        return (long) (((double) (bitrate * 8)) / (((double) getDuration(track)) / ((double) track.getTrackMetaData().getTimescale())));
    }

    protected static long getDuration(Track track) {
        long duration = 0;
        for (TimeToSampleBox.Entry entry : track.getDecodingTimeEntries()) {
            duration += entry.getCount() * entry.getDelta();
        }
        return duration;
    }

    /* access modifiers changed from: protected */
    public long[] checkFragmentsAlign(long[] referenceTimes, long[] checkTimes) throws IOException {
        if (referenceTimes == null || referenceTimes.length == 0) {
            return checkTimes;
        }
        long[] referenceTimesMinusLast = new long[(referenceTimes.length - 1)];
        System.arraycopy(referenceTimes, 0, referenceTimesMinusLast, 0, referenceTimes.length - 1);
        long[] checkTimesMinusLast = new long[(checkTimes.length - 1)];
        System.arraycopy(checkTimes, 0, checkTimesMinusLast, 0, checkTimes.length - 1);
        if (Arrays.equals(checkTimesMinusLast, referenceTimesMinusLast)) {
            return checkTimes;
        }
        String log = ("" + referenceTimes.length) + "Reference     :  [";
        for (long l : referenceTimes) {
            log = log + String.format("%10d,", Long.valueOf(l));
        }
        LOG.warning(log + Operators.ARRAY_END_STR);
        String log2 = ("" + checkTimes.length) + "Current       :  [";
        for (long l2 : checkTimes) {
            log2 = log2 + String.format("%10d,", Long.valueOf(l2));
        }
        LOG.warning(log2 + Operators.ARRAY_END_STR);
        throw new IOException("Track does not have the same fragment borders as its predecessor.");
    }

    /* access modifiers changed from: protected */
    public String getFormat(SampleEntry se) {
        String type = se.getType();
        if (type.equals(VisualSampleEntry.TYPE_ENCRYPTED) || type.equals(AudioSampleEntry.TYPE_ENCRYPTED) || type.equals(VisualSampleEntry.TYPE_ENCRYPTED)) {
            return ((OriginalFormatBox) se.getBoxes(OriginalFormatBox.class, true).get(0)).getDataFormat();
        }
        return type;
    }
}
