package com.googlecode.mp4parser.authoring.builder;

import com.coremedia.iso.BoxParser;
import com.coremedia.iso.IsoFile;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.ContainerBox;
import com.coremedia.iso.boxes.DataEntryUrlBox;
import com.coremedia.iso.boxes.DataInformationBox;
import com.coremedia.iso.boxes.DataReferenceBox;
import com.coremedia.iso.boxes.FileTypeBox;
import com.coremedia.iso.boxes.HandlerBox;
import com.coremedia.iso.boxes.MediaBox;
import com.coremedia.iso.boxes.MediaHeaderBox;
import com.coremedia.iso.boxes.MediaInformationBox;
import com.coremedia.iso.boxes.MovieBox;
import com.coremedia.iso.boxes.MovieHeaderBox;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleSizeBox;
import com.coremedia.iso.boxes.SampleTableBox;
import com.coremedia.iso.boxes.SampleToChunkBox;
import com.coremedia.iso.boxes.StaticChunkOffsetBox;
import com.coremedia.iso.boxes.SyncSampleBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.TrackBox;
import com.coremedia.iso.boxes.TrackHeaderBox;
import com.coremedia.iso.boxes.mdat.MediaDataBox;
import com.coremedia.iso.boxes.sampleentry.VisualSampleEntry;
import com.googlecode.mp4parser.authoring.DateHelper;
import com.googlecode.mp4parser.authoring.Movie;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.util.CastUtils;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.MappedByteBuffer;
import java.nio.channels.GatheringByteChannel;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.logging.Level;
import java.util.logging.Logger;

public class DefaultMp4Builder implements Mp4Builder {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static Logger LOG = Logger.getLogger(DefaultMp4Builder.class.getName());
    public int STEPSIZE = 64;
    Set<StaticChunkOffsetBox> chunkOffsetBoxes = new HashSet();
    private FragmentIntersectionFinder intersectionFinder = new TwoSecondIntersectionFinder();
    HashMap<Track, List<ByteBuffer>> track2Sample = new HashMap<>();
    HashMap<Track, long[]> track2SampleSizes = new HashMap<>();

    public void setIntersectionFinder(FragmentIntersectionFinder intersectionFinder2) {
        this.intersectionFinder = intersectionFinder2;
    }

    @Override // com.googlecode.mp4parser.authoring.builder.Mp4Builder
    public IsoFile build(Movie movie) {
        Logger logger = LOG;
        logger.fine("Creating movie " + movie);
        for (Track track : movie.getTracks()) {
            List<ByteBuffer> samples = track.getSamples();
            putSamples(track, samples);
            long[] sizes = new long[samples.size()];
            for (int i = 0; i < sizes.length; i++) {
                sizes[i] = (long) samples.get(i).limit();
            }
            putSampleSizes(track, sizes);
        }
        IsoFile isoFile = new IsoFile();
        List<String> minorBrands = new LinkedList<>();
        minorBrands.add("isom");
        minorBrands.add("iso2");
        minorBrands.add(VisualSampleEntry.TYPE3);
        isoFile.addBox(new FileTypeBox("isom", 0, minorBrands));
        isoFile.addBox(createMovieBox(movie));
        InterleaveChunkMdat mdat = new InterleaveChunkMdat(movie);
        isoFile.addBox(mdat);
        long dataOffset = mdat.getDataOffset();
        for (StaticChunkOffsetBox chunkOffsetBox : this.chunkOffsetBoxes) {
            long[] offsets = chunkOffsetBox.getChunkOffsets();
            for (int i2 = 0; i2 < offsets.length; i2++) {
                offsets[i2] = offsets[i2] + dataOffset;
            }
        }
        return isoFile;
    }

    public FragmentIntersectionFinder getFragmentIntersectionFinder() {
        throw new UnsupportedOperationException("No fragment intersection finder in default MP4 builder!");
    }

    /* access modifiers changed from: protected */
    public long[] putSampleSizes(Track track, long[] sizes) {
        return this.track2SampleSizes.put(track, sizes);
    }

    /* access modifiers changed from: protected */
    public List<ByteBuffer> putSamples(Track track, List<ByteBuffer> samples) {
        return this.track2Sample.put(track, samples);
    }

    private MovieBox createMovieBox(Movie movie) {
        MovieBox movieBox = new MovieBox();
        MovieHeaderBox mvhd = new MovieHeaderBox();
        mvhd.setCreationTime(new Date());
        mvhd.setModificationTime(new Date());
        long movieTimeScale = getTimescale(movie);
        long duration = 0;
        for (Track track : movie.getTracks()) {
            long tracksDuration = (getDuration(track) * movieTimeScale) / track.getTrackMetaData().getTimescale();
            if (tracksDuration > duration) {
                duration = tracksDuration;
            }
        }
        mvhd.setDuration(duration);
        mvhd.setTimescale(movieTimeScale);
        long nextTrackId = 0;
        for (Track track2 : movie.getTracks()) {
            nextTrackId = nextTrackId < track2.getTrackMetaData().getTrackId() ? track2.getTrackMetaData().getTrackId() : nextTrackId;
        }
        mvhd.setNextTrackId(1 + nextTrackId);
        if (DateHelper.convert(mvhd.getCreationTime()) >= 4294967296L || DateHelper.convert(mvhd.getModificationTime()) >= 4294967296L || mvhd.getDuration() >= 4294967296L) {
            mvhd.setVersion(1);
        }
        movieBox.addBox(mvhd);
        for (Track track3 : movie.getTracks()) {
            movieBox.addBox(createTrackBox(track3, movie));
        }
        Box udta = createUdta(movie);
        if (udta != null) {
            movieBox.addBox(udta);
        }
        return movieBox;
    }

    /* access modifiers changed from: protected */
    public Box createUdta(Movie movie) {
        return null;
    }

    private TrackBox createTrackBox(Track track, Movie movie) {
        long offset;
        long offset2;
        SampleTableBox stbl;
        MediaInformationBox minf;
        String str;
        long[] syncSamples;
        List<TimeToSampleBox.Entry> decodingTimeToSampleEntries;
        DataEntryUrlBox url;
        LOG.info("Creating Mp4TrackImpl " + track);
        TrackBox trackBox = new TrackBox();
        TrackHeaderBox tkhd = new TrackHeaderBox();
        int flags = 0;
        if (track.isEnabled()) {
            flags = 0 + 1;
        }
        if (track.isInMovie()) {
            flags += 2;
        }
        if (track.isInPreview()) {
            flags += 4;
        }
        if (track.isInPoster()) {
            flags += 8;
        }
        tkhd.setFlags(flags);
        tkhd.setAlternateGroup(track.getTrackMetaData().getGroup());
        tkhd.setCreationTime(track.getTrackMetaData().getCreationTime());
        tkhd.setDuration((getDuration(track) * getTimescale(movie)) / track.getTrackMetaData().getTimescale());
        tkhd.setHeight(track.getTrackMetaData().getHeight());
        tkhd.setWidth(track.getTrackMetaData().getWidth());
        tkhd.setLayer(track.getTrackMetaData().getLayer());
        tkhd.setModificationTime(new Date());
        tkhd.setTrackId(track.getTrackMetaData().getTrackId());
        tkhd.setVolume(track.getTrackMetaData().getVolume());
        tkhd.setMatrix(track.getTrackMetaData().getMatrix());
        if (DateHelper.convert(tkhd.getCreationTime()) >= 4294967296L || DateHelper.convert(tkhd.getModificationTime()) >= 4294967296L || tkhd.getDuration() >= 4294967296L) {
            tkhd.setVersion(1);
        }
        trackBox.addBox(tkhd);
        MediaBox mdia = new MediaBox();
        trackBox.addBox(mdia);
        MediaHeaderBox mdhd = new MediaHeaderBox();
        mdhd.setCreationTime(track.getTrackMetaData().getCreationTime());
        mdhd.setDuration(getDuration(track));
        mdhd.setTimescale(track.getTrackMetaData().getTimescale());
        mdhd.setLanguage(track.getTrackMetaData().getLanguage());
        mdia.addBox(mdhd);
        HandlerBox hdlr = new HandlerBox();
        mdia.addBox(hdlr);
        hdlr.setHandlerType(track.getHandler());
        MediaInformationBox minf2 = new MediaInformationBox();
        minf2.addBox(track.getMediaHeaderBox());
        DataInformationBox dinf = new DataInformationBox();
        DataReferenceBox dref = new DataReferenceBox();
        dinf.addBox(dref);
        DataEntryUrlBox url2 = new DataEntryUrlBox();
        url2.setFlags(1);
        dref.addBox(url2);
        minf2.addBox(dinf);
        SampleTableBox stbl2 = new SampleTableBox();
        stbl2.addBox(track.getSampleDescriptionBox());
        List<TimeToSampleBox.Entry> decodingTimeToSampleEntries2 = track.getDecodingTimeEntries();
        if (decodingTimeToSampleEntries2 != null && !track.getDecodingTimeEntries().isEmpty()) {
            TimeToSampleBox stts = new TimeToSampleBox();
            stts.setEntries(track.getDecodingTimeEntries());
            stbl2.addBox(stts);
        }
        List<CompositionTimeToSample.Entry> compositionTimeToSampleEntries = track.getCompositionTimeEntries();
        if (compositionTimeToSampleEntries != null && !compositionTimeToSampleEntries.isEmpty()) {
            CompositionTimeToSample ctts = new CompositionTimeToSample();
            ctts.setEntries(compositionTimeToSampleEntries);
            stbl2.addBox(ctts);
        }
        long[] syncSamples2 = track.getSyncSamples();
        if (syncSamples2 != null) {
            if (syncSamples2.length > 0) {
                SyncSampleBox stss = new SyncSampleBox();
                stss.setSampleNumber(syncSamples2);
                stbl2.addBox(stss);
            }
        }
        if (track.getSampleDependencies() != null && !track.getSampleDependencies().isEmpty()) {
            SampleDependencyTypeBox sdtp = new SampleDependencyTypeBox();
            sdtp.setEntries(track.getSampleDependencies());
            stbl2.addBox(sdtp);
        }
        HashMap<Track, int[]> track2ChunkSizes = new HashMap<>();
        for (Iterator<Track> it = movie.getTracks().iterator(); it.hasNext(); it = it) {
            Track current = it.next();
            track2ChunkSizes.put(current, getChunkSizes(current, movie));
            mdhd = mdhd;
        }
        int[] tracksChunkSizes = track2ChunkSizes.get(track);
        SampleToChunkBox stsc = new SampleToChunkBox();
        stsc.setEntries(new LinkedList());
        long lastChunkSize = -2147483648L;
        int i = 0;
        while (i < tracksChunkSizes.length) {
            if (lastChunkSize != ((long) tracksChunkSizes[i])) {
                url = url2;
                decodingTimeToSampleEntries = decodingTimeToSampleEntries2;
                syncSamples = syncSamples2;
                stsc.getEntries().add(new SampleToChunkBox.Entry((long) (i + 1), (long) tracksChunkSizes[i], 1));
                lastChunkSize = (long) tracksChunkSizes[i];
            } else {
                url = url2;
                decodingTimeToSampleEntries = decodingTimeToSampleEntries2;
                syncSamples = syncSamples2;
            }
            i++;
            hdlr = hdlr;
            dinf = dinf;
            dref = dref;
            url2 = url;
            decodingTimeToSampleEntries2 = decodingTimeToSampleEntries;
            syncSamples2 = syncSamples;
        }
        stbl2.addBox(stsc);
        SampleSizeBox stsz = new SampleSizeBox();
        stsz.setSampleSizes(this.track2SampleSizes.get(track));
        stbl2.addBox(stsz);
        StaticChunkOffsetBox stco = new StaticChunkOffsetBox();
        this.chunkOffsetBoxes.add(stco);
        long[] chunkOffset = new long[tracksChunkSizes.length];
        String str2 = "Calculating chunk offsets for track_";
        if (LOG.isLoggable(Level.FINE)) {
            Logger logger = LOG;
            StringBuilder sb = new StringBuilder();
            sb.append(str2);
            offset = 0;
            sb.append(track.getTrackMetaData().getTrackId());
            logger.fine(sb.toString());
        } else {
            offset = 0;
        }
        int i2 = 0;
        long offset3 = offset;
        while (i2 < tracksChunkSizes.length) {
            if (LOG.isLoggable(Level.FINER)) {
                Logger logger2 = LOG;
                StringBuilder sb2 = new StringBuilder();
                sb2.append(str2);
                offset2 = offset3;
                sb2.append(track.getTrackMetaData().getTrackId());
                sb2.append(" chunk ");
                sb2.append(i2);
                logger2.finer(sb2.toString());
            } else {
                offset2 = offset3;
            }
            Iterator<Track> it2 = movie.getTracks().iterator();
            offset3 = offset2;
            while (it2.hasNext()) {
                Track current2 = it2.next();
                if (LOG.isLoggable(Level.FINEST)) {
                    Logger logger3 = LOG;
                    StringBuilder sb3 = new StringBuilder();
                    str = str2;
                    sb3.append("Adding offsets of track_");
                    minf = minf2;
                    stbl = stbl2;
                    sb3.append(current2.getTrackMetaData().getTrackId());
                    logger3.finest(sb3.toString());
                } else {
                    minf = minf2;
                    stbl = stbl2;
                    str = str2;
                }
                int[] chunkSizes = track2ChunkSizes.get(current2);
                long firstSampleOfChunk = 0;
                int j = 0;
                while (j < i2) {
                    firstSampleOfChunk += (long) chunkSizes[j];
                    j++;
                    trackBox = trackBox;
                    track2ChunkSizes = track2ChunkSizes;
                }
                if (current2 == track) {
                    chunkOffset[i2] = offset3;
                }
                int j2 = CastUtils.l2i(firstSampleOfChunk);
                while (((long) j2) < ((long) chunkSizes[i2]) + firstSampleOfChunk) {
                    offset3 += this.track2SampleSizes.get(current2)[j2];
                    j2++;
                    chunkSizes = chunkSizes;
                    mdia = mdia;
                }
                it2 = it2;
                stsc = stsc;
                str2 = str;
                minf2 = minf;
                stbl2 = stbl;
                trackBox = trackBox;
                track2ChunkSizes = track2ChunkSizes;
                mdia = mdia;
            }
            i2++;
            tracksChunkSizes = tracksChunkSizes;
        }
        stco.setChunkOffsets(chunkOffset);
        stbl2.addBox(stco);
        minf2.addBox(stbl2);
        mdia.addBox(minf2);
        return trackBox;
    }

    private class InterleaveChunkMdat implements Box {
        long contentSize;
        ContainerBox parent;
        List<ByteBuffer> samples;
        List<Track> tracks;

        @Override // com.coremedia.iso.boxes.Box
        public ContainerBox getParent() {
            return this.parent;
        }

        @Override // com.coremedia.iso.boxes.Box
        public void setParent(ContainerBox parent2) {
            this.parent = parent2;
        }

        @Override // com.coremedia.iso.boxes.Box
        public void parse(ReadableByteChannel readableByteChannel, ByteBuffer header, long contentSize2, BoxParser boxParser) throws IOException {
        }

        private InterleaveChunkMdat(Movie movie) {
            this.samples = new ArrayList();
            this.contentSize = 0;
            this.tracks = movie.getTracks();
            Map<Track, int[]> chunks = new HashMap<>();
            for (Track track : movie.getTracks()) {
                chunks.put(track, DefaultMp4Builder.this.getChunkSizes(track, movie));
            }
            for (int i = 0; i < chunks.values().iterator().next().length; i++) {
                for (Track track2 : this.tracks) {
                    int[] chunkSizes = chunks.get(track2);
                    long firstSampleOfChunk = 0;
                    for (int j = 0; j < i; j++) {
                        firstSampleOfChunk += (long) chunkSizes[j];
                    }
                    for (int j2 = CastUtils.l2i(firstSampleOfChunk); ((long) j2) < ((long) chunkSizes[i]) + firstSampleOfChunk; j2++) {
                        ByteBuffer s = DefaultMp4Builder.this.track2Sample.get(track2).get(j2);
                        this.contentSize += (long) s.limit();
                        this.samples.add((ByteBuffer) s.rewind());
                    }
                }
            }
        }

        public long getDataOffset() {
            Box box;
            Box b = this;
            long offset = 16;
            while (b.getParent() != null) {
                Iterator<Box> it = b.getParent().getBoxes().iterator();
                while (it.hasNext() && b != (box = it.next())) {
                    offset += box.getSize();
                }
                b = b.getParent();
            }
            return offset;
        }

        @Override // com.coremedia.iso.boxes.Box
        public String getType() {
            return MediaDataBox.TYPE;
        }

        @Override // com.coremedia.iso.boxes.Box
        public long getSize() {
            return this.contentSize + 16;
        }

        private boolean isSmallBox(long contentSize2) {
            return 8 + contentSize2 < 4294967296L;
        }

        @Override // com.coremedia.iso.boxes.Box
        public void getBox(WritableByteChannel writableByteChannel) throws IOException {
            ByteBuffer bb = ByteBuffer.allocate(16);
            long size = getSize();
            if (isSmallBox(size)) {
                IsoTypeWriter.writeUInt32(bb, size);
            } else {
                IsoTypeWriter.writeUInt32(bb, 1);
            }
            bb.put(IsoFile.fourCCtoBytes(MediaDataBox.TYPE));
            if (isSmallBox(size)) {
                bb.put(new byte[8]);
            } else {
                IsoTypeWriter.writeUInt64(bb, size);
            }
            bb.rewind();
            writableByteChannel.write(bb);
            if (writableByteChannel instanceof GatheringByteChannel) {
                List<ByteBuffer> nuSamples = DefaultMp4Builder.this.unifyAdjacentBuffers(this.samples);
                for (int i = 0; ((double) i) < Math.ceil(((double) nuSamples.size()) / ((double) DefaultMp4Builder.this.STEPSIZE)); i++) {
                    List<ByteBuffer> sublist = nuSamples.subList(DefaultMp4Builder.this.STEPSIZE * i, (i + 1) * DefaultMp4Builder.this.STEPSIZE < nuSamples.size() ? (i + 1) * DefaultMp4Builder.this.STEPSIZE : nuSamples.size());
                    ByteBuffer[] sampleArray = (ByteBuffer[]) sublist.toArray(new ByteBuffer[sublist.size()]);
                    do {
                        ((GatheringByteChannel) writableByteChannel).write(sampleArray);
                    } while (sampleArray[sampleArray.length - 1].remaining() > 0);
                }
                return;
            }
            for (ByteBuffer sample : this.samples) {
                sample.rewind();
                writableByteChannel.write(sample);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public int[] getChunkSizes(Track track, Movie movie) {
        long end;
        long[] referenceChunkStarts = this.intersectionFinder.sampleNumbers(track, movie);
        int[] chunkSizes = new int[referenceChunkStarts.length];
        for (int i = 0; i < referenceChunkStarts.length; i++) {
            long start = referenceChunkStarts[i] - 1;
            if (referenceChunkStarts.length == i + 1) {
                end = (long) track.getSamples().size();
            } else {
                end = referenceChunkStarts[i + 1] - 1;
            }
            chunkSizes[i] = CastUtils.l2i(end - start);
        }
        return chunkSizes;
    }

    private static long sum(int[] ls) {
        long rc = 0;
        for (int i : ls) {
            rc += (long) i;
        }
        return rc;
    }

    protected static long getDuration(Track track) {
        long duration = 0;
        for (TimeToSampleBox.Entry entry : track.getDecodingTimeEntries()) {
            duration += entry.getCount() * entry.getDelta();
        }
        return duration;
    }

    public long getTimescale(Movie movie) {
        long timescale = movie.getTracks().iterator().next().getTrackMetaData().getTimescale();
        for (Track track : movie.getTracks()) {
            timescale = gcd(track.getTrackMetaData().getTimescale(), timescale);
        }
        return timescale;
    }

    public static long gcd(long a, long b) {
        if (b == 0) {
            return a;
        }
        return gcd(b, a % b);
    }

    public List<ByteBuffer> unifyAdjacentBuffers(List<ByteBuffer> samples) {
        ArrayList<ByteBuffer> nuSamples = new ArrayList<>(samples.size());
        for (ByteBuffer buffer : samples) {
            int lastIndex = nuSamples.size() - 1;
            if (lastIndex >= 0 && buffer.hasArray() && nuSamples.get(lastIndex).hasArray() && buffer.array() == nuSamples.get(lastIndex).array() && nuSamples.get(lastIndex).arrayOffset() + nuSamples.get(lastIndex).limit() == buffer.arrayOffset()) {
                ByteBuffer oldBuffer = nuSamples.remove(lastIndex);
                nuSamples.add(ByteBuffer.wrap(buffer.array(), oldBuffer.arrayOffset(), oldBuffer.limit() + buffer.limit()).slice());
            } else if (lastIndex < 0 || !(buffer instanceof MappedByteBuffer) || !(nuSamples.get(lastIndex) instanceof MappedByteBuffer) || nuSamples.get(lastIndex).limit() != nuSamples.get(lastIndex).capacity() - buffer.capacity()) {
                nuSamples.add(buffer);
            } else {
                ByteBuffer oldBuffer2 = nuSamples.get(lastIndex);
                oldBuffer2.limit(buffer.limit() + oldBuffer2.limit());
            }
        }
        return nuSamples;
    }
}
