package com.googlecode.mp4parser.authoring.builder;

import com.coremedia.iso.BoxParser;
import com.coremedia.iso.IsoFile;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.ContainerBox;
import com.coremedia.iso.boxes.DataEntryUrlBox;
import com.coremedia.iso.boxes.DataInformationBox;
import com.coremedia.iso.boxes.DataReferenceBox;
import com.coremedia.iso.boxes.FileTypeBox;
import com.coremedia.iso.boxes.HandlerBox;
import com.coremedia.iso.boxes.MediaBox;
import com.coremedia.iso.boxes.MediaHeaderBox;
import com.coremedia.iso.boxes.MediaInformationBox;
import com.coremedia.iso.boxes.MovieBox;
import com.coremedia.iso.boxes.MovieHeaderBox;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleTableBox;
import com.coremedia.iso.boxes.StaticChunkOffsetBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.TrackBox;
import com.coremedia.iso.boxes.TrackHeaderBox;
import com.coremedia.iso.boxes.fragment.MovieExtendsBox;
import com.coremedia.iso.boxes.fragment.MovieExtendsHeaderBox;
import com.coremedia.iso.boxes.fragment.MovieFragmentBox;
import com.coremedia.iso.boxes.fragment.MovieFragmentHeaderBox;
import com.coremedia.iso.boxes.fragment.MovieFragmentRandomAccessBox;
import com.coremedia.iso.boxes.fragment.MovieFragmentRandomAccessOffsetBox;
import com.coremedia.iso.boxes.fragment.SampleFlags;
import com.coremedia.iso.boxes.fragment.TrackExtendsBox;
import com.coremedia.iso.boxes.fragment.TrackFragmentBox;
import com.coremedia.iso.boxes.fragment.TrackFragmentHeaderBox;
import com.coremedia.iso.boxes.fragment.TrackFragmentRandomAccessBox;
import com.coremedia.iso.boxes.fragment.TrackRunBox;
import com.coremedia.iso.boxes.mdat.MediaDataBox;
import com.coremedia.iso.boxes.sampleentry.VisualSampleEntry;
import com.googlecode.mp4parser.authoring.Movie;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.util.CastUtils;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.GatheringByteChannel;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.logging.Logger;

public class FragmentedMp4Builder implements Mp4Builder {
    private static final Logger LOG = Logger.getLogger(FragmentedMp4Builder.class.getName());
    protected FragmentIntersectionFinder intersectionFinder = new SyncSampleIntersectFinderImpl();

    public List<String> getAllowedHandlers() {
        return Arrays.asList("soun", "vide");
    }

    public Box createFtyp(Movie movie) {
        List<String> minorBrands = new LinkedList<>();
        minorBrands.add("isom");
        minorBrands.add("iso2");
        minorBrands.add(VisualSampleEntry.TYPE3);
        return new FileTypeBox("isom", 0, minorBrands);
    }

    /* access modifiers changed from: protected */
    public List<Track> sortTracksInSequence(List<Track> tracks, final int cycle, final Map<Track, long[]> intersectionMap) {
        List<Track> tracks2 = new LinkedList<>(tracks);
        Collections.sort(tracks2, new Comparator<Track>() {
            /* class com.googlecode.mp4parser.authoring.builder.FragmentedMp4Builder.AnonymousClass1 */

            public int compare(Track o1, Track o2) {
                long[] startSamples1 = (long[]) intersectionMap.get(o1);
                int i = cycle;
                long startSample1 = startSamples1[i];
                long endSample1 = i + 1 < startSamples1.length ? startSamples1[i + 1] : (long) (o1.getSamples().size() + 1);
                long[] startSamples2 = (long[]) intersectionMap.get(o2);
                int i2 = cycle;
                long startSample2 = startSamples2[i2];
                long endSample2 = i2 + 1 < startSamples2.length ? startSamples2[i2 + 1] : (long) (o2.getSamples().size() + 1);
                List<ByteBuffer> samples1 = o1.getSamples().subList(CastUtils.l2i(startSample1) - 1, CastUtils.l2i(endSample1) - 1);
                List<ByteBuffer> samples2 = o2.getSamples().subList(CastUtils.l2i(startSample2) - 1, CastUtils.l2i(endSample2) - 1);
                int size1 = 0;
                for (ByteBuffer byteBuffer : samples1) {
                    size1 += byteBuffer.limit();
                }
                int size2 = 0;
                for (ByteBuffer byteBuffer2 : samples2) {
                    size2 += byteBuffer2.limit();
                }
                return size1 - size2;
            }
        });
        return tracks2;
    }

    /* access modifiers changed from: protected */
    public List<Box> createMoofMdat(Movie movie) {
        List<Box> boxes = new LinkedList<>();
        HashMap<Track, long[]> intersectionMap = new HashMap<>();
        int maxNumberOfFragments = 0;
        for (Track track : movie.getTracks()) {
            long[] intersects = this.intersectionFinder.sampleNumbers(track, movie);
            intersectionMap.put(track, intersects);
            maxNumberOfFragments = Math.max(maxNumberOfFragments, intersects.length);
        }
        int sequence = 1;
        int cycle = 0;
        while (cycle < maxNumberOfFragments) {
            int sequence2 = sequence;
            for (Track track2 : sortTracksInSequence(movie.getTracks(), cycle, intersectionMap)) {
                if (getAllowedHandlers().isEmpty() || getAllowedHandlers().contains(track2.getHandler())) {
                    long[] startSamples = intersectionMap.get(track2);
                    if (cycle < startSamples.length) {
                        long startSample = startSamples[cycle];
                        long endSample = cycle + 1 < startSamples.length ? startSamples[cycle + 1] : (long) (track2.getSamples().size() + 1);
                        if (startSample != endSample) {
                            boxes.add(createMoof(startSample, endSample, track2, sequence2));
                            boxes.add(createMdat(startSample, endSample, track2, sequence2));
                            sequence2++;
                        }
                    }
                }
            }
            cycle++;
            sequence = sequence2;
        }
        return boxes;
    }

    @Override // com.googlecode.mp4parser.authoring.builder.Mp4Builder
    public IsoFile build(Movie movie) {
        Logger logger = LOG;
        logger.fine("Creating movie " + movie);
        IsoFile isoFile = new IsoFile();
        isoFile.addBox(createFtyp(movie));
        isoFile.addBox(createMoov(movie));
        for (Box box : createMoofMdat(movie)) {
            isoFile.addBox(box);
        }
        isoFile.addBox(createMfra(movie, isoFile));
        return isoFile;
    }

    /* access modifiers changed from: protected */
    public Box createMdat(final long startSample, final long endSample, final Track track, final int i) {
        return new Box() {
            /* class com.googlecode.mp4parser.authoring.builder.FragmentedMp4Builder.AnonymousClass1Mdat */
            ContainerBox parent;

            @Override // com.coremedia.iso.boxes.Box
            public ContainerBox getParent() {
                return this.parent;
            }

            @Override // com.coremedia.iso.boxes.Box
            public void setParent(ContainerBox parent2) {
                this.parent = parent2;
            }

            @Override // com.coremedia.iso.boxes.Box
            public long getSize() {
                long size = 8;
                for (ByteBuffer sample : FragmentedMp4Builder.this.getSamples(startSample, endSample, track, i)) {
                    size += (long) sample.limit();
                }
                return size;
            }

            @Override // com.coremedia.iso.boxes.Box
            public String getType() {
                return MediaDataBox.TYPE;
            }

            @Override // com.coremedia.iso.boxes.Box
            public void getBox(WritableByteChannel writableByteChannel) throws IOException {
                List<ByteBuffer> samples = ByteBufferHelper.mergeAdjacentBuffers(FragmentedMp4Builder.this.getSamples(startSample, endSample, track, i));
                ByteBuffer header = ByteBuffer.allocate(8);
                IsoTypeWriter.writeUInt32(header, (long) CastUtils.l2i(getSize()));
                header.put(IsoFile.fourCCtoBytes(getType()));
                header.rewind();
                writableByteChannel.write(header);
                if (writableByteChannel instanceof GatheringByteChannel) {
                    for (int i = 0; ((double) i) < Math.ceil(((double) samples.size()) / ((double) 1024)); i++) {
                        List<ByteBuffer> sublist = samples.subList(i * 1024, (i + 1) * 1024 < samples.size() ? (i + 1) * 1024 : samples.size());
                        ByteBuffer[] sampleArray = (ByteBuffer[]) sublist.toArray(new ByteBuffer[sublist.size()]);
                        do {
                            ((GatheringByteChannel) writableByteChannel).write(sampleArray);
                        } while (sampleArray[sampleArray.length - 1].remaining() > 0);
                    }
                    return;
                }
                for (ByteBuffer sample : samples) {
                    sample.rewind();
                    writableByteChannel.write(sample);
                }
            }

            @Override // com.coremedia.iso.boxes.Box
            public void parse(ReadableByteChannel readableByteChannel, ByteBuffer header, long contentSize, BoxParser boxParser) throws IOException {
            }
        };
    }

    /* access modifiers changed from: protected */
    public Box createTfhd(long startSample, long endSample, Track track, int sequenceNumber) {
        TrackFragmentHeaderBox tfhd = new TrackFragmentHeaderBox();
        tfhd.setDefaultSampleFlags(new SampleFlags());
        tfhd.setBaseDataOffset(-1);
        tfhd.setTrackId(track.getTrackMetaData().getTrackId());
        return tfhd;
    }

    /* access modifiers changed from: protected */
    public Box createMfhd(long startSample, long endSample, Track track, int sequenceNumber) {
        MovieFragmentHeaderBox mfhd = new MovieFragmentHeaderBox();
        mfhd.setSequenceNumber((long) sequenceNumber);
        return mfhd;
    }

    /* access modifiers changed from: protected */
    public Box createTraf(long startSample, long endSample, Track track, int sequenceNumber) {
        TrackFragmentBox traf = new TrackFragmentBox();
        traf.addBox(createTfhd(startSample, endSample, track, sequenceNumber));
        for (Box trun : createTruns(startSample, endSample, track, sequenceNumber)) {
            traf.addBox(trun);
        }
        return traf;
    }

    /* access modifiers changed from: protected */
    public List<ByteBuffer> getSamples(long startSample, long endSample, Track track, int sequenceNumber) {
        return track.getSamples().subList(CastUtils.l2i(startSample) - 1, CastUtils.l2i(endSample) - 1);
    }

    /* access modifiers changed from: protected */
    public long[] getSampleSizes(long startSample, long endSample, Track track, int sequenceNumber) {
        List<ByteBuffer> samples = getSamples(startSample, endSample, track, sequenceNumber);
        long[] sampleSizes = new long[samples.size()];
        for (int i = 0; i < sampleSizes.length; i++) {
            sampleSizes[i] = (long) samples.get(i).limit();
        }
        return sampleSizes;
    }

    /* access modifiers changed from: protected */
    public List<? extends Box> createTruns(long startSample, long endSample, Track track, int sequenceNumber) {
        long left;
        long j;
        TrackRunBox trun = new TrackRunBox();
        long[] sampleSizes = getSampleSizes(startSample, endSample, track, sequenceNumber);
        trun.setSampleDurationPresent(true);
        trun.setSampleSizePresent(true);
        List<TrackRunBox.Entry> entries = new ArrayList<>(CastUtils.l2i(endSample - startSample));
        Queue<TimeToSampleBox.Entry> timeQueue = new LinkedList<>(track.getDecodingTimeEntries());
        long left2 = startSample - 1;
        long curEntryLeft = timeQueue.peek().getCount();
        while (left2 > curEntryLeft) {
            left2 -= curEntryLeft;
            timeQueue.remove();
            curEntryLeft = timeQueue.peek().getCount();
        }
        long curEntryLeft2 = curEntryLeft - left2;
        Queue<CompositionTimeToSample.Entry> compositionTimeQueue = (track.getCompositionTimeEntries() == null || track.getCompositionTimeEntries().size() <= 0) ? null : new LinkedList<>(track.getCompositionTimeEntries());
        long compositionTimeEntriesLeft = compositionTimeQueue != null ? (long) compositionTimeQueue.peek().getCount() : -1;
        trun.setSampleCompositionTimeOffsetPresent(compositionTimeEntriesLeft > 0);
        for (long i = 1; i < startSample; i++) {
            if (compositionTimeQueue != null) {
                long j2 = compositionTimeEntriesLeft - 1;
                compositionTimeEntriesLeft = j2;
                if (j2 == 0 && compositionTimeQueue.size() > 1) {
                    compositionTimeQueue.remove();
                    compositionTimeEntriesLeft = (long) compositionTimeQueue.element().getCount();
                }
            }
        }
        boolean sampleFlagsRequired = (track.getSampleDependencies() != null && !track.getSampleDependencies().isEmpty()) || !(track.getSyncSamples() == null || track.getSyncSamples().length == 0);
        trun.setSampleFlagsPresent(sampleFlagsRequired);
        int i2 = 0;
        while (i2 < sampleSizes.length) {
            TrackRunBox.Entry entry = new TrackRunBox.Entry();
            entry.setSampleSize(sampleSizes[i2]);
            if (sampleFlagsRequired) {
                SampleFlags sflags = new SampleFlags();
                if (track.getSampleDependencies() != null && !track.getSampleDependencies().isEmpty()) {
                    SampleDependencyTypeBox.Entry e = track.getSampleDependencies().get(i2);
                    sflags.setSampleDependsOn(e.getSampleDependsOn());
                    sflags.setSampleIsDependedOn(e.getSampleIsDependentOn());
                    sflags.setSampleHasRedundancy(e.getSampleHasRedundancy());
                }
                if (track.getSyncSamples() == null || track.getSyncSamples().length <= 0) {
                    left = left2;
                } else {
                    left = left2;
                    if (Arrays.binarySearch(track.getSyncSamples(), startSample + ((long) i2)) >= 0) {
                        sflags.setSampleIsDifferenceSample(false);
                        sflags.setSampleDependsOn(2);
                    } else {
                        sflags.setSampleIsDifferenceSample(true);
                        sflags.setSampleDependsOn(1);
                    }
                }
                entry.setSampleFlags(sflags);
            } else {
                left = left2;
            }
            entry.setSampleDuration(timeQueue.peek().getDelta());
            long curEntryLeft3 = curEntryLeft2 - 1;
            if (curEntryLeft3 != 0 || timeQueue.size() <= 1) {
                curEntryLeft2 = curEntryLeft3;
            } else {
                timeQueue.remove();
                curEntryLeft2 = timeQueue.peek().getCount();
            }
            if (compositionTimeQueue != null) {
                entry.setSampleCompositionTimeOffset(compositionTimeQueue.peek().getOffset());
                j = 1;
                long j3 = compositionTimeEntriesLeft - 1;
                compositionTimeEntriesLeft = j3;
                if (j3 == 0) {
                    if (compositionTimeQueue.size() > 1) {
                        compositionTimeQueue.remove();
                        compositionTimeEntriesLeft = (long) compositionTimeQueue.element().getCount();
                    }
                }
            } else {
                j = 1;
            }
            entries.add(entry);
            i2++;
            entries = entries;
            left2 = left;
        }
        trun.setEntries(entries);
        return Collections.singletonList(trun);
    }

    /* access modifiers changed from: protected */
    public Box createMoof(long startSample, long endSample, Track track, int sequenceNumber) {
        MovieFragmentBox moof = new MovieFragmentBox();
        moof.addBox(createMfhd(startSample, endSample, track, sequenceNumber));
        moof.addBox(createTraf(startSample, endSample, track, sequenceNumber));
        TrackRunBox firstTrun = moof.getTrackRunBoxes().get(0);
        firstTrun.setDataOffset(1);
        firstTrun.setDataOffset((int) (moof.getSize() + 8));
        return moof;
    }

    /* access modifiers changed from: protected */
    public Box createMvhd(Movie movie) {
        MovieHeaderBox mvhd = new MovieHeaderBox();
        mvhd.setVersion(1);
        mvhd.setCreationTime(new Date());
        mvhd.setModificationTime(new Date());
        long movieTimeScale = movie.getTimescale();
        long duration = 0;
        for (Track track : movie.getTracks()) {
            long tracksDuration = (getDuration(track) * movieTimeScale) / track.getTrackMetaData().getTimescale();
            if (tracksDuration > duration) {
                duration = tracksDuration;
            }
        }
        mvhd.setDuration(duration);
        mvhd.setTimescale(movieTimeScale);
        long nextTrackId = 0;
        for (Track track2 : movie.getTracks()) {
            nextTrackId = nextTrackId < track2.getTrackMetaData().getTrackId() ? track2.getTrackMetaData().getTrackId() : nextTrackId;
        }
        mvhd.setNextTrackId(1 + nextTrackId);
        return mvhd;
    }

    /* access modifiers changed from: protected */
    public Box createMoov(Movie movie) {
        MovieBox movieBox = new MovieBox();
        movieBox.addBox(createMvhd(movie));
        movieBox.addBox(createMvex(movie));
        for (Track track : movie.getTracks()) {
            movieBox.addBox(createTrak(track, movie));
        }
        return movieBox;
    }

    /* JADX INFO: Multiple debug info for r2v17 'offset2timeEntriesThisTrun'  java.util.List<com.coremedia.iso.boxes.fragment.TrackFragmentRandomAccessBox$Entry>: [D('trunEntry' com.coremedia.iso.boxes.fragment.TrackRunBox$Entry), D('offset2timeEntriesThisTrun' java.util.List<com.coremedia.iso.boxes.fragment.TrackFragmentRandomAccessBox$Entry>)] */
    /* access modifiers changed from: protected */
    public Box createTfra(Track track, IsoFile isoFile) {
        TrackFragmentRandomAccessBox tfra;
        Iterator<Box> it;
        List<Box> boxes;
        TrackFragmentRandomAccessBox tfra2;
        Iterator<Box> it2;
        List<Box> boxes2;
        Iterator<Box> it3;
        List<TrackFragmentRandomAccessBox.Entry> offset2timeEntriesThisTrun;
        SampleFlags sf;
        Box box;
        int i;
        List<TrackFragmentBox> trafs;
        List<TrackRunBox> truns;
        TrackFragmentBox traf;
        TrackRunBox.Entry trunEntry;
        int j;
        int k;
        List<TrackFragmentRandomAccessBox.Entry> offset2timeEntries;
        TrackFragmentRandomAccessBox tfra3;
        List<TrackFragmentRandomAccessBox.Entry> offset2timeEntriesThisTrun2;
        TrackFragmentRandomAccessBox tfra4 = new TrackFragmentRandomAccessBox();
        tfra4.setVersion(1);
        List<TrackFragmentRandomAccessBox.Entry> offset2timeEntries2 = new LinkedList<>();
        List<Box> boxes3 = isoFile.getBoxes();
        long offset = 0;
        long duration = 0;
        Iterator<Box> it4 = boxes3.iterator();
        while (it4.hasNext()) {
            Box box2 = it4.next();
            if (box2 instanceof MovieFragmentBox) {
                List<TrackFragmentBox> trafs2 = ((MovieFragmentBox) box2).getBoxes(TrackFragmentBox.class);
                int i2 = 0;
                while (i2 < trafs2.size()) {
                    TrackFragmentBox traf2 = trafs2.get(i2);
                    if (traf2.getTrackFragmentHeaderBox().getTrackId() == track.getTrackMetaData().getTrackId()) {
                        List<TrackRunBox> truns2 = traf2.getBoxes(TrackRunBox.class);
                        int j2 = 0;
                        while (j2 < truns2.size()) {
                            List<TrackFragmentRandomAccessBox.Entry> offset2timeEntriesThisTrun3 = new LinkedList<>();
                            TrackRunBox trun = truns2.get(j2);
                            int k2 = 0;
                            while (k2 < trun.getEntries().size()) {
                                TrackRunBox.Entry trunEntry2 = trun.getEntries().get(k2);
                                SampleFlags sf2 = null;
                                if (k2 == 0 && trun.isFirstSampleFlagsPresent()) {
                                    it3 = it4;
                                    offset2timeEntriesThisTrun = offset2timeEntriesThisTrun3;
                                    sf = trun.getFirstSampleFlags();
                                } else if (trun.isSampleFlagsPresent()) {
                                    it3 = it4;
                                    offset2timeEntriesThisTrun = offset2timeEntriesThisTrun3;
                                    sf = trunEntry2.getSampleFlags();
                                } else {
                                    it3 = it4;
                                    offset2timeEntriesThisTrun = offset2timeEntriesThisTrun3;
                                    List<MovieExtendsBox> mvexs = isoFile.getMovieBox().getBoxes(MovieExtendsBox.class);
                                    Iterator<MovieExtendsBox> it5 = mvexs.iterator();
                                    while (it5.hasNext()) {
                                        for (TrackExtendsBox trex : it5.next().getBoxes(TrackExtendsBox.class)) {
                                            if (trex.getTrackId() == track.getTrackMetaData().getTrackId()) {
                                                sf2 = trex.getDefaultSampleFlags();
                                            }
                                        }
                                        it5 = it5;
                                        mvexs = mvexs;
                                    }
                                    sf = sf2;
                                }
                                if (sf != null) {
                                    if (sf.getSampleDependsOn() == 2) {
                                        tfra3 = tfra4;
                                        offset2timeEntries = offset2timeEntries2;
                                        k = k2;
                                        trunEntry = trunEntry2;
                                        j = j2;
                                        offset2timeEntriesThisTrun2 = offset2timeEntriesThisTrun;
                                        traf = traf2;
                                        truns = truns2;
                                        trafs = trafs2;
                                        i = i2;
                                        box = box2;
                                        offset2timeEntriesThisTrun2.add(new TrackFragmentRandomAccessBox.Entry(duration, offset, (long) (i2 + 1), (long) (j2 + 1), (long) (k2 + 1)));
                                    } else {
                                        tfra3 = tfra4;
                                        offset2timeEntries = offset2timeEntries2;
                                        trunEntry = trunEntry2;
                                        k = k2;
                                        j = j2;
                                        traf = traf2;
                                        truns = truns2;
                                        trafs = trafs2;
                                        i = i2;
                                        box = box2;
                                        offset2timeEntriesThisTrun2 = offset2timeEntriesThisTrun;
                                    }
                                    duration += trunEntry.getSampleDuration();
                                    k2 = k + 1;
                                    offset2timeEntriesThisTrun3 = offset2timeEntriesThisTrun2;
                                    boxes3 = boxes3;
                                    it4 = it3;
                                    tfra4 = tfra3;
                                    offset2timeEntries2 = offset2timeEntries;
                                    j2 = j;
                                    traf2 = traf;
                                    truns2 = truns;
                                    trafs2 = trafs;
                                    i2 = i;
                                    box2 = box;
                                } else {
                                    throw new RuntimeException("Could not find any SampleFlags to indicate random access or not");
                                }
                            }
                            if (offset2timeEntriesThisTrun3.size() != trun.getEntries().size() || trun.getEntries().size() <= 0) {
                                offset2timeEntries2 = offset2timeEntries2;
                                offset2timeEntries2.addAll(offset2timeEntriesThisTrun3);
                            } else {
                                offset2timeEntries2 = offset2timeEntries2;
                                offset2timeEntries2.add(offset2timeEntriesThisTrun3.get(0));
                            }
                            j2++;
                            boxes3 = boxes3;
                            it4 = it4;
                            tfra4 = tfra4;
                            traf2 = traf2;
                            truns2 = truns2;
                            trafs2 = trafs2;
                            i2 = i2;
                            box2 = box2;
                        }
                        tfra2 = tfra4;
                        boxes2 = boxes3;
                        it2 = it4;
                    } else {
                        tfra2 = tfra4;
                        boxes2 = boxes3;
                        it2 = it4;
                    }
                    i2++;
                    boxes3 = boxes2;
                    it4 = it2;
                    tfra4 = tfra2;
                    trafs2 = trafs2;
                    box2 = box2;
                }
                tfra = tfra4;
                boxes = boxes3;
                it = it4;
            } else {
                tfra = tfra4;
                boxes = boxes3;
                it = it4;
            }
            offset += box2.getSize();
            boxes3 = boxes;
            it4 = it;
            tfra4 = tfra;
        }
        tfra4.setEntries(offset2timeEntries2);
        tfra4.setTrackId(track.getTrackMetaData().getTrackId());
        return tfra4;
    }

    /* access modifiers changed from: protected */
    public Box createMfra(Movie movie, IsoFile isoFile) {
        MovieFragmentRandomAccessBox mfra = new MovieFragmentRandomAccessBox();
        for (Track track : movie.getTracks()) {
            mfra.addBox(createTfra(track, isoFile));
        }
        MovieFragmentRandomAccessOffsetBox mfro = new MovieFragmentRandomAccessOffsetBox();
        mfra.addBox(mfro);
        mfro.setMfraSize(mfra.getSize());
        return mfra;
    }

    /* access modifiers changed from: protected */
    public Box createTrex(Movie movie, Track track) {
        TrackExtendsBox trex = new TrackExtendsBox();
        trex.setTrackId(track.getTrackMetaData().getTrackId());
        trex.setDefaultSampleDescriptionIndex(1);
        trex.setDefaultSampleDuration(0);
        trex.setDefaultSampleSize(0);
        SampleFlags sf = new SampleFlags();
        if ("soun".equals(track.getHandler())) {
            sf.setSampleDependsOn(2);
            sf.setSampleIsDependedOn(2);
        }
        trex.setDefaultSampleFlags(sf);
        return trex;
    }

    /* access modifiers changed from: protected */
    public Box createMvex(Movie movie) {
        MovieExtendsBox mvex = new MovieExtendsBox();
        MovieExtendsHeaderBox mved = new MovieExtendsHeaderBox();
        for (Track track : movie.getTracks()) {
            long trackDuration = getTrackDuration(movie, track);
            if (mved.getFragmentDuration() < trackDuration) {
                mved.setFragmentDuration(trackDuration);
            }
        }
        mvex.addBox(mved);
        for (Track track2 : movie.getTracks()) {
            mvex.addBox(createTrex(movie, track2));
        }
        return mvex;
    }

    /* access modifiers changed from: protected */
    public Box createTkhd(Movie movie, Track track) {
        TrackHeaderBox tkhd = new TrackHeaderBox();
        tkhd.setVersion(1);
        int flags = 0;
        if (track.isEnabled()) {
            flags = 0 + 1;
        }
        if (track.isInMovie()) {
            flags += 2;
        }
        if (track.isInPreview()) {
            flags += 4;
        }
        if (track.isInPoster()) {
            flags += 8;
        }
        tkhd.setFlags(flags);
        tkhd.setAlternateGroup(track.getTrackMetaData().getGroup());
        tkhd.setCreationTime(track.getTrackMetaData().getCreationTime());
        tkhd.setDuration(getTrackDuration(movie, track));
        tkhd.setHeight(track.getTrackMetaData().getHeight());
        tkhd.setWidth(track.getTrackMetaData().getWidth());
        tkhd.setLayer(track.getTrackMetaData().getLayer());
        tkhd.setModificationTime(new Date());
        tkhd.setTrackId(track.getTrackMetaData().getTrackId());
        tkhd.setVolume(track.getTrackMetaData().getVolume());
        return tkhd;
    }

    private long getTrackDuration(Movie movie, Track track) {
        return (getDuration(track) * movie.getTimescale()) / track.getTrackMetaData().getTimescale();
    }

    /* access modifiers changed from: protected */
    public Box createMdhd(Movie movie, Track track) {
        MediaHeaderBox mdhd = new MediaHeaderBox();
        mdhd.setCreationTime(track.getTrackMetaData().getCreationTime());
        mdhd.setDuration(getDuration(track));
        mdhd.setTimescale(track.getTrackMetaData().getTimescale());
        mdhd.setLanguage(track.getTrackMetaData().getLanguage());
        return mdhd;
    }

    /* access modifiers changed from: protected */
    public Box createStbl(Movie movie, Track track) {
        SampleTableBox stbl = new SampleTableBox();
        stbl.addBox(track.getSampleDescriptionBox());
        stbl.addBox(new TimeToSampleBox());
        stbl.addBox(new StaticChunkOffsetBox());
        return stbl;
    }

    /* access modifiers changed from: protected */
    public Box createMinf(Track track, Movie movie) {
        MediaInformationBox minf = new MediaInformationBox();
        minf.addBox(track.getMediaHeaderBox());
        minf.addBox(createDinf(movie, track));
        minf.addBox(createStbl(movie, track));
        return minf;
    }

    /* access modifiers changed from: protected */
    public Box createMdiaHdlr(Track track, Movie movie) {
        HandlerBox hdlr = new HandlerBox();
        hdlr.setHandlerType(track.getHandler());
        return hdlr;
    }

    /* access modifiers changed from: protected */
    public Box createMdia(Track track, Movie movie) {
        MediaBox mdia = new MediaBox();
        mdia.addBox(createMdhd(movie, track));
        mdia.addBox(createMdiaHdlr(track, movie));
        mdia.addBox(createMinf(track, movie));
        return mdia;
    }

    /* access modifiers changed from: protected */
    public Box createTrak(Track track, Movie movie) {
        Logger logger = LOG;
        logger.fine("Creating Track " + track);
        TrackBox trackBox = new TrackBox();
        trackBox.addBox(createTkhd(movie, track));
        trackBox.addBox(createMdia(track, movie));
        return trackBox;
    }

    /* access modifiers changed from: protected */
    public DataInformationBox createDinf(Movie movie, Track track) {
        DataInformationBox dinf = new DataInformationBox();
        DataReferenceBox dref = new DataReferenceBox();
        dinf.addBox(dref);
        DataEntryUrlBox url = new DataEntryUrlBox();
        url.setFlags(1);
        dref.addBox(url);
        return dinf;
    }

    public FragmentIntersectionFinder getFragmentIntersectionFinder() {
        return this.intersectionFinder;
    }

    public void setIntersectionFinder(FragmentIntersectionFinder intersectionFinder2) {
        this.intersectionFinder = intersectionFinder2;
    }

    /* access modifiers changed from: protected */
    public long getDuration(Track track) {
        long duration = 0;
        for (TimeToSampleBox.Entry entry : track.getDecodingTimeEntries()) {
            duration += entry.getCount() * entry.getDelta();
        }
        return duration;
    }
}
