package com.googlecode.mp4parser.authoring.tracks;

import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleDescriptionBox;
import com.coremedia.iso.boxes.SubSampleInformationBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.authoring.TrackMetaData;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;
import java.util.logging.Logger;

public class ChangeTimeScaleTrack implements Track {
    private static final Logger LOG = Logger.getLogger(ChangeTimeScaleTrack.class.getName());
    List<CompositionTimeToSample.Entry> ctts;
    Track source;
    long timeScale;
    List<TimeToSampleBox.Entry> tts;

    public ChangeTimeScaleTrack(Track source2, long targetTimeScale, long[] syncSamples) {
        this.source = source2;
        this.timeScale = targetTimeScale;
        double timeScaleFactor = ((double) targetTimeScale) / ((double) source2.getTrackMetaData().getTimescale());
        this.ctts = adjustCtts(source2.getCompositionTimeEntries(), timeScaleFactor);
        this.tts = adjustTts(source2.getDecodingTimeEntries(), timeScaleFactor, syncSamples, getTimes(source2, syncSamples, targetTimeScale));
    }

    private static long[] getTimes(Track track, long[] syncSamples, long targetTimeScale) {
        long[] syncSampleTimes = new long[syncSamples.length];
        Queue<TimeToSampleBox.Entry> timeQueue = new LinkedList<>(track.getDecodingTimeEntries());
        int currentSample = 1;
        long currentDuration = 0;
        long currentDelta = 0;
        int currentSyncSampleIndex = 0;
        long left = 0;
        while (((long) currentSample) <= syncSamples[syncSamples.length - 1]) {
            int currentSample2 = currentSample + 1;
            if (((long) currentSample) == syncSamples[currentSyncSampleIndex]) {
                syncSampleTimes[currentSyncSampleIndex] = (currentDuration * targetTimeScale) / track.getTrackMetaData().getTimescale();
                currentSyncSampleIndex++;
            }
            long left2 = left - 1;
            if (left == 0) {
                TimeToSampleBox.Entry entry = timeQueue.poll();
                left = entry.getCount() - 1;
                currentDelta = entry.getDelta();
            } else {
                left = left2;
            }
            currentDuration += currentDelta;
            currentSample = currentSample2;
        }
        return syncSampleTimes;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SampleDescriptionBox getSampleDescriptionBox() {
        return this.source.getSampleDescriptionBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<TimeToSampleBox.Entry> getDecodingTimeEntries() {
        return this.tts;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<CompositionTimeToSample.Entry> getCompositionTimeEntries() {
        return this.ctts;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public long[] getSyncSamples() {
        return this.source.getSyncSamples();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<SampleDependencyTypeBox.Entry> getSampleDependencies() {
        return this.source.getSampleDependencies();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public TrackMetaData getTrackMetaData() {
        TrackMetaData trackMetaData = (TrackMetaData) this.source.getTrackMetaData().clone();
        trackMetaData.setTimescale(this.timeScale);
        return trackMetaData;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public String getHandler() {
        return this.source.getHandler();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public boolean isEnabled() {
        return this.source.isEnabled();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public boolean isInMovie() {
        return this.source.isInMovie();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public boolean isInPreview() {
        return this.source.isInPreview();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public boolean isInPoster() {
        return this.source.isInPoster();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<ByteBuffer> getSamples() {
        return this.source.getSamples();
    }

    static List<CompositionTimeToSample.Entry> adjustCtts(List<CompositionTimeToSample.Entry> source2, double timeScaleFactor) {
        if (source2 == null) {
            return null;
        }
        List<CompositionTimeToSample.Entry> entries2 = new ArrayList<>(source2.size());
        for (CompositionTimeToSample.Entry entry : source2) {
            entries2.add(new CompositionTimeToSample.Entry(entry.getCount(), (int) Math.round(((double) entry.getOffset()) * timeScaleFactor)));
        }
        return entries2;
    }

    static List<TimeToSampleBox.Entry> adjustTts(List<TimeToSampleBox.Entry> source2, double timeScaleFactor, long[] syncSample, long[] syncSampleTimes) {
        long[] sourceArray;
        long[] sourceArray2 = TimeToSampleBox.blowupTimeToSamples(source2);
        long summedDurations = 0;
        LinkedList<TimeToSampleBox.Entry> entries2 = new LinkedList<>();
        int i = 1;
        while (i <= sourceArray2.length) {
            long x = Math.round(((double) sourceArray2[i - 1]) * timeScaleFactor);
            TimeToSampleBox.Entry last = entries2.peekLast();
            int ssIndex = Arrays.binarySearch(syncSample, (long) (i + 1));
            if (ssIndex < 0) {
                sourceArray = sourceArray2;
            } else if (syncSampleTimes[ssIndex] != summedDurations) {
                long correction = syncSampleTimes[ssIndex] - (summedDurations + x);
                sourceArray = sourceArray2;
                LOG.finest(String.format("Sample %d %d / %d - correct by %d", Integer.valueOf(i), Long.valueOf(summedDurations), Long.valueOf(syncSampleTimes[ssIndex]), Long.valueOf(correction)));
                x += correction;
            } else {
                sourceArray = sourceArray2;
            }
            summedDurations += x;
            if (last == null) {
                entries2.add(new TimeToSampleBox.Entry(1, x));
            } else if (last.getDelta() != x) {
                entries2.add(new TimeToSampleBox.Entry(1, x));
            } else {
                last.setCount(last.getCount() + 1);
            }
            i++;
            sourceArray2 = sourceArray;
        }
        return entries2;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public Box getMediaHeaderBox() {
        return this.source.getMediaHeaderBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SubSampleInformationBox getSubsampleInformationBox() {
        return this.source.getSubsampleInformationBox();
    }

    public String toString() {
        return "ChangeTimeScaleTrack{source=" + this.source + Operators.BLOCK_END;
    }
}
