package com.googlecode.mp4parser.boxes.piff;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.taobao.weex.el.parse.Operators;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class PlayReadyHeader extends ProtectionSpecificHeader {
    private long length;
    private List<PlayReadyRecord> records;

    @Override // com.googlecode.mp4parser.boxes.piff.ProtectionSpecificHeader
    public void parse(ByteBuffer byteBuffer) {
        this.length = IsoTypeReader.readUInt32BE(byteBuffer);
        this.records = PlayReadyRecord.createFor(byteBuffer, IsoTypeReader.readUInt16BE(byteBuffer));
    }

    @Override // com.googlecode.mp4parser.boxes.piff.ProtectionSpecificHeader
    public ByteBuffer getData() {
        int size = 6;
        for (PlayReadyRecord record : this.records) {
            size = size + 4 + record.getValue().rewind().limit();
        }
        ByteBuffer byteBuffer = ByteBuffer.allocate(size);
        IsoTypeWriter.writeUInt32BE(byteBuffer, (long) size);
        IsoTypeWriter.writeUInt16BE(byteBuffer, this.records.size());
        for (PlayReadyRecord record2 : this.records) {
            IsoTypeWriter.writeUInt16BE(byteBuffer, record2.type);
            IsoTypeWriter.writeUInt16BE(byteBuffer, record2.getValue().limit());
            byteBuffer.put(record2.getValue());
        }
        return byteBuffer;
    }

    public void setRecords(List<PlayReadyRecord> records2) {
        this.records = records2;
    }

    public List<PlayReadyRecord> getRecords() {
        return Collections.unmodifiableList(this.records);
    }

    @Override // com.googlecode.mp4parser.boxes.piff.ProtectionSpecificHeader
    public String toString() {
        return "PlayReadyHeader" + "{length=" + this.length + ", recordCount=" + this.records.size() + ", records=" + this.records + Operators.BLOCK_END;
    }

    public static abstract class PlayReadyRecord {
        int type;

        public abstract ByteBuffer getValue();

        public abstract void parse(ByteBuffer byteBuffer);

        public PlayReadyRecord(int type2) {
            this.type = type2;
        }

        public static List<PlayReadyRecord> createFor(ByteBuffer byteBuffer, int recordCount) {
            PlayReadyRecord record;
            List<PlayReadyRecord> records = new ArrayList<>(recordCount);
            for (int i = 0; i < recordCount; i++) {
                int type2 = IsoTypeReader.readUInt16BE(byteBuffer);
                int length = IsoTypeReader.readUInt16BE(byteBuffer);
                if (type2 == 1) {
                    record = new RMHeader();
                } else if (type2 == 2) {
                    record = new DefaulPlayReadyRecord(2);
                } else if (type2 != 3) {
                    record = new DefaulPlayReadyRecord(type2);
                } else {
                    record = new EmeddedLicenseStore();
                }
                record.parse((ByteBuffer) byteBuffer.slice().limit(length));
                byteBuffer.position(byteBuffer.position() + length);
                records.add(record);
            }
            return records;
        }

        public String toString() {
            return "PlayReadyRecord" + "{type=" + this.type + ", length=" + getValue().limit() + Operators.BLOCK_END;
        }

        public static class RMHeader extends PlayReadyRecord {
            String header;

            public RMHeader() {
                super(1);
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public void parse(ByteBuffer bytes) {
                try {
                    byte[] str = new byte[bytes.slice().limit()];
                    bytes.get(str);
                    this.header = new String(str, "UTF-16LE");
                } catch (UnsupportedEncodingException e) {
                    throw new RuntimeException(e);
                }
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public ByteBuffer getValue() {
                try {
                    return ByteBuffer.wrap(this.header.getBytes("UTF-16LE"));
                } catch (UnsupportedEncodingException e) {
                    throw new RuntimeException(e);
                }
            }

            public void setHeader(String header2) {
                this.header = header2;
            }

            public String getHeader() {
                return this.header;
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public String toString() {
                return "RMHeader" + "{length=" + getValue().limit() + ", header='" + this.header + Operators.SINGLE_QUOTE + Operators.BLOCK_END;
            }
        }

        public static class EmeddedLicenseStore extends PlayReadyRecord {
            ByteBuffer value;

            public EmeddedLicenseStore() {
                super(3);
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public void parse(ByteBuffer bytes) {
                this.value = bytes.duplicate();
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public ByteBuffer getValue() {
                return this.value;
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public String toString() {
                return "EmeddedLicenseStore" + "{length=" + getValue().limit() + Operators.BLOCK_END;
            }
        }

        public static class DefaulPlayReadyRecord extends PlayReadyRecord {
            ByteBuffer value;

            public DefaulPlayReadyRecord(int type) {
                super(type);
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public void parse(ByteBuffer bytes) {
                this.value = bytes.duplicate();
            }

            @Override // com.googlecode.mp4parser.boxes.piff.PlayReadyHeader.PlayReadyRecord
            public ByteBuffer getValue() {
                return this.value;
            }
        }
    }
}
