package com.taobao.weex.adapter;

import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.tencent.connect.common.Constants;
import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class DefaultWXHttpAdapter implements IWXHttpAdapter {
    private static final IEventReporterDelegate DEFAULT_DELEGATE = new NOPEventReportDelegate();
    private ExecutorService mExecutorService;

    public interface IEventReporterDelegate {
        void httpExchangeFailed(IOException iOException);

        InputStream interpretResponseStream(InputStream inputStream);

        void postConnect();

        void preConnect(HttpURLConnection httpURLConnection, String str);
    }

    private void execute(Runnable runnable) {
        if (this.mExecutorService == null) {
            this.mExecutorService = Executors.newFixedThreadPool(3);
        }
        this.mExecutorService.execute(runnable);
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter
    public void sendRequest(final WXRequest request, final IWXHttpAdapter.OnHttpListener listener) {
        if (listener != null) {
            listener.onHttpStart();
        }
        execute(new Runnable() {
            /* class com.taobao.weex.adapter.DefaultWXHttpAdapter.AnonymousClass1 */

            public void run() {
                WXSDKInstance instance = WXSDKManager.getInstance().getAllInstanceMap().get(request.instanceId);
                if (instance != null && !instance.isDestroy()) {
                    instance.getApmForInstance().actionNetRequest();
                }
                boolean isNetRequestSucceed = true;
                WXResponse response = new WXResponse();
                IEventReporterDelegate reporter = DefaultWXHttpAdapter.this.getEventReporterDelegate();
                try {
                    HttpURLConnection connection = DefaultWXHttpAdapter.this.openConnection(request, listener);
                    reporter.preConnect(connection, request.body);
                    Map<String, List<String>> headers = connection.getHeaderFields();
                    int responseCode = connection.getResponseCode();
                    if (listener != null) {
                        listener.onHeadersReceived(responseCode, headers);
                    }
                    reporter.postConnect();
                    response.statusCode = String.valueOf(responseCode);
                    if (responseCode < 200 || responseCode > 299) {
                        response.errorMsg = DefaultWXHttpAdapter.this.readInputStream(connection.getErrorStream(), listener);
                        isNetRequestSucceed = false;
                    } else {
                        response.originalData = DefaultWXHttpAdapter.this.readInputStreamAsBytes(reporter.interpretResponseStream(connection.getInputStream()), listener);
                    }
                    if (listener != null) {
                        listener.onHttpFinish(response);
                    }
                } catch (IOException | IllegalArgumentException e) {
                    isNetRequestSucceed = false;
                    e.printStackTrace();
                    response.statusCode = "-1";
                    response.errorCode = "-1";
                    response.errorMsg = e.getMessage();
                    IWXHttpAdapter.OnHttpListener onHttpListener = listener;
                    if (onHttpListener != null) {
                        onHttpListener.onHttpFinish(response);
                    }
                    if (e instanceof IOException) {
                        reporter.httpExchangeFailed((IOException) e);
                    }
                } catch (Throwable t) {
                    t.printStackTrace();
                }
                if (instance != null && !instance.isDestroy()) {
                    instance.getApmForInstance().actionNetResult(isNetRequestSucceed, null);
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private HttpURLConnection openConnection(WXRequest request, IWXHttpAdapter.OnHttpListener listener) throws IOException {
        HttpURLConnection connection = createConnection(new URL(request.url));
        connection.setConnectTimeout(request.timeoutMs);
        connection.setReadTimeout(request.timeoutMs);
        connection.setUseCaches(false);
        connection.setDoInput(true);
        if (request.paramMap != null) {
            for (String key : request.paramMap.keySet()) {
                connection.addRequestProperty(key, request.paramMap.get(key));
            }
        }
        if (Constants.HTTP_POST.equals(request.method) || "PUT".equals(request.method) || "PATCH".equals(request.method)) {
            connection.setRequestMethod(request.method);
            if (request.body != null) {
                if (listener != null) {
                    listener.onHttpUploadProgress(0);
                }
                connection.setDoOutput(true);
                DataOutputStream out = new DataOutputStream(connection.getOutputStream());
                out.write(request.body.getBytes());
                out.close();
                if (listener != null) {
                    listener.onHttpUploadProgress(100);
                }
            }
        } else if (!TextUtils.isEmpty(request.method)) {
            connection.setRequestMethod(request.method);
        } else {
            connection.setRequestMethod(Constants.HTTP_GET);
        }
        return connection;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private byte[] readInputStreamAsBytes(InputStream inputStream, IWXHttpAdapter.OnHttpListener listener) throws IOException {
        if (inputStream == null) {
            return null;
        }
        ByteArrayOutputStream buffer = new ByteArrayOutputStream();
        int readCount = 0;
        byte[] data = new byte[2048];
        while (true) {
            int nRead = inputStream.read(data, 0, data.length);
            if (nRead != -1) {
                buffer.write(data, 0, nRead);
                readCount += nRead;
                if (listener != null) {
                    listener.onHttpResponseProgress(readCount);
                }
            } else {
                buffer.flush();
                return buffer.toByteArray();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String readInputStream(InputStream inputStream, IWXHttpAdapter.OnHttpListener listener) throws IOException {
        if (inputStream == null) {
            return null;
        }
        StringBuilder builder = new StringBuilder();
        BufferedReader localBufferedReader = new BufferedReader(new InputStreamReader(inputStream));
        char[] data = new char[2048];
        while (true) {
            int len = localBufferedReader.read(data);
            if (len != -1) {
                builder.append(data, 0, len);
                if (listener != null) {
                    listener.onHttpResponseProgress(builder.length());
                }
            } else {
                localBufferedReader.close();
                return builder.toString();
            }
        }
    }

    /* access modifiers changed from: protected */
    public HttpURLConnection createConnection(URL url) throws IOException {
        return (HttpURLConnection) url.openConnection();
    }

    public IEventReporterDelegate getEventReporterDelegate() {
        return DEFAULT_DELEGATE;
    }

    private static class NOPEventReportDelegate implements IEventReporterDelegate {
        private NOPEventReportDelegate() {
        }

        @Override // com.taobao.weex.adapter.DefaultWXHttpAdapter.IEventReporterDelegate
        public void preConnect(HttpURLConnection connection, String body) {
        }

        @Override // com.taobao.weex.adapter.DefaultWXHttpAdapter.IEventReporterDelegate
        public void postConnect() {
        }

        @Override // com.taobao.weex.adapter.DefaultWXHttpAdapter.IEventReporterDelegate
        public InputStream interpretResponseStream(InputStream inputStream) {
            return inputStream;
        }

        @Override // com.taobao.weex.adapter.DefaultWXHttpAdapter.IEventReporterDelegate
        public void httpExchangeFailed(IOException e) {
        }
    }
}
