package com.taobao.weex.common;

import android.os.Handler;
import android.os.HandlerThread;
import android.os.Message;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.tools.LogDetail;
import java.lang.ref.WeakReference;

public class WXThread extends HandlerThread {
    private Handler mHandler;

    /* access modifiers changed from: package-private */
    public static class SafeRunnable implements Runnable {
        static final String TAG = "SafeRunnable";
        private WeakReference<WXSDKInstance> mInstance;
        final Runnable mTask;
        private LogDetail mTimelineLog;

        SafeRunnable(Runnable task) {
            this(task, null);
        }

        SafeRunnable(Runnable task, String taskName) {
            this(task, null, taskName);
        }

        SafeRunnable(Runnable runnable, WXSDKInstance instance, String taskName) {
            this.mTimelineLog = null;
            this.mTask = runnable;
            if (taskName != null) {
                LogDetail logDetail = new LogDetail();
                this.mTimelineLog = logDetail;
                logDetail.info.platform = "Android";
                this.mTimelineLog.name(taskName);
                this.mInstance = new WeakReference<>(instance);
            }
        }

        public void run() {
            WeakReference<WXSDKInstance> weakReference;
            WXSDKInstance wxsdkInstance;
            try {
                if (this.mTask != null) {
                    if (this.mTimelineLog != null) {
                        this.mTimelineLog.taskStart();
                    }
                    this.mTask.run();
                    if (this.mTimelineLog != null) {
                        this.mTimelineLog.taskEnd();
                    }
                }
            } catch (Throwable e) {
                if (!WXEnvironment.isApkDebugable()) {
                    WXLogUtils.w(TAG, e);
                } else {
                    WXLogUtils.e(TAG, "SafeRunnable run throw expection:" + e.getMessage());
                    throw e;
                }
            }
            if (this.mTimelineLog != null && (weakReference = this.mInstance) != null && (wxsdkInstance = weakReference.get()) != null && wxsdkInstance.mTimeCalculator != null) {
                wxsdkInstance.mTimeCalculator.addLog(this.mTimelineLog);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static class SafeCallback implements Handler.Callback {
        static final String TAG = "SafeCallback";
        final Handler.Callback mCallback;

        SafeCallback(Handler.Callback cb) {
            this.mCallback = cb;
        }

        public boolean handleMessage(Message msg) {
            try {
                if (this.mCallback != null) {
                    return this.mCallback.handleMessage(msg);
                }
                return false;
            } catch (Throwable e) {
                if (!WXEnvironment.isApkDebugable()) {
                    return false;
                }
                WXLogUtils.e(TAG, "SafeCallback handleMessage throw expection:" + e.getMessage());
                throw e;
            }
        }
    }

    public static Runnable secure(Runnable runnable) {
        return secure(runnable, null, null);
    }

    public static Runnable secure(Runnable runnable, WXSDKInstance instance, String runnableName) {
        if (runnable == null || (runnable instanceof SafeRunnable)) {
            return runnable;
        }
        return new SafeRunnable(runnable, instance, runnableName);
    }

    public static Handler.Callback secure(Handler.Callback callback) {
        if (callback == null || (callback instanceof SafeCallback)) {
            return callback;
        }
        return new SafeCallback(callback);
    }

    public WXThread(String name) {
        super(name);
        start();
        this.mHandler = new Handler(getLooper());
    }

    public WXThread(String name, Handler.Callback callback) {
        super(name);
        start();
        this.mHandler = new Handler(getLooper(), secure(callback));
    }

    public WXThread(String name, int priority, Handler.Callback callback) {
        super(name, priority);
        start();
        this.mHandler = new Handler(getLooper(), secure(callback));
    }

    public WXThread(String name, int priority) {
        super(name, priority);
        start();
        this.mHandler = new Handler(getLooper());
    }

    public Handler getHandler() {
        return this.mHandler;
    }

    public boolean isWXThreadAlive() {
        return (this.mHandler == null || getLooper() == null || !isAlive()) ? false : true;
    }

    public boolean quit() {
        Handler handler = this.mHandler;
        if (handler != null) {
            handler.removeCallbacksAndMessages(null);
        }
        return super.quit();
    }
}
