package com.taobao.weex.dom.transition;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ArgbEvaluator;
import android.animation.ObjectAnimator;
import android.animation.PropertyValuesHolder;
import android.animation.ValueAnimator;
import android.graphics.drawable.ColorDrawable;
import android.os.Handler;
import android.text.TextUtils;
import android.view.View;
import android.view.animation.Interpolator;
import androidx.collection.ArrayMap;
import androidx.core.view.animation.PathInterpolatorCompat;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.ui.animation.BackgroundColorProperty;
import com.taobao.weex.ui.animation.TransformParser;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.utils.SingleFunctionParser;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.regex.Pattern;

public class WXTransition {
    private static final Set<String> LAYOUT_PROPERTIES;
    public static final Pattern PROPERTY_SPLIT_PATTERN = Pattern.compile("\\||,");
    private static final Set<String> TRANSFORM_PROPERTIES;
    public static final String TRANSITION_DELAY = "transitionDelay";
    public static final String TRANSITION_DURATION = "transitionDuration";
    public static final String TRANSITION_PROPERTY = "transitionProperty";
    public static final String TRANSITION_TIMING_FUNCTION = "transitionTimingFunction";
    private Runnable animationRunnable;
    private long delay;
    private long duration;
    private Handler handler = new Handler();
    private Interpolator interpolator;
    private Map<String, Object> layoutPendingUpdates = new ArrayMap();
    private ValueAnimator layoutValueAnimator;
    private volatile AtomicInteger lockToken = new AtomicInteger(0);
    private WXComponent mWXComponent;
    private List<String> properties = new ArrayList(4);
    private Map<String, Object> targetStyles = new ArrayMap();
    private Runnable transformAnimationRunnable;
    private ObjectAnimator transformAnimator;
    private Map<String, Object> transformPendingUpdates = new ArrayMap();
    private Runnable transitionEndEvent;

    static {
        HashSet hashSet = new HashSet();
        LAYOUT_PROPERTIES = hashSet;
        hashSet.add("width");
        LAYOUT_PROPERTIES.add("height");
        LAYOUT_PROPERTIES.add(Constants.Name.MARGIN_TOP);
        LAYOUT_PROPERTIES.add(Constants.Name.MARGIN_BOTTOM);
        LAYOUT_PROPERTIES.add(Constants.Name.MARGIN_LEFT);
        LAYOUT_PROPERTIES.add(Constants.Name.MARGIN_RIGHT);
        LAYOUT_PROPERTIES.add("left");
        LAYOUT_PROPERTIES.add("right");
        LAYOUT_PROPERTIES.add("top");
        LAYOUT_PROPERTIES.add("bottom");
        LAYOUT_PROPERTIES.add(Constants.Name.PADDING_LEFT);
        LAYOUT_PROPERTIES.add(Constants.Name.PADDING_RIGHT);
        LAYOUT_PROPERTIES.add(Constants.Name.PADDING_TOP);
        LAYOUT_PROPERTIES.add(Constants.Name.PADDING_BOTTOM);
        HashSet hashSet2 = new HashSet();
        TRANSFORM_PROPERTIES = hashSet2;
        hashSet2.add("opacity");
        TRANSFORM_PROPERTIES.add("backgroundColor");
        TRANSFORM_PROPERTIES.add("transform");
    }

    public static WXTransition fromMap(Map<String, Object> style, WXComponent component) {
        String propertyString;
        if (style.get(TRANSITION_PROPERTY) == null || (propertyString = WXUtils.getString(style.get(TRANSITION_PROPERTY), null)) == null) {
            return null;
        }
        WXTransition transition = new WXTransition();
        updateTransitionProperties(transition, propertyString);
        if (transition.properties.isEmpty()) {
            return null;
        }
        transition.duration = parseTimeMillis(style, TRANSITION_DURATION, 0);
        transition.delay = parseTimeMillis(style, TRANSITION_DELAY, 0);
        transition.interpolator = createTimeInterpolator(WXUtils.getString(style.get(TRANSITION_TIMING_FUNCTION), null));
        transition.mWXComponent = component;
        return transition;
    }

    public boolean hasTransitionProperty(Map<String, Object> styles) {
        for (String property : this.properties) {
            if (styles.containsKey(property)) {
                return true;
            }
        }
        return false;
    }

    public void updateTranstionParams(Map<String, Object> updates) {
        if (updates.containsKey(TRANSITION_DELAY)) {
            this.mWXComponent.getStyles().put(TRANSITION_DELAY, updates.remove(TRANSITION_DELAY));
            this.delay = parseTimeMillis(this.mWXComponent.getStyles(), TRANSITION_DELAY, 0);
        }
        if (updates.containsKey(TRANSITION_TIMING_FUNCTION) && updates.get(TRANSITION_TIMING_FUNCTION) != null) {
            this.mWXComponent.getStyles().put(TRANSITION_TIMING_FUNCTION, updates.remove(TRANSITION_TIMING_FUNCTION));
            this.interpolator = createTimeInterpolator(this.mWXComponent.getStyles().get(TRANSITION_TIMING_FUNCTION).toString());
        }
        if (updates.containsKey(TRANSITION_DURATION)) {
            this.mWXComponent.getStyles().put(TRANSITION_DURATION, updates.remove(TRANSITION_DURATION));
            this.duration = parseTimeMillis(this.mWXComponent.getStyles(), TRANSITION_DURATION, 0);
        }
        if (updates.containsKey(TRANSITION_PROPERTY)) {
            this.mWXComponent.getStyles().put(TRANSITION_PROPERTY, updates.remove(TRANSITION_PROPERTY));
            updateTransitionProperties(this, WXUtils.getString(this.mWXComponent.getStyles().get(TRANSITION_PROPERTY), null));
        }
    }

    public void startTransition(Map<String, Object> updates) {
        synchronized (this.lockToken) {
            if (getTargetView() != null) {
                final int token = this.lockToken.incrementAndGet();
                for (String property : this.properties) {
                    if (updates.containsKey(property)) {
                        Object targetValue = updates.remove(property);
                        if (LAYOUT_PROPERTIES.contains(property)) {
                            this.layoutPendingUpdates.put(property, targetValue);
                        } else if (TRANSFORM_PROPERTIES.contains(property)) {
                            this.transformPendingUpdates.put(property, targetValue);
                        }
                    }
                }
                int delay2 = WXUtils.getNumberInt(this.mWXComponent.getAttrs().get("actionDelay"), 16);
                if (((long) delay2) > this.duration) {
                    delay2 = (int) this.duration;
                }
                if (this.animationRunnable != null) {
                    this.handler.removeCallbacks(this.animationRunnable);
                }
                AnonymousClass1 r4 = new Runnable() {
                    /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass1 */

                    public void run() {
                        if (token == WXTransition.this.lockToken.get()) {
                            WXTransition.this.doTransitionAnimation(token);
                        }
                        WXTransition.this.animationRunnable = null;
                    }
                };
                this.animationRunnable = r4;
                if (delay2 > 0) {
                    this.handler.postDelayed(r4, (long) delay2);
                } else {
                    r4.run();
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doTransitionAnimation(final int token) {
        View taregtView = getTargetView();
        if (taregtView != null) {
            if (this.targetStyles.size() > 0) {
                for (String property : this.properties) {
                    if ((LAYOUT_PROPERTIES.contains(property) || TRANSFORM_PROPERTIES.contains(property)) && !this.layoutPendingUpdates.containsKey(property) && !this.transformPendingUpdates.containsKey(property)) {
                        synchronized (this.targetStyles) {
                            if (this.targetStyles.containsKey(property)) {
                                this.mWXComponent.getStyles().put(property, this.targetStyles.remove(property));
                            }
                        }
                    }
                }
            }
            Runnable runnable = this.transitionEndEvent;
            if (runnable != null) {
                taregtView.removeCallbacks(runnable);
            }
            if (this.transitionEndEvent == null && ((float) this.duration) > Float.MIN_NORMAL) {
                this.transitionEndEvent = new Runnable() {
                    /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass2 */

                    public void run() {
                        WXTransition.this.transitionEndEvent = null;
                        if (((float) WXTransition.this.duration) >= Float.MIN_NORMAL && WXTransition.this.mWXComponent != null && WXTransition.this.mWXComponent.getEvents().contains(Constants.Event.ON_TRANSITION_END)) {
                            WXTransition.this.mWXComponent.fireEvent(Constants.Event.ON_TRANSITION_END);
                        }
                    }
                };
            }
            Runnable runnable2 = this.transformAnimationRunnable;
            if (runnable2 != null) {
                taregtView.removeCallbacks(runnable2);
            }
            AnonymousClass3 r1 = new Runnable() {
                /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass3 */

                public void run() {
                    synchronized (WXTransition.this.lockToken) {
                        if (token == WXTransition.this.lockToken.get()) {
                            WXTransition.this.doPendingTransformAnimation(token);
                        }
                    }
                }
            };
            this.transformAnimationRunnable = r1;
            taregtView.post(r1);
            doPendingLayoutAnimation();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void doPendingTransformAnimation(int token) {
        View taregtView;
        ObjectAnimator objectAnimator = this.transformAnimator;
        if (objectAnimator != null) {
            objectAnimator.cancel();
            this.transformAnimator = null;
        }
        if (!(this.transformPendingUpdates.size() == 0 || (taregtView = getTargetView()) == null || this.mWXComponent.getInstance() == null)) {
            List<PropertyValuesHolder> holders = new ArrayList<>(8);
            String transform = WXUtils.getString(this.transformPendingUpdates.remove("transform"), null);
            if (!TextUtils.isEmpty(transform)) {
                for (PropertyValuesHolder holder : TransformParser.toHolders(TransformParser.parseTransForm(this.mWXComponent.getInstanceId(), transform, (int) this.mWXComponent.getLayoutWidth(), (int) this.mWXComponent.getLayoutHeight(), this.mWXComponent.getViewPortWidthForFloat()))) {
                    holders.add(holder);
                }
                synchronized (this.targetStyles) {
                    this.targetStyles.put("transform", transform);
                }
            }
            for (String property : this.properties) {
                if (TRANSFORM_PROPERTIES.contains(property) && this.transformPendingUpdates.containsKey(property)) {
                    Object value = this.transformPendingUpdates.remove(property);
                    synchronized (this.targetStyles) {
                        this.targetStyles.put(property, value);
                    }
                    char c = 65535;
                    int hashCode = property.hashCode();
                    if (hashCode != -1267206133) {
                        if (hashCode == 1287124693 && property.equals("backgroundColor")) {
                            c = 1;
                        }
                    } else if (property.equals("opacity")) {
                        c = 0;
                    }
                    if (c == 0) {
                        holders.add(PropertyValuesHolder.ofFloat(View.ALPHA, taregtView.getAlpha(), WXUtils.getFloat(value, Float.valueOf(1.0f)).floatValue()));
                        taregtView.setLayerType(1, null);
                    } else if (c == 1) {
                        int fromColor = WXResourceUtils.getColor(WXUtils.getString(this.mWXComponent.getStyles().getBackgroundColor(), null), 0);
                        int toColor = WXResourceUtils.getColor(WXUtils.getString(value, null), 0);
                        if (WXViewUtils.getBorderDrawable(taregtView) != null) {
                            fromColor = WXViewUtils.getBorderDrawable(taregtView).getColor();
                        } else if (taregtView.getBackground() instanceof ColorDrawable) {
                            fromColor = ((ColorDrawable) taregtView.getBackground()).getColor();
                        }
                        holders.add(PropertyValuesHolder.ofObject(new BackgroundColorProperty(), new ArgbEvaluator(), Integer.valueOf(fromColor), Integer.valueOf(toColor)));
                    }
                }
            }
            if (token == this.lockToken.get()) {
                this.transformPendingUpdates.clear();
            }
            ObjectAnimator ofPropertyValuesHolder = ObjectAnimator.ofPropertyValuesHolder(taregtView, (PropertyValuesHolder[]) holders.toArray(new PropertyValuesHolder[holders.size()]));
            this.transformAnimator = ofPropertyValuesHolder;
            ofPropertyValuesHolder.setDuration(this.duration);
            long j = this.delay;
            if (j > 0) {
                this.transformAnimator.setStartDelay(j);
            }
            Interpolator interpolator2 = this.interpolator;
            if (interpolator2 != null) {
                this.transformAnimator.setInterpolator(interpolator2);
            }
            this.transformAnimator.addListener(new AnimatorListenerAdapter() {
                /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass4 */
                boolean hasCancel = false;

                public void onAnimationCancel(Animator animation) {
                    super.onAnimationCancel(animation);
                    this.hasCancel = true;
                }

                public void onAnimationEnd(Animator animation) {
                    if (!this.hasCancel) {
                        super.onAnimationEnd(animation);
                        WXTransition.this.onTransitionAnimationEnd();
                    }
                }
            });
            this.transformAnimator.start();
        }
    }

    public void doPendingLayoutAnimation() {
        ValueAnimator valueAnimator = this.layoutValueAnimator;
        if (valueAnimator != null) {
            valueAnimator.cancel();
            this.layoutValueAnimator = null;
        }
        if (this.layoutPendingUpdates.size() != 0) {
            PropertyValuesHolder[] holders = new PropertyValuesHolder[this.layoutPendingUpdates.size()];
            int index = 0;
            if (this.properties.size() != 0) {
                for (String property : this.properties) {
                    if (LAYOUT_PROPERTIES.contains(property) && this.layoutPendingUpdates.containsKey(property)) {
                        Object targetValue = this.layoutPendingUpdates.remove(property);
                        synchronized (this.targetStyles) {
                            this.targetStyles.put(property, targetValue);
                        }
                        holders[index] = createLayoutPropertyValueHolder(property, targetValue);
                        index++;
                    }
                }
                this.layoutPendingUpdates.clear();
                doLayoutPropertyValuesHolderAnimation(holders);
            }
        }
    }

    private PropertyValuesHolder createLayoutPropertyValueHolder(String property, Object value) {
        char c;
        String str;
        PropertyValuesHolder holder;
        switch (property.hashCode()) {
            case -1501175880:
                str = Constants.Name.PADDING_LEFT;
                if (property.equals(str)) {
                    c = '\f';
                    break;
                }
                c = 65535;
                break;
            case -1383228885:
                if (property.equals("bottom")) {
                    str = Constants.Name.PADDING_LEFT;
                    c = '\b';
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case -1221029593:
                if (property.equals("height")) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 1;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case -1044792121:
                if (property.equals(Constants.Name.MARGIN_TOP)) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 2;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case -289173127:
                if (property.equals(Constants.Name.MARGIN_BOTTOM)) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 5;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 115029:
                if (property.equals("top")) {
                    str = Constants.Name.PADDING_LEFT;
                    c = '\t';
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 3317767:
                if (property.equals("left")) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 6;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 90130308:
                if (property.equals(Constants.Name.PADDING_TOP)) {
                    str = Constants.Name.PADDING_LEFT;
                    c = '\n';
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 108511772:
                if (property.equals("right")) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 7;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 113126854:
                if (property.equals("width")) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 0;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 202355100:
                if (property.equals(Constants.Name.PADDING_BOTTOM)) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 11;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 713848971:
                if (property.equals(Constants.Name.PADDING_RIGHT)) {
                    str = Constants.Name.PADDING_LEFT;
                    c = '\r';
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 975087886:
                if (property.equals(Constants.Name.MARGIN_RIGHT)) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 4;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            case 1970934485:
                if (property.equals(Constants.Name.MARGIN_LEFT)) {
                    str = Constants.Name.PADDING_LEFT;
                    c = 3;
                    break;
                }
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
            default:
                str = Constants.Name.PADDING_LEFT;
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                holder = PropertyValuesHolder.ofFloat("width", this.mWXComponent.getLayoutWidth(), WXViewUtils.getRealPxByWidth(WXUtils.getFloat(value, Float.valueOf(0.0f)).floatValue(), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 1:
                holder = PropertyValuesHolder.ofFloat("height", this.mWXComponent.getLayoutHeight(), WXViewUtils.getRealPxByWidth(WXUtils.getFloat(value, Float.valueOf(0.0f)).floatValue(), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 2:
                holder = PropertyValuesHolder.ofFloat(Constants.Name.MARGIN_TOP, this.mWXComponent.getMargin().get(CSSShorthand.EDGE.TOP), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 3:
                holder = PropertyValuesHolder.ofFloat(Constants.Name.MARGIN_LEFT, this.mWXComponent.getMargin().get(CSSShorthand.EDGE.LEFT), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 4:
                holder = PropertyValuesHolder.ofFloat(Constants.Name.MARGIN_RIGHT, this.mWXComponent.getMargin().get(CSSShorthand.EDGE.RIGHT), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 5:
                holder = PropertyValuesHolder.ofFloat(Constants.Name.MARGIN_BOTTOM, this.mWXComponent.getMargin().get(CSSShorthand.EDGE.BOTTOM), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 6:
                holder = PropertyValuesHolder.ofFloat("left", this.mWXComponent.getLayoutPosition().getLeft(), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 7:
                holder = PropertyValuesHolder.ofFloat("right", this.mWXComponent.getLayoutPosition().getRight(), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case '\b':
                holder = PropertyValuesHolder.ofFloat("bottom", this.mWXComponent.getLayoutPosition().getBottom(), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case '\t':
                holder = PropertyValuesHolder.ofFloat("top", this.mWXComponent.getLayoutPosition().getTop(), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case '\n':
                holder = PropertyValuesHolder.ofFloat(Constants.Name.PADDING_TOP, this.mWXComponent.getPadding().get(CSSShorthand.EDGE.TOP), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case 11:
                holder = PropertyValuesHolder.ofFloat(Constants.Name.PADDING_BOTTOM, this.mWXComponent.getPadding().get(CSSShorthand.EDGE.BOTTOM), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case '\f':
                holder = PropertyValuesHolder.ofFloat(str, this.mWXComponent.getPadding().get(CSSShorthand.EDGE.LEFT), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            case '\r':
                holder = PropertyValuesHolder.ofFloat(Constants.Name.PADDING_RIGHT, this.mWXComponent.getPadding().get(CSSShorthand.EDGE.RIGHT), WXViewUtils.getRealPxByWidth(WXUtils.getFloatByViewport(value, this.mWXComponent.getViewPortWidthForFloat()), this.mWXComponent.getViewPortWidthForFloat()));
                break;
            default:
                holder = null;
                break;
        }
        if (holder == null) {
            return PropertyValuesHolder.ofFloat(property, 1.0f, 1.0f);
        }
        return holder;
    }

    private void doLayoutPropertyValuesHolderAnimation(PropertyValuesHolder[] holders) {
        ValueAnimator ofPropertyValuesHolder = ValueAnimator.ofPropertyValuesHolder(holders);
        this.layoutValueAnimator = ofPropertyValuesHolder;
        ofPropertyValuesHolder.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass5 */

            public void onAnimationUpdate(ValueAnimator animation) {
                for (PropertyValuesHolder holder : animation.getValues()) {
                    String property = holder.getPropertyName();
                    WXTransition.asynchronouslyUpdateLayout(WXTransition.this.mWXComponent, property, ((Float) animation.getAnimatedValue(property)).floatValue());
                }
            }
        });
        this.layoutValueAnimator.addListener(new AnimatorListenerAdapter() {
            /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass6 */
            boolean hasCancel = false;

            public void onAnimationCancel(Animator animation) {
                super.onAnimationCancel(animation);
                this.hasCancel = true;
            }

            public void onAnimationEnd(Animator animation) {
                if (!this.hasCancel) {
                    super.onAnimationEnd(animation);
                    WXTransition.this.onTransitionAnimationEnd();
                }
            }
        });
        Interpolator interpolator2 = this.interpolator;
        if (interpolator2 != null) {
            this.layoutValueAnimator.setInterpolator(interpolator2);
        }
        this.layoutValueAnimator.setStartDelay(this.delay);
        this.layoutValueAnimator.setDuration(this.duration);
        this.layoutValueAnimator.start();
    }

    public static void asynchronouslyUpdateLayout(WXComponent component, final String propertyName, final float propertyValue) {
        if (component != null && component.getInstance() != null) {
            final String ref = component.getRef();
            final String instanceId = component.getInstanceId();
            if (!TextUtils.isEmpty(ref) && !TextUtils.isEmpty(instanceId)) {
                WXSDKManager.getInstance().getWXBridgeManager().post(new Runnable() {
                    /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass7 */

                    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
                    public void run() {
                        char c;
                        String str = propertyName;
                        switch (str.hashCode()) {
                            case -1501175880:
                                if (str.equals(Constants.Name.PADDING_LEFT)) {
                                    c = '\f';
                                    break;
                                }
                                c = 65535;
                                break;
                            case -1383228885:
                                if (str.equals("bottom")) {
                                    c = '\b';
                                    break;
                                }
                                c = 65535;
                                break;
                            case -1221029593:
                                if (str.equals("height")) {
                                    c = 1;
                                    break;
                                }
                                c = 65535;
                                break;
                            case -1044792121:
                                if (str.equals(Constants.Name.MARGIN_TOP)) {
                                    c = 2;
                                    break;
                                }
                                c = 65535;
                                break;
                            case -289173127:
                                if (str.equals(Constants.Name.MARGIN_BOTTOM)) {
                                    c = 5;
                                    break;
                                }
                                c = 65535;
                                break;
                            case 115029:
                                if (str.equals("top")) {
                                    c = '\t';
                                    break;
                                }
                                c = 65535;
                                break;
                            case 3317767:
                                if (str.equals("left")) {
                                    c = 6;
                                    break;
                                }
                                c = 65535;
                                break;
                            case 90130308:
                                if (str.equals(Constants.Name.PADDING_TOP)) {
                                    c = '\n';
                                    break;
                                }
                                c = 65535;
                                break;
                            case 108511772:
                                if (str.equals("right")) {
                                    c = 7;
                                    break;
                                }
                                c = 65535;
                                break;
                            case 113126854:
                                if (str.equals("width")) {
                                    c = 0;
                                    break;
                                }
                                c = 65535;
                                break;
                            case 202355100:
                                if (str.equals(Constants.Name.PADDING_BOTTOM)) {
                                    c = 11;
                                    break;
                                }
                                c = 65535;
                                break;
                            case 713848971:
                                if (str.equals(Constants.Name.PADDING_RIGHT)) {
                                    c = '\r';
                                    break;
                                }
                                c = 65535;
                                break;
                            case 975087886:
                                if (str.equals(Constants.Name.MARGIN_RIGHT)) {
                                    c = 4;
                                    break;
                                }
                                c = 65535;
                                break;
                            case 1970934485:
                                if (str.equals(Constants.Name.MARGIN_LEFT)) {
                                    c = 3;
                                    break;
                                }
                                c = 65535;
                                break;
                            default:
                                c = 65535;
                                break;
                        }
                        switch (c) {
                            case 0:
                                WXBridgeManager.getInstance().setStyleWidth(instanceId, ref, propertyValue);
                                return;
                            case 1:
                                WXBridgeManager.getInstance().setStyleHeight(instanceId, ref, propertyValue);
                                return;
                            case 2:
                                WXBridgeManager.getInstance().setMargin(instanceId, ref, CSSShorthand.EDGE.TOP, propertyValue);
                                return;
                            case 3:
                                WXBridgeManager.getInstance().setMargin(instanceId, ref, CSSShorthand.EDGE.LEFT, propertyValue);
                                return;
                            case 4:
                                WXBridgeManager.getInstance().setMargin(instanceId, ref, CSSShorthand.EDGE.RIGHT, propertyValue);
                                return;
                            case 5:
                                WXBridgeManager.getInstance().setMargin(instanceId, ref, CSSShorthand.EDGE.BOTTOM, propertyValue);
                                return;
                            case 6:
                                WXBridgeManager.getInstance().setPosition(instanceId, ref, CSSShorthand.EDGE.LEFT, propertyValue);
                                return;
                            case 7:
                                WXBridgeManager.getInstance().setPosition(instanceId, ref, CSSShorthand.EDGE.RIGHT, propertyValue);
                                return;
                            case '\b':
                                WXBridgeManager.getInstance().setPosition(instanceId, ref, CSSShorthand.EDGE.BOTTOM, propertyValue);
                                return;
                            case '\t':
                                WXBridgeManager.getInstance().setPosition(instanceId, ref, CSSShorthand.EDGE.TOP, propertyValue);
                                return;
                            case '\n':
                                WXBridgeManager.getInstance().setPadding(instanceId, ref, CSSShorthand.EDGE.TOP, propertyValue);
                                return;
                            case 11:
                                WXBridgeManager.getInstance().setPadding(instanceId, ref, CSSShorthand.EDGE.BOTTOM, propertyValue);
                                return;
                            case '\f':
                                WXBridgeManager.getInstance().setPadding(instanceId, ref, CSSShorthand.EDGE.LEFT, propertyValue);
                                return;
                            case '\r':
                                WXBridgeManager.getInstance().setPadding(instanceId, ref, CSSShorthand.EDGE.RIGHT, propertyValue);
                                return;
                            default:
                                return;
                        }
                    }
                });
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void onTransitionAnimationEnd() {
        if (this.duration > 0 && this.transitionEndEvent != null) {
            View view = getTargetView();
            if (!(view == null || this.transitionEndEvent == null)) {
                view.post(this.transitionEndEvent);
            }
            this.transitionEndEvent = null;
        }
        synchronized (this.targetStyles) {
            if (this.targetStyles.size() > 0) {
                for (String property : this.properties) {
                    if (this.targetStyles.containsKey(property)) {
                        this.mWXComponent.getStyles().put(property, this.targetStyles.remove(property));
                    }
                }
                this.targetStyles.clear();
            }
        }
    }

    private View getTargetView() {
        WXComponent wXComponent = this.mWXComponent;
        if (wXComponent != null) {
            return wXComponent.getHostView();
        }
        return null;
    }

    private static long parseTimeMillis(Map<String, Object> style, String key, long defaultValue) {
        String duration2 = WXUtils.getString(style.get(key), null);
        if (duration2 != null) {
            duration2 = duration2.replaceAll("ms", "");
        }
        if (duration2 != null) {
            if (WXEnvironment.isApkDebugable() && duration2.contains("px")) {
                WXLogUtils.w("Transition Duration Unit Only Support ms, " + duration2 + " is not ms Unit");
            }
            duration2 = duration2.replaceAll("px", "");
        }
        if (TextUtils.isEmpty(duration2)) {
            return defaultValue;
        }
        try {
            return (long) Float.parseFloat(duration2);
        } catch (NumberFormatException e) {
            return defaultValue;
        }
    }

    private static Interpolator createTimeInterpolator(String interpolator2) {
        if (!TextUtils.isEmpty(interpolator2)) {
            char c = 65535;
            switch (interpolator2.hashCode()) {
                case -1965120668:
                    if (interpolator2.equals("ease-in")) {
                        c = 0;
                        break;
                    }
                    break;
                case -1102672091:
                    if (interpolator2.equals("linear")) {
                        c = 4;
                        break;
                    }
                    break;
                case -789192465:
                    if (interpolator2.equals("ease-out")) {
                        c = 1;
                        break;
                    }
                    break;
                case -361990811:
                    if (interpolator2.equals("ease-in-out")) {
                        c = 2;
                        break;
                    }
                    break;
                case 3105774:
                    if (interpolator2.equals(Constants.TimeFunction.EASE)) {
                        c = 3;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                return PathInterpolatorCompat.create(0.42f, 0.0f, 1.0f, 1.0f);
            }
            if (c == 1) {
                return PathInterpolatorCompat.create(0.0f, 0.0f, 0.58f, 1.0f);
            }
            if (c == 2) {
                return PathInterpolatorCompat.create(0.42f, 0.0f, 0.58f, 1.0f);
            }
            if (c == 3) {
                return PathInterpolatorCompat.create(0.25f, 0.1f, 0.25f, 1.0f);
            }
            if (c == 4) {
                return PathInterpolatorCompat.create(0.0f, 0.0f, 1.0f, 1.0f);
            }
            try {
                List<Float> params = new SingleFunctionParser<>(interpolator2, new SingleFunctionParser.FlatMapper<Float>() {
                    /* class com.taobao.weex.dom.transition.WXTransition.AnonymousClass8 */

                    @Override // com.taobao.weex.utils.SingleFunctionParser.FlatMapper
                    public Float map(String raw) {
                        return Float.valueOf(Float.parseFloat(raw));
                    }
                }).parse("cubic-bezier");
                if (params != null && params.size() == 4) {
                    return PathInterpolatorCompat.create(params.get(0).floatValue(), params.get(1).floatValue(), params.get(2).floatValue(), params.get(3).floatValue());
                }
            } catch (RuntimeException e) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.e("WXTransition", e);
                }
            }
        }
        return PathInterpolatorCompat.create(0.25f, 0.1f, 0.25f, 1.0f);
    }

    private static void updateTransitionProperties(WXTransition transition, String transtionProperty) {
        if (transtionProperty != null) {
            transition.properties.clear();
            for (String property : PROPERTY_SPLIT_PATTERN.split(transtionProperty)) {
                String trim = property.trim();
                if (!TextUtils.isEmpty(trim)) {
                    if (LAYOUT_PROPERTIES.contains(trim) || TRANSFORM_PROPERTIES.contains(trim)) {
                        transition.properties.add(trim);
                    } else if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.e("WXTransition Property Not Supported" + trim + " in " + transtionProperty);
                    }
                }
            }
        }
    }

    public List<String> getProperties() {
        return this.properties;
    }
}
