package com.taobao.weex.ui.component.richtext.node;

import android.content.Context;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.SpannableStringBuilder;
import android.text.TextUtils;
import android.text.style.AbsoluteSizeSpan;
import android.text.style.BackgroundColorSpan;
import android.text.style.ForegroundColorSpan;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.WXCustomStyleSpan;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public abstract class RichTextNode {
    public static final String ATTR = "attr";
    public static final String CHILDREN = "children";
    public static final String ITEM_CLICK = "itemclick";
    private static final int MAX_LEVEL = 255;
    public static final String PSEUDO_REF = "pseudoRef";
    public static final String STYLE = "style";
    public static final String TYPE = "type";
    public static final String VALUE = "value";
    protected Map<String, Object> attr;
    protected List<RichTextNode> children;
    protected final String mComponentRef;
    protected final Context mContext;
    protected final String mInstanceId;
    protected final String mRef;
    protected Map<String, Object> style;

    /* access modifiers changed from: protected */
    public abstract boolean isInternalNode();

    public abstract String toString();

    protected RichTextNode(Context context, String instanceId, String componentRef) {
        this.mContext = context;
        this.mInstanceId = instanceId;
        this.mComponentRef = componentRef;
        this.mRef = null;
    }

    protected RichTextNode(Context context, String instanceId, String componentRef, String ref, Map<String, Object> styles, Map<String, Object> attrs) {
        this.mContext = context;
        this.mInstanceId = instanceId;
        this.mComponentRef = componentRef;
        this.mRef = ref;
        if (styles != null) {
            this.style = styles;
        } else {
            this.style = new ArrayMap(0);
        }
        if (attrs != null) {
            this.attr = attrs;
        } else {
            this.attr = new ArrayMap(0);
        }
        this.children = new LinkedList();
    }

    public static Spannable parse(Context context, String instanceId, String componentRef, String json) {
        RichTextNode node;
        JSONArray jsonArray = JSON.parseArray(json);
        if (jsonArray == null || jsonArray.isEmpty()) {
            return new SpannableString("");
        }
        List<RichTextNode> nodes = new ArrayList<>(jsonArray.size());
        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject jsonObject = jsonArray.getJSONObject(i);
            if (!(jsonObject == null || (node = RichTextNodeManager.createRichTextNode(context, instanceId, componentRef, jsonObject)) == null)) {
                nodes.add(node);
            }
        }
        return parse(nodes);
    }

    public static int createSpanFlag(int level) {
        return createPriorityFlag(level) | 17;
    }

    public String getRef() {
        return this.mRef;
    }

    /* access modifiers changed from: package-private */
    public final void parse(Context context, String instanceId, String componentRef, JSONObject jsonObject) {
        JSONObject jsonStyle = jsonObject.getJSONObject("style");
        if (jsonStyle != null) {
            ArrayMap arrayMap = new ArrayMap();
            this.style = arrayMap;
            arrayMap.putAll(jsonStyle);
        } else {
            this.style = new ArrayMap(0);
        }
        JSONObject jsonAttr = jsonObject.getJSONObject(ATTR);
        if (jsonAttr != null) {
            ArrayMap arrayMap2 = new ArrayMap(jsonAttr.size());
            this.attr = arrayMap2;
            arrayMap2.putAll(jsonAttr);
        } else {
            this.attr = new ArrayMap(0);
        }
        JSONArray jsonChildren = jsonObject.getJSONArray(CHILDREN);
        if (jsonChildren != null) {
            this.children = new ArrayList(jsonChildren.size());
            for (int i = 0; i < jsonChildren.size(); i++) {
                RichTextNode node = RichTextNodeManager.createRichTextNode(context, instanceId, componentRef, jsonChildren.getJSONObject(i));
                if (node != null) {
                    this.children.add(node);
                }
            }
            return;
        }
        this.children = new ArrayList(0);
    }

    public void addChildNode(RichTextNode child) {
        if (this.children == null) {
            this.children = new LinkedList();
        }
        if (child != null && isInternalNode()) {
            this.children.add(child);
        }
    }

    public void removeChildNode(String ref) {
        List<RichTextNode> list = this.children;
        if (list != null && !list.isEmpty() && !TextUtils.isEmpty(ref)) {
            try {
                for (RichTextNode child : this.children) {
                    if (TextUtils.equals(child.mRef, ref)) {
                        this.children.remove(child);
                    }
                }
            } catch (Exception e) {
                WXLogUtils.getStackTrace(e);
            }
        }
    }

    public void updateStyles(Map<String, Object> styles) {
        if (styles != null && !styles.isEmpty()) {
            this.style.putAll(styles);
        }
    }

    public void updateAttrs(Map<String, Object> attrs) {
        if (this.attr != null && !attrs.isEmpty()) {
            this.attr.putAll(attrs);
        }
    }

    /* access modifiers changed from: protected */
    public void updateSpans(SpannableStringBuilder spannableStringBuilder, int level) {
        int color;
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(this.mInstanceId);
        if (!(this.style == null || instance == null)) {
            List<Object> spans = new LinkedList<>();
            WXCustomStyleSpan customStyleSpan = createCustomStyleSpan();
            if (customStyleSpan != null) {
                spans.add(customStyleSpan);
            }
            if (this.style.containsKey(Constants.Name.FONT_SIZE)) {
                spans.add(new AbsoluteSizeSpan(WXStyle.getFontSize(this.style, instance.getDefaultFontSize(), instance.getInstanceViewPortWidthWithFloat())));
            }
            if (this.style.containsKey("backgroundColor") && (color = WXResourceUtils.getColor(this.style.get("backgroundColor").toString(), 0)) != 0) {
                spans.add(new BackgroundColorSpan(color));
            }
            if (this.style.containsKey("color")) {
                spans.add(new ForegroundColorSpan(WXResourceUtils.getColor(WXStyle.getTextColor(this.style))));
            }
            int spanFlag = createSpanFlag(level);
            for (Object span : spans) {
                spannableStringBuilder.setSpan(span, 0, spannableStringBuilder.length(), spanFlag);
            }
        }
    }

    private static int createPriorityFlag(int level) {
        if (level <= 255) {
            return (255 - level) << 16;
        }
        return 16711680;
    }

    private static Spannable parse(List<RichTextNode> list) {
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        for (RichTextNode richTextNode : list) {
            spannableStringBuilder.append((CharSequence) richTextNode.toSpan(1));
        }
        return spannableStringBuilder;
    }

    public Spannable toSpan(int level) {
        List<RichTextNode> list;
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        spannableStringBuilder.append((CharSequence) toString());
        if (isInternalNode() && (list = this.children) != null) {
            for (RichTextNode child : list) {
                spannableStringBuilder.append((CharSequence) child.toSpan(level + 1));
            }
        }
        updateSpans(spannableStringBuilder, level);
        return spannableStringBuilder;
    }

    private WXCustomStyleSpan createCustomStyleSpan() {
        int fontWeight = -1;
        int fontStyle = -1;
        String fontFamily = null;
        if (this.style.containsKey(Constants.Name.FONT_WEIGHT)) {
            fontWeight = WXStyle.getFontWeight(this.style);
        }
        if (this.style.containsKey(Constants.Name.FONT_STYLE)) {
            fontStyle = WXStyle.getFontStyle(this.style);
        }
        if (this.style.containsKey(Constants.Name.FONT_FAMILY)) {
            fontFamily = WXStyle.getFontFamily(this.style);
        }
        if (fontWeight == -1 && fontStyle == -1 && fontFamily == null) {
            return null;
        }
        return new WXCustomStyleSpan(fontStyle, fontWeight, fontFamily);
    }

    public RichTextNode findRichNode(String ref) {
        String str = this.mRef;
        if (str != null && TextUtils.equals(str, ref)) {
            return this;
        }
        List<RichTextNode> list = this.children;
        if (list == null || list.isEmpty()) {
            return null;
        }
        for (RichTextNode child : this.children) {
            RichTextNode theNode = child.findRichNode(ref);
            if (theNode != null) {
                return theNode;
            }
        }
        return null;
    }
}
