package com.taobao.weex.utils;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BlurMaskFilter;
import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Region;
import android.graphics.Shader;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.os.Build;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.util.StringUtil;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class BoxShadowUtil {
    private static final String TAG = "BoxShadowUtil";
    private static boolean sBoxShadowEnabled = true;
    private static Pattern sColorPattern;

    public static void setBoxShadowEnabled(boolean enabled) {
        sBoxShadowEnabled = enabled;
        WXLogUtils.w(TAG, "Switch box-shadow status: " + enabled);
    }

    public static boolean isBoxShadowEnabled() {
        return sBoxShadowEnabled;
    }

    public static void setBoxShadow(final View target, String style, final float[] radii, float viewPort, final float quality) {
        if (!sBoxShadowEnabled) {
            WXLogUtils.w(TAG, "box-shadow was disabled by config");
        } else if (target == null) {
            WXLogUtils.w(TAG, "Target view is null!");
        } else if (!TextUtils.isEmpty(style) || Build.VERSION.SDK_INT < 18) {
            BoxShadowOptions[] shadows = parseBoxShadows(style, viewPort);
            if (shadows == null || shadows.length == 0) {
                WXLogUtils.w(TAG, "Failed to parse box-shadow: " + style);
                return;
            }
            final List<BoxShadowOptions> normalShadows = new ArrayList<>();
            final List<BoxShadowOptions> insetShadows = new ArrayList<>();
            for (BoxShadowOptions shadow : shadows) {
                if (shadow != null) {
                    if (shadow.isInset) {
                        insetShadows.add(0, shadow);
                    } else {
                        normalShadows.add(0, shadow);
                    }
                }
            }
            if (radii != null) {
                if (radii.length != 8) {
                    WXLogUtils.w(TAG, "Length of radii must be 8");
                } else {
                    for (int i = 0; i < radii.length; i++) {
                        radii[i] = WXViewUtils.getRealSubPxByWidth(radii[i], viewPort);
                    }
                }
            }
            target.post(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.utils.BoxShadowUtil.AnonymousClass1 */

                public void run() {
                    if (Build.VERSION.SDK_INT >= 18) {
                        target.getOverlay().clear();
                        if (normalShadows.size() > 0) {
                            BoxShadowUtil.setNormalBoxShadow(target, normalShadows, quality, radii);
                        }
                        if (insetShadows.size() > 0) {
                            BoxShadowUtil.setInsetBoxShadow(target, insetShadows, quality, radii);
                        }
                    }
                }
            }));
        } else {
            target.getOverlay().clear();
            WXLogUtils.d(TAG, "Remove all box-shadow");
        }
    }

    private static void drawShadow(Canvas canvas, BoxShadowOptions options) {
        RectF shadowRect = new RectF(0.0f, 0.0f, ((float) options.viewWidth) + (options.spread * 2.0f), ((float) options.viewHeight) + (options.spread * 2.0f));
        if (options.topLeft != null) {
            shadowRect.offset(options.topLeft.x, options.topLeft.y);
        }
        float shadowDx = options.blur;
        float shadowDy = options.blur;
        if (options.hShadow > 0.0f) {
            shadowDx += options.hShadow * 2.0f;
        }
        if (options.vShadow > 0.0f) {
            shadowDy += options.vShadow * 2.0f;
        }
        shadowRect.offset(shadowDx, shadowDy);
        Paint shadowPaint = new Paint();
        shadowPaint.setAntiAlias(true);
        shadowPaint.setColor(options.color);
        shadowPaint.setStyle(Paint.Style.FILL);
        if (options.blur > 0.0f) {
            shadowPaint.setMaskFilter(new BlurMaskFilter(options.blur, BlurMaskFilter.Blur.NORMAL));
        }
        Path shadowPath = new Path();
        float[] shadowRadii = new float[8];
        for (int i = 0; i < options.radii.length; i++) {
            if (options.radii[i] == 0.0f) {
                shadowRadii[i] = 0.0f;
            } else {
                shadowRadii[i] = options.radii[i] + options.spread;
            }
        }
        shadowPath.addRoundRect(shadowRect, shadowRadii, Path.Direction.CCW);
        canvas.drawPath(shadowPath, shadowPaint);
    }

    /* access modifiers changed from: private */
    public static void setNormalBoxShadow(View target, List<BoxShadowOptions> options, float quality, float[] radii) {
        int h = target.getHeight();
        int w = target.getWidth();
        ViewGroup.LayoutParams p = target.getLayoutParams();
        if (h != 0) {
            if (w != 0) {
                if (Build.VERSION.SDK_INT >= 18) {
                    int maxWidth = 0;
                    int maxHeight = 0;
                    for (BoxShadowOptions option : options) {
                        option.viewWidth = w;
                        option.viewHeight = h;
                        option.radii = radii;
                        Rect rect = option.getTargetCanvasRect();
                        if (maxWidth < rect.width()) {
                            maxWidth = rect.width();
                        }
                        if (maxHeight < rect.height()) {
                            maxHeight = rect.height();
                        }
                    }
                    Bitmap output = Bitmap.createBitmap((int) (((float) maxWidth) * quality), (int) (((float) maxHeight) * quality), Bitmap.Config.ARGB_4444);
                    if (Build.VERSION.SDK_INT >= 19) {
                        WXLogUtils.d(TAG, "Allocation memory for box-shadow: " + (output.getAllocationByteCount() / 1024) + " KB");
                    }
                    Canvas canvas = new Canvas(output);
                    for (BoxShadowOptions option2 : options) {
                        Rect rect2 = option2.getTargetCanvasRect();
                        option2.topLeft = new PointF(((float) (maxWidth - rect2.width())) / 2.0f, ((float) (maxHeight - rect2.height())) / 2.0f);
                        drawShadow(canvas, option2.scale(quality));
                        p = p;
                    }
                    OverflowBitmapDrawable shadowDrawable = new OverflowBitmapDrawable(target.getResources(), output, new Point((maxWidth - w) / 2, (maxHeight - h) / 2), new Rect(0, 0, w, h), radii);
                    target.getOverlay().add(shadowDrawable);
                    ViewParent parent = target.getParent();
                    if (parent != null) {
                        parent.requestLayout();
                        if (parent instanceof ViewGroup) {
                            ((ViewGroup) parent).invalidate(shadowDrawable.getBounds());
                            return;
                        }
                        return;
                    }
                    return;
                }
                Log.w(TAG, "Call setNormalBoxShadow() requires API level 18 or higher.");
                return;
            }
        }
        Log.w(TAG, "Target view is invisible, ignore set shadow.");
    }

    /* access modifiers changed from: private */
    public static void setInsetBoxShadow(View target, List<BoxShadowOptions> options, float quality, float[] radii) {
        if (target == null || options == null) {
            WXLogUtils.w(TAG, "Illegal arguments");
        } else if (target.getWidth() == 0 || target.getHeight() == 0) {
            WXLogUtils.w(TAG, "Target view is invisible, ignore set shadow.");
        } else if (Build.VERSION.SDK_INT >= 18) {
            Drawable[] drawables = new Drawable[options.size()];
            for (int i = 0; i < options.size(); i++) {
                BoxShadowOptions option = options.get(i);
                drawables[i] = new InsetShadowDrawable(target.getWidth(), target.getHeight(), option.hShadow, option.vShadow, option.blur, option.spread, option.color, radii);
            }
            target.getOverlay().add(new LayerDrawable(drawables));
            target.invalidate();
        } else {
            Log.w(TAG, "Call setInsetBoxShadow() requires API level 18 or higher.");
        }
    }

    public static BoxShadowOptions[] parseBoxShadows(String boxShadowStyle, float viewport) {
        if (sColorPattern == null) {
            sColorPattern = Pattern.compile("([rR][gG][bB][aA]?)\\((\\d+\\s*),\\s*(\\d+\\s*),\\s*(\\d+\\s*)(?:,\\s*(\\d+(?:\\.\\d+)?))?\\)");
        }
        Matcher matcher = sColorPattern.matcher(boxShadowStyle);
        String processedStyle = boxShadowStyle;
        while (matcher.find()) {
            String color = matcher.group();
            processedStyle = processedStyle.replace(color, "#" + StringUtil.format("%8s", Integer.toHexString(WXResourceUtils.getColor(color, -16777216))).replaceAll("\\s", "0"));
        }
        String[] styles = processedStyle.split(",");
        if (styles == null || styles.length <= 0) {
            return null;
        }
        BoxShadowOptions[] result = new BoxShadowOptions[styles.length];
        for (int i = 0; i < styles.length; i++) {
            result[i] = parseBoxShadow(styles[i], viewport);
        }
        return result;
    }

    private static BoxShadowOptions parseBoxShadow(String boxShadow, float viewport) {
        BoxShadowOptions result = new BoxShadowOptions(viewport);
        if (TextUtils.isEmpty(boxShadow)) {
            return null;
        }
        String boxShadowCopy = boxShadow.replaceAll("\\s*,\\s+", ",");
        if (boxShadowCopy.contains("inset")) {
            result.isInset = true;
            boxShadowCopy = boxShadowCopy.replace("inset", "");
        }
        List<String> params = new ArrayList<>(Arrays.asList(boxShadowCopy.trim().split("\\s+")));
        String maybeColor = params.get(params.size() - 1);
        if (!TextUtils.isEmpty(maybeColor) && (maybeColor.startsWith("#") || maybeColor.startsWith("rgb") || WXResourceUtils.isNamedColor(maybeColor))) {
            result.color = WXResourceUtils.getColor(maybeColor, -16777216);
            params.remove(params.size() - 1);
        }
        try {
            if (params.size() < 2) {
                return null;
            }
            if (!TextUtils.isEmpty(params.get(0))) {
                result.hShadow = WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(params.get(0).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
            }
            if (!TextUtils.isEmpty(params.get(1))) {
                result.vShadow = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(params.get(1).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
            }
            for (int i = 2; i < params.size(); i++) {
                ((BoxShadowOptions.IParser) result.optionParamParsers.get(i - 2)).parse(params.get(i));
            }
            return result;
        } catch (Throwable t) {
            t.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    public static class OverflowBitmapDrawable extends BitmapDrawable {
        private int paddingX;
        private int paddingY;
        private float[] radii;
        private Rect viewRect;

        private OverflowBitmapDrawable(Resources resources, Bitmap bitmap, Point topLeft, Rect viewRect2, float[] radii2) {
            super(resources, bitmap);
            this.paddingX = topLeft.x;
            int i = topLeft.y;
            this.paddingY = i;
            this.viewRect = viewRect2;
            this.radii = radii2;
            setBounds(-this.paddingX, -i, viewRect2.width() + this.paddingX, viewRect2.height() + this.paddingY);
        }

        public void draw(Canvas canvas) {
            Rect bounds = canvas.getClipBounds();
            Rect newRect = new Rect(bounds);
            newRect.inset((-this.paddingX) * 2, (-this.paddingY) * 2);
            try {
                if (WXEnvironment.sApplication.getApplicationInfo().targetSdkVersion > 26) {
                    canvas.clipRect(newRect);
                } else {
                    canvas.clipRect(newRect, Region.Op.REPLACE);
                }
            } catch (NullPointerException e) {
                canvas.clipRect(newRect);
            }
            Path contentPath = new Path();
            contentPath.addRoundRect(new RectF(bounds), this.radii, Path.Direction.CCW);
            canvas.clipPath(contentPath, Region.Op.DIFFERENCE);
            canvas.translate((float) bounds.left, (float) bounds.top);
            super.draw(canvas);
        }
    }

    /* access modifiers changed from: private */
    public static class InsetShadowDrawable extends Drawable {
        private static final int BOTTOM_TO_TOP = 3;
        private static final int LEFT_TO_RIGHT = 0;
        private static final int RIGHT_TO_LEFT = 2;
        private static final int TOP_TO_BOTTOM = 1;
        private float blurRadius;
        private float height;
        private Paint paint;
        private Path[] paths;
        private float[] radii;
        private Shader[] shades;
        private int shadowColor;
        private float shadowXSize;
        private float shadowYSize;
        private float width;

        private InsetShadowDrawable(int viewWidth, int viewHeight, float dx, float dy, float blurRadius2, float spread, int shadowColor2, float[] radii2) {
            this.shades = new Shader[4];
            this.paths = new Path[4];
            this.blurRadius = blurRadius2;
            this.shadowColor = shadowColor2;
            this.width = ((float) viewWidth) + (dx * 2.0f);
            this.height = ((float) viewHeight) + (2.0f * dy);
            this.shadowXSize = dx + spread;
            this.shadowYSize = dy + spread;
            this.radii = radii2;
            setBounds(0, 0, viewWidth, viewHeight);
            prepare();
        }

        private void prepare() {
            PointF a = new PointF(0.0f, 0.0f);
            PointF b = new PointF(this.width, 0.0f);
            PointF c = new PointF(b.x, this.height);
            PointF d = new PointF(a.x, c.y);
            PointF e = new PointF(this.shadowXSize, this.shadowYSize);
            PointF f = new PointF(b.x - this.shadowXSize, e.y);
            PointF g = new PointF(f.x, c.y - this.shadowYSize);
            PointF h = new PointF(e.x, g.y);
            Shader ltr = new LinearGradient(e.x - this.blurRadius, e.y, e.x, e.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            Shader ttb = new LinearGradient(e.x, e.y - this.blurRadius, e.x, e.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            Shader rtl = new LinearGradient(this.blurRadius + g.x, g.y, g.x, g.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            Shader btt = new LinearGradient(g.x, this.blurRadius + g.y, g.x, g.y, this.shadowColor, 0, Shader.TileMode.CLAMP);
            Shader[] shaderArr = this.shades;
            shaderArr[0] = ltr;
            shaderArr[1] = ttb;
            shaderArr[2] = rtl;
            shaderArr[3] = btt;
            Path ltrPath = new Path();
            ltrPath.moveTo(a.x, a.y);
            ltrPath.lineTo(e.x, e.y);
            ltrPath.lineTo(h.x, h.y);
            ltrPath.lineTo(d.x, d.y);
            ltrPath.close();
            Path ttbPath = new Path();
            ttbPath.moveTo(a.x, a.y);
            ttbPath.lineTo(b.x, b.y);
            ttbPath.lineTo(f.x, f.y);
            ttbPath.lineTo(e.x, e.y);
            ttbPath.close();
            Path rtlPath = new Path();
            rtlPath.moveTo(b.x, b.y);
            rtlPath.lineTo(c.x, c.y);
            rtlPath.lineTo(g.x, g.y);
            rtlPath.lineTo(f.x, f.y);
            rtlPath.close();
            Path bttPath = new Path();
            bttPath.moveTo(d.x, d.y);
            bttPath.lineTo(c.x, c.y);
            bttPath.lineTo(g.x, g.y);
            bttPath.lineTo(h.x, h.y);
            bttPath.close();
            Path[] pathArr = this.paths;
            pathArr[0] = ltrPath;
            pathArr[1] = ttbPath;
            pathArr[2] = rtlPath;
            pathArr[3] = bttPath;
            Paint paint2 = new Paint();
            this.paint = paint2;
            paint2.setAntiAlias(true);
            this.paint.setStyle(Paint.Style.FILL);
            this.paint.setColor(this.shadowColor);
        }

        public void draw(Canvas canvas) {
            Rect bounds = canvas.getClipBounds();
            Path border = new Path();
            border.addRoundRect(new RectF(bounds), this.radii, Path.Direction.CCW);
            canvas.clipPath(border);
            canvas.translate((float) bounds.left, (float) bounds.top);
            for (int i = 0; i < 4; i++) {
                Shader shader = this.shades[i];
                Path path = this.paths[i];
                this.paint.setShader(shader);
                canvas.drawPath(path, this.paint);
            }
        }

        public void setAlpha(int alpha) {
        }

        public void setColorFilter(ColorFilter colorFilter) {
        }

        public int getOpacity() {
            return -1;
        }
    }

    public static class BoxShadowOptions {
        public float blur;
        public int color;
        public float hShadow;
        public boolean isInset;
        private List<IParser> optionParamParsers;
        public float[] radii;
        public float spread;
        public PointF topLeft;
        public float vShadow;
        public int viewHeight;
        public int viewWidth;
        private float viewport;

        /* access modifiers changed from: private */
        public interface IParser {
            void parse(String str);
        }

        private BoxShadowOptions(float vp) {
            this.viewport = 750.0f;
            this.blur = 0.0f;
            this.spread = 0.0f;
            this.radii = new float[]{0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
            this.color = -16777216;
            this.isInset = false;
            this.viewWidth = 0;
            this.viewHeight = 0;
            this.topLeft = null;
            if (750.0f != 0.0f) {
                this.viewport = vp;
            }
            this.optionParamParsers = new ArrayList();
            IParser spreadParser = new IParser() {
                /* class com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.AnonymousClass1 */

                @Override // com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.IParser
                public void parse(String param) {
                    if (!TextUtils.isEmpty(param)) {
                        float px = WXUtils.getFloat(param, Float.valueOf(0.0f)).floatValue();
                        BoxShadowOptions boxShadowOptions = BoxShadowOptions.this;
                        boxShadowOptions.spread = WXViewUtils.getRealSubPxByWidth(px, boxShadowOptions.viewport);
                        WXLogUtils.w(BoxShadowUtil.TAG, "Experimental box-shadow attribute: spread");
                    }
                }
            };
            this.optionParamParsers.add(new IParser() {
                /* class com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.AnonymousClass2 */

                @Override // com.taobao.weex.utils.BoxShadowUtil.BoxShadowOptions.IParser
                public void parse(String param) {
                    if (!TextUtils.isEmpty(param)) {
                        float px = WXUtils.getFloat(param, Float.valueOf(0.0f)).floatValue();
                        BoxShadowOptions boxShadowOptions = BoxShadowOptions.this;
                        boxShadowOptions.blur = WXViewUtils.getRealSubPxByWidth(px, boxShadowOptions.viewport);
                    }
                }
            });
            this.optionParamParsers.add(spreadParser);
        }

        public BoxShadowOptions scale(float scale) {
            if (scale <= 0.0f || scale > 1.0f) {
                return null;
            }
            BoxShadowOptions scaledOptions = new BoxShadowOptions(this.viewport);
            scaledOptions.hShadow = this.hShadow * scale;
            scaledOptions.vShadow = this.vShadow * scale;
            scaledOptions.blur = this.blur * scale;
            scaledOptions.spread = this.spread * scale;
            int i = 0;
            while (true) {
                float[] fArr = this.radii;
                if (i >= fArr.length) {
                    break;
                }
                scaledOptions.radii[i] = fArr[i] * scale;
                i++;
            }
            scaledOptions.viewHeight = (int) (((float) this.viewHeight) * scale);
            scaledOptions.viewWidth = (int) (((float) this.viewWidth) * scale);
            if (this.topLeft != null) {
                PointF pointF = new PointF();
                scaledOptions.topLeft = pointF;
                pointF.x = this.topLeft.x * scale;
                scaledOptions.topLeft.y = this.topLeft.y * scale;
            }
            scaledOptions.color = this.color;
            scaledOptions.isInset = this.isInset;
            WXLogUtils.d(BoxShadowUtil.TAG, "Scaled BoxShadowOptions: [" + scale + "] " + scaledOptions);
            return scaledOptions;
        }

        public Rect getTargetCanvasRect() {
            return new Rect(0, 0, this.viewWidth + (((int) (this.blur + this.spread + Math.abs(this.hShadow))) * 2), this.viewHeight + (((int) (this.blur + this.spread + Math.abs(this.vShadow))) * 2));
        }

        public String toString() {
            StringBuffer sb = new StringBuffer("BoxShadowOptions{");
            sb.append("h-shadow=");
            sb.append(this.hShadow);
            sb.append(", v-shadow=");
            sb.append(this.vShadow);
            sb.append(", blur=");
            sb.append(this.blur);
            sb.append(", spread=");
            sb.append(this.spread);
            sb.append(", corner-radius=");
            sb.append(Operators.ARRAY_START_STR + this.radii[0] + "," + this.radii[2] + "," + this.radii[4] + "," + this.radii[6] + Operators.ARRAY_END_STR);
            sb.append(", color=#");
            sb.append(Integer.toHexString(this.color));
            sb.append(", inset=");
            sb.append(this.isInset);
            sb.append(Operators.BLOCK_END);
            return sb.toString();
        }
    }
}
