package com.taobao.weex.wson;

import androidx.collection.LruCache;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import com.alipay.sdk.m.n.a;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.common.DHInterface.IApp;
import java.lang.reflect.Array;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class Wson {
    private static final byte ARRAY_TYPE = 91;
    private static final byte BOOLEAN_TYPE_FALSE = 102;
    private static final byte BOOLEAN_TYPE_TRUE = 116;
    private static final int GLOBAL_STRING_CACHE_SIZE = 2048;
    private static final boolean IS_NATIVE_LITTLE_ENDIAN = (ByteOrder.nativeOrder() == ByteOrder.LITTLE_ENDIAN);
    private static final byte MAP_TYPE = 123;
    private static final String METHOD_PREFIX_GET = "get";
    private static final String METHOD_PREFIX_IS = "is";
    private static final byte NULL_TYPE = 48;
    private static final byte NUMBER_BIG_DECIMAL_TYPE = 101;
    private static final byte NUMBER_BIG_INTEGER_TYPE = 103;
    private static final byte NUMBER_DOUBLE_TYPE = 100;
    private static final byte NUMBER_FLOAT_TYPE = 70;
    private static final byte NUMBER_INT_TYPE = 105;
    private static final byte NUMBER_LONG_TYPE = 108;
    private static final byte STRING_TYPE = 115;
    public static final boolean WriteMapNullValue = false;
    private static LruCache<String, List<Field>> fieldsCache = new LruCache<>(128);
    private static final String[] globalStringBytesCache = new String[2048];
    private static final ThreadLocal<char[]> localCharsBufferCache = new ThreadLocal<>();
    private static LruCache<String, List<Method>> methodsCache = new LruCache<>(128);
    private static LruCache<String, Boolean> specialClass = new LruCache<>(16);

    public static final Object parse(byte[] data) {
        if (data == null) {
            return null;
        }
        try {
            Parser parser = new Parser(data);
            Object object = parser.parse();
            parser.close();
            return object;
        } catch (Exception e) {
            WXLogUtils.e("parseWson", e);
            return null;
        }
    }

    public static final byte[] toWson(Object object) {
        if (object == null) {
            return null;
        }
        Builder builder = new Builder();
        byte[] bts = builder.toWson(object);
        builder.close();
        return bts;
    }

    /* access modifiers changed from: private */
    public static final class Parser {
        private byte[] buffer;
        private char[] charsBuffer;
        private int position;

        private Parser(byte[] buffer2) {
            this.position = 0;
            this.buffer = buffer2;
            char[] cArr = (char[]) Wson.localCharsBufferCache.get();
            this.charsBuffer = cArr;
            if (cArr != null) {
                Wson.localCharsBufferCache.set(null);
            } else {
                this.charsBuffer = new char[512];
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private final Object parse() {
            return readObject();
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private final void close() {
            this.position = 0;
            this.buffer = null;
            if (this.charsBuffer != null) {
                Wson.localCharsBufferCache.set(this.charsBuffer);
            }
            this.charsBuffer = null;
        }

        private final Object readObject() {
            byte type = readType();
            if (type == 48) {
                return null;
            }
            if (type == 70) {
                return readFloat();
            }
            if (type == 91) {
                return readArray();
            }
            if (type == 105) {
                return Integer.valueOf(readVarInt());
            }
            if (type == 108) {
                return Long.valueOf(readLong());
            }
            if (type == 123) {
                return readMap();
            }
            if (type == 115) {
                return readUTF16String();
            }
            if (type == 116) {
                return Boolean.TRUE;
            }
            switch (type) {
                case 100:
                    return readDouble();
                case 101:
                    return new BigDecimal(readUTF16String());
                case 102:
                    return Boolean.FALSE;
                case 103:
                    return new BigInteger(readUTF16String());
                default:
                    throw new RuntimeException("wson unhandled type " + ((int) type) + Operators.SPACE_STR + this.position + " length " + this.buffer.length);
            }
        }

        private final Object readMap() {
            int size = readUInt();
            Map<String, Object> object = new JSONObject();
            for (int i = 0; i < size; i++) {
                object.put(readMapKeyUTF16(), readObject());
            }
            return object;
        }

        private final Object readArray() {
            int length = readUInt();
            List<Object> array = new JSONArray(length);
            for (int i = 0; i < length; i++) {
                array.add(readObject());
            }
            return array;
        }

        private final byte readType() {
            byte[] bArr = this.buffer;
            int i = this.position;
            byte type = bArr[i];
            this.position = i + 1;
            return type;
        }

        private final String readMapKeyUTF16() {
            int length = readUInt() / 2;
            if (this.charsBuffer.length < length) {
                this.charsBuffer = new char[length];
            }
            int hash = 5381;
            if (Wson.IS_NATIVE_LITTLE_ENDIAN) {
                for (int i = 0; i < length; i++) {
                    byte[] bArr = this.buffer;
                    int i2 = this.position;
                    char ch = (char) ((bArr[i2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) + (bArr[i2 + 1] << 8));
                    this.charsBuffer[i] = ch;
                    hash = (hash << 5) + hash + ch;
                    this.position = i2 + 2;
                }
            } else {
                for (int i3 = 0; i3 < length; i3++) {
                    byte[] bArr2 = this.buffer;
                    int i4 = this.position;
                    char ch2 = (char) ((bArr2[i4 + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) + (bArr2[i4] << 8));
                    this.charsBuffer[i3] = ch2;
                    hash = (hash << 5) + hash + ch2;
                    this.position = i4 + 2;
                }
            }
            int globalIndex = (Wson.globalStringBytesCache.length - 1) & hash;
            String cache = Wson.globalStringBytesCache[globalIndex];
            if (cache != null && cache.length() == length) {
                boolean isStringEqual = true;
                int i5 = 0;
                while (true) {
                    if (i5 >= length) {
                        break;
                    } else if (this.charsBuffer[i5] != cache.charAt(i5)) {
                        isStringEqual = false;
                        break;
                    } else {
                        i5++;
                    }
                }
                if (isStringEqual) {
                    return cache;
                }
            }
            String cache2 = new String(this.charsBuffer, 0, length);
            if (length < 64) {
                Wson.globalStringBytesCache[globalIndex] = cache2;
            }
            return cache2;
        }

        private final String readUTF16String() {
            int length = readUInt() / 2;
            if (this.charsBuffer.length < length) {
                this.charsBuffer = new char[length];
            }
            if (Wson.IS_NATIVE_LITTLE_ENDIAN) {
                for (int i = 0; i < length; i++) {
                    byte[] bArr = this.buffer;
                    int i2 = this.position;
                    this.charsBuffer[i] = (char) ((bArr[i2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) + (bArr[i2 + 1] << 8));
                    this.position = i2 + 2;
                }
            } else {
                for (int i3 = 0; i3 < length; i3++) {
                    byte[] bArr2 = this.buffer;
                    int i4 = this.position;
                    this.charsBuffer[i3] = (char) ((bArr2[i4 + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) + (bArr2[i4] << 8));
                    this.position = i4 + 2;
                }
            }
            return new String(this.charsBuffer, 0, length);
        }

        private final int readVarInt() {
            int raw = readUInt();
            return (Integer.MIN_VALUE & raw) ^ ((((raw << 31) >> 31) ^ raw) >> 1);
        }

        private final int readUInt() {
            int value = 0;
            int i = 0;
            do {
                byte[] bArr = this.buffer;
                int i2 = this.position;
                byte b = bArr[i2];
                if ((b & 128) != 0) {
                    value |= (b & Byte.MAX_VALUE) << i;
                    i += 7;
                    this.position = i2 + 1;
                } else {
                    this.position = i2 + 1;
                    return (b << i) | value;
                }
            } while (i <= 35);
            throw new IllegalArgumentException("Variable length quantity is too long");
        }

        private final long readLong() {
            byte[] bArr = this.buffer;
            int i = this.position;
            long number = (((long) bArr[i + 7]) & 255) + ((((long) bArr[i + 6]) & 255) << 8) + ((((long) bArr[i + 5]) & 255) << 16) + ((((long) bArr[i + 4]) & 255) << 24) + ((((long) bArr[i + 3]) & 255) << 32) + ((((long) bArr[i + 2]) & 255) << 40) + ((255 & ((long) bArr[i + 1])) << 48) + (((long) bArr[i]) << 56);
            this.position = i + 8;
            return number;
        }

        private final Object readDouble() {
            double number = Double.longBitsToDouble(readLong());
            if (number > 2.147483647E9d) {
                long numberLong = (long) number;
                if (number - ((double) numberLong) < Double.MIN_NORMAL) {
                    return Long.valueOf(numberLong);
                }
            }
            return Double.valueOf(number);
        }

        private Object readFloat() {
            byte[] bArr = this.buffer;
            int i = this.position;
            this.position = i + 4;
            return Float.valueOf(Float.intBitsToFloat((bArr[i + 3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) + ((bArr[i + 2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) + ((bArr[i + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) + ((bArr[i] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 24)));
        }
    }

    /* access modifiers changed from: private */
    public static final class Builder {
        private static final ThreadLocal<byte[]> bufLocal = new ThreadLocal<>();
        private static final ThreadLocal<ArrayList> refsLocal = new ThreadLocal<>();
        private byte[] buffer;
        private int position;
        private ArrayList refs;

        private Builder() {
            byte[] bArr = bufLocal.get();
            this.buffer = bArr;
            if (bArr != null) {
                bufLocal.set(null);
            } else {
                this.buffer = new byte[1024];
            }
            ArrayList arrayList = refsLocal.get();
            this.refs = arrayList;
            if (arrayList != null) {
                refsLocal.set(null);
            } else {
                this.refs = new ArrayList(16);
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private final byte[] toWson(Object object) {
            writeObject(object);
            int i = this.position;
            byte[] bts = new byte[i];
            System.arraycopy(this.buffer, 0, bts, 0, i);
            return bts;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private final void close() {
            byte[] bArr = this.buffer;
            if (bArr.length <= 16384) {
                bufLocal.set(bArr);
            }
            if (this.refs.isEmpty()) {
                refsLocal.set(this.refs);
            } else {
                this.refs.clear();
            }
            this.refs = null;
            this.buffer = null;
            this.position = 0;
        }

        private final void writeObject(Object object) {
            if (object instanceof CharSequence) {
                ensureCapacity(2);
                writeByte(Wson.STRING_TYPE);
                writeUTF16String((CharSequence) object);
            } else if (object instanceof Map) {
                if (this.refs.contains(object)) {
                    ensureCapacity(2);
                    writeByte(Wson.NULL_TYPE);
                    return;
                }
                this.refs.add(object);
                writeMap((Map) object);
                ArrayList arrayList = this.refs;
                arrayList.remove(arrayList.size() - 1);
            } else if (object instanceof List) {
                if (this.refs.contains(object)) {
                    ensureCapacity(2);
                    writeByte(Wson.NULL_TYPE);
                    return;
                }
                this.refs.add(object);
                ensureCapacity(8);
                List<Object> list = (List) object;
                writeByte(Wson.ARRAY_TYPE);
                writeUInt(list.size());
                for (Object value : list) {
                    writeObject(value);
                }
                ArrayList arrayList2 = this.refs;
                arrayList2.remove(arrayList2.size() - 1);
            } else if (object instanceof Number) {
                writeNumber((Number) object);
            } else if (object instanceof Boolean) {
                ensureCapacity(2);
                if (((Boolean) object).booleanValue()) {
                    writeByte(Wson.BOOLEAN_TYPE_TRUE);
                } else {
                    writeByte(Wson.BOOLEAN_TYPE_FALSE);
                }
            } else if (object == null) {
                ensureCapacity(2);
                writeByte(Wson.NULL_TYPE);
            } else if (object.getClass().isArray()) {
                if (this.refs.contains(object)) {
                    ensureCapacity(2);
                    writeByte(Wson.NULL_TYPE);
                    return;
                }
                this.refs.add(object);
                ensureCapacity(8);
                int length = Array.getLength(object);
                writeByte(Wson.ARRAY_TYPE);
                writeUInt(length);
                for (int i = 0; i < length; i++) {
                    writeObject(Array.get(object, i));
                }
                ArrayList arrayList3 = this.refs;
                arrayList3.remove(arrayList3.size() - 1);
            } else if (object instanceof Date) {
                ensureCapacity(10);
                writeByte(Wson.NUMBER_DOUBLE_TYPE);
                writeDouble((double) ((Date) object).getTime());
            } else if (object instanceof Calendar) {
                ensureCapacity(10);
                writeByte(Wson.NUMBER_DOUBLE_TYPE);
                writeDouble((double) ((Calendar) object).getTime().getTime());
            } else if (object instanceof Collection) {
                if (this.refs.contains(object)) {
                    ensureCapacity(2);
                    writeByte(Wson.NULL_TYPE);
                    return;
                }
                this.refs.add(object);
                ensureCapacity(8);
                Collection<Object> list2 = (Collection) object;
                writeByte(Wson.ARRAY_TYPE);
                writeUInt(list2.size());
                for (Object value2 : list2) {
                    writeObject(value2);
                }
                ArrayList arrayList4 = this.refs;
                arrayList4.remove(arrayList4.size() - 1);
            } else if (this.refs.contains(object)) {
                ensureCapacity(2);
                writeByte(Wson.NULL_TYPE);
            } else {
                this.refs.add(object);
                if (object.getClass().isEnum()) {
                    writeObject(JSON.toJSONString(object));
                } else {
                    writeAdapterObject(object);
                }
                ArrayList arrayList5 = this.refs;
                arrayList5.remove(arrayList5.size() - 1);
            }
        }

        private final void writeNumber(Number number) {
            ensureCapacity(12);
            if (number instanceof Integer) {
                writeByte(Wson.NUMBER_INT_TYPE);
                writeVarInt(number.intValue());
            } else if (number instanceof Float) {
                writeByte(Wson.NUMBER_FLOAT_TYPE);
                writeFloat(number.floatValue());
            } else if (number instanceof Double) {
                writeByte(Wson.NUMBER_DOUBLE_TYPE);
                writeDouble(number.doubleValue());
            } else if (number instanceof Long) {
                writeByte(Wson.NUMBER_LONG_TYPE);
                writeLong(number.longValue());
            } else if ((number instanceof Short) || (number instanceof Byte)) {
                writeByte(Wson.NUMBER_INT_TYPE);
                writeVarInt(number.intValue());
            } else if (number instanceof BigInteger) {
                writeByte(Wson.NUMBER_BIG_INTEGER_TYPE);
                writeUTF16String(number.toString());
            } else if (number instanceof BigDecimal) {
                String value = number.toString();
                double doubleValue = number.doubleValue();
                if (value.equals(Double.toString(doubleValue))) {
                    writeByte(Wson.NUMBER_DOUBLE_TYPE);
                    writeDouble(doubleValue);
                    return;
                }
                writeByte(Wson.NUMBER_BIG_DECIMAL_TYPE);
                writeUTF16String(value);
            } else {
                writeByte(Wson.STRING_TYPE);
                writeUTF16String(number.toString());
            }
        }

        private final void writeMap(Map map) {
            Set<Map.Entry<Object, Object>> entries = map.entrySet();
            int nullValueSize = 0;
            for (Map.Entry<Object, Object> entry : entries) {
                if (entry.getValue() == null) {
                    nullValueSize++;
                }
            }
            ensureCapacity(8);
            writeByte(Wson.MAP_TYPE);
            writeUInt(map.size() - nullValueSize);
            for (Map.Entry<Object, Object> entry2 : entries) {
                if (entry2.getValue() != null) {
                    writeMapKeyUTF16(entry2.getKey().toString());
                    writeObject(entry2.getValue());
                }
            }
        }

        private final void writeByte(byte type) {
            byte[] bArr = this.buffer;
            int i = this.position;
            bArr[i] = type;
            this.position = i + 1;
        }

        private final void writeAdapterObject(Object object) {
            if (Wson.specialClass.get(object.getClass().getName()) != null) {
                writeObject(JSON.toJSON(object));
                return;
            }
            try {
                writeMap(toMap(object));
            } catch (Exception e) {
                Wson.specialClass.put(object.getClass().getName(), true);
                writeObject(JSON.toJSON(object));
            }
        }

        private final Map toMap(Object object) {
            Object value;
            Map map = new JSONObject();
            try {
                Class<?> targetClass = object.getClass();
                String key = targetClass.getName();
                for (Method method : Wson.getBeanMethod(key, targetClass)) {
                    String methodName = method.getName();
                    if (methodName.startsWith(Wson.METHOD_PREFIX_GET)) {
                        Object value2 = method.invoke(object, new Object[0]);
                        if (value2 != null) {
                            StringBuilder builder = new StringBuilder(method.getName().substring(3));
                            builder.setCharAt(0, Character.toLowerCase(builder.charAt(0)));
                            map.put(builder.toString(), value2);
                        }
                    } else if (methodName.startsWith("is") && (value = method.invoke(object, new Object[0])) != null) {
                        StringBuilder builder2 = new StringBuilder(method.getName().substring(2));
                        builder2.setCharAt(0, Character.toLowerCase(builder2.charAt(0)));
                        map.put(builder2.toString(), value);
                    }
                }
                for (Field field : Wson.getBeanFields(key, targetClass)) {
                    String fieldName = field.getName();
                    if (!map.containsKey(fieldName)) {
                        Object value3 = field.get(object);
                        if (value3 != null) {
                            map.put(fieldName, value3);
                        }
                    }
                }
                return map;
            } catch (Exception e) {
                if (e instanceof RuntimeException) {
                    throw ((RuntimeException) e);
                }
                throw new RuntimeException(e);
            }
        }

        private final void writeMapKeyUTF16(String value) {
            writeUTF16String(value);
        }

        private final void writeUTF16String(CharSequence value) {
            int length = value.length();
            ensureCapacity((length * 2) + 8);
            writeUInt(length * 2);
            if (Wson.IS_NATIVE_LITTLE_ENDIAN) {
                for (int i = 0; i < length; i++) {
                    char ch = value.charAt(i);
                    byte[] bArr = this.buffer;
                    int i2 = this.position;
                    bArr[i2] = (byte) ch;
                    bArr[i2 + 1] = (byte) (ch >>> '\b');
                    this.position = i2 + 2;
                }
                return;
            }
            for (int i3 = 0; i3 < length; i3++) {
                char ch2 = value.charAt(i3);
                byte[] bArr2 = this.buffer;
                int i4 = this.position;
                bArr2[i4 + 1] = (byte) ch2;
                bArr2[i4] = (byte) (ch2 >>> '\b');
                this.position = i4 + 2;
            }
        }

        private final void writeDouble(double value) {
            writeLong(Double.doubleToLongBits(value));
        }

        private final void writeFloat(float value) {
            int val = Float.floatToIntBits(value);
            byte[] bArr = this.buffer;
            int i = this.position;
            bArr[i + 3] = (byte) val;
            bArr[i + 2] = (byte) (val >>> 8);
            bArr[i + 1] = (byte) (val >>> 16);
            bArr[i] = (byte) (val >>> 24);
            this.position = i + 4;
        }

        private final void writeLong(long val) {
            byte[] bArr = this.buffer;
            int i = this.position;
            bArr[i + 7] = (byte) ((int) val);
            bArr[i + 6] = (byte) ((int) (val >>> 8));
            bArr[i + 5] = (byte) ((int) (val >>> 16));
            bArr[i + 4] = (byte) ((int) (val >>> 24));
            bArr[i + 3] = (byte) ((int) (val >>> 32));
            bArr[i + 2] = (byte) ((int) (val >>> 40));
            bArr[i + 1] = (byte) ((int) (val >>> 48));
            bArr[i] = (byte) ((int) (val >>> 56));
            this.position = i + 8;
        }

        private final void writeVarInt(int value) {
            writeUInt((value << 1) ^ (value >> 31));
        }

        private final void writeUInt(int value) {
            while ((value & a.g) != 0) {
                byte[] bArr = this.buffer;
                int i = this.position;
                bArr[i] = (byte) ((value & 127) | 128);
                this.position = i + 1;
                value >>>= 7;
            }
            byte[] bArr2 = this.buffer;
            int i2 = this.position;
            bArr2[i2] = (byte) (value & 127);
            this.position = i2 + 1;
        }

        private final void ensureCapacity(int minCapacity) {
            int minCapacity2 = minCapacity + this.position;
            byte[] bArr = this.buffer;
            if (minCapacity2 - bArr.length > 0) {
                int newCapacity = bArr.length << 1;
                if (newCapacity < 16384) {
                    newCapacity = 16384;
                }
                if (newCapacity - minCapacity2 < 0) {
                    newCapacity = minCapacity2;
                }
                this.buffer = Arrays.copyOf(this.buffer, newCapacity);
            }
        }
    }

    /* access modifiers changed from: private */
    public static final List<Method> getBeanMethod(String key, Class targetClass) {
        List<Method> methods = methodsCache.get(key);
        if (methods == null) {
            methods = new ArrayList();
            Method[] allMethods = targetClass.getMethods();
            for (Method method : allMethods) {
                if (method.getDeclaringClass() != Object.class && (method.getModifiers() & 8) == 0) {
                    String methodName = method.getName();
                    if (methodName.startsWith(METHOD_PREFIX_GET) || methodName.startsWith("is")) {
                        if (method.getAnnotation(JSONField.class) == null) {
                            methods.add(method);
                        } else {
                            throw new UnsupportedOperationException("getBeanMethod JSONField Annotation Not Handled, Use toJSON");
                        }
                    }
                }
            }
            methodsCache.put(key, methods);
        }
        return methods;
    }

    /* access modifiers changed from: private */
    public static final List<Field> getBeanFields(String key, Class targetClass) {
        List<Field> fieldList = fieldsCache.get(key);
        if (fieldList == null) {
            Field[] fields = targetClass.getFields();
            fieldList = new ArrayList(fields.length);
            for (Field field : fields) {
                if ((field.getModifiers() & 8) == 0) {
                    if (field.getAnnotation(JSONField.class) == null) {
                        fieldList.add(field);
                    } else {
                        throw new UnsupportedOperationException("getBeanMethod JSONField Annotation Not Handled, Use toJSON");
                    }
                }
            }
            fieldsCache.put(key, fieldList);
        }
        return fieldList;
    }
}
