package io.dcloud.feature.uniapp.utils;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BlurMaskFilter;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PaintFlagsDrawFilter;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Region;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.text.TextUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowData;
import io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowOptions;
import io.dcloud.feature.uniapp.ui.shadow.UniInsetBoxShadowDrawable;
import io.dcloud.feature.uniapp.ui.shadow.UniInsetBoxShadowLayer;
import io.dcloud.feature.uniapp.ui.shadow.UniNormalBoxShadowDrawable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class UniBoxShadowUtil {
    private static final String TAG = "UniBoxShadowUtil";
    private static boolean sBoxShadowEnabled = true;
    private static Pattern sColorPattern;

    public static void setBoxShadowEnabled(boolean enabled) {
        sBoxShadowEnabled = enabled;
        WXLogUtils.w(TAG, "Switch box-shadow status: " + enabled);
    }

    public static boolean isBoxShadowEnabled() {
        return sBoxShadowEnabled;
    }

    public static UniBoxShadowData parseBoxShadow(int width, int height, String style, float[] radii, float viewPort, float quality) {
        if (!sBoxShadowEnabled) {
            WXLogUtils.w(TAG, "box-shadow was disabled by config");
            return null;
        }
        UniBoxShadowOptions[] shadows = parseBoxShadows(style, viewPort);
        if (shadows == null || shadows.length == 0) {
            WXLogUtils.w(TAG, "Failed to parse box-shadow: " + style);
            return null;
        }
        List<UniBoxShadowOptions> normalShadows = new ArrayList<>();
        List<UniBoxShadowOptions> insetShadows = new ArrayList<>();
        for (UniBoxShadowOptions shadow : shadows) {
            if (shadow != null) {
                if (shadow.isInset) {
                    insetShadows.add(0, shadow);
                } else {
                    normalShadows.add(0, shadow);
                }
            }
        }
        if (!(radii == null || radii.length == 8)) {
            WXLogUtils.w(TAG, "Length of radii must be 8");
        }
        UniBoxShadowData data = new UniBoxShadowData(normalShadows, insetShadows, radii, quality);
        data.setStyle(style);
        if (normalShadows.size() > 0) {
            int maxWidth = 0;
            int maxHeight = 0;
            for (UniBoxShadowOptions option : normalShadows) {
                option.viewWidth = width;
                option.viewHeight = height;
                option.radii = radii;
                Rect rect = option.getTargetCanvasRect();
                if (maxWidth < rect.width()) {
                    maxWidth = rect.width();
                }
                if (maxHeight < rect.height()) {
                    maxHeight = rect.height();
                }
            }
            data.setNormalMaxWidth(maxWidth);
            data.setNormalMaxHeight(maxHeight);
            data.setNormalLeft(maxWidth - width);
            data.setNormalTop(maxHeight - height);
        }
        data.setContentHeight(height);
        data.setContentWidth(width);
        return data;
    }

    public static UniBoxShadowOptions[] parseBoxShadows(String boxShadowStyle, float viewport) {
        if (sColorPattern == null) {
            sColorPattern = Pattern.compile("([rR][gG][bB][aA]?)\\((\\d+\\s*),\\s*(\\d+\\s*),\\s*(\\d+\\s*)(?:,\\s*(\\d+(?:\\.\\d+)?))?\\)");
        }
        Matcher matcher = sColorPattern.matcher(boxShadowStyle);
        String processedStyle = boxShadowStyle;
        while (matcher.find()) {
            String color = matcher.group();
            processedStyle = processedStyle.replace(color, "#" + StringUtil.format("%8s", Integer.toHexString(WXResourceUtils.getColor(color, -16777216))).replaceAll("\\s", "0"));
        }
        String[] styles = processedStyle.split(",");
        if (styles == null || styles.length <= 0) {
            return null;
        }
        UniBoxShadowOptions[] result = new UniBoxShadowOptions[styles.length];
        for (int i = 0; i < styles.length; i++) {
            result[i] = parseBoxShadow(styles[i], viewport);
        }
        return result;
    }

    private static UniBoxShadowOptions parseBoxShadow(String boxShadow, float viewport) {
        UniBoxShadowOptions result = new UniBoxShadowOptions(viewport);
        if (TextUtils.isEmpty(boxShadow)) {
            return null;
        }
        String boxShadowCopy = boxShadow.replaceAll("\\s*,\\s+", ",");
        if (boxShadowCopy.contains("inset")) {
            result.isInset = true;
            boxShadowCopy = boxShadowCopy.replace("inset", "");
        }
        List<String> params = new ArrayList<>(Arrays.asList(boxShadowCopy.trim().split("\\s+")));
        String maybeColor = params.get(params.size() - 1);
        if (!TextUtils.isEmpty(maybeColor) && (maybeColor.startsWith("#") || maybeColor.startsWith("rgb") || WXResourceUtils.isNamedColor(maybeColor))) {
            result.color = WXResourceUtils.getColor(maybeColor, -16777216);
            params.remove(params.size() - 1);
        }
        try {
            if (params.size() < 2) {
                return null;
            }
            if (!TextUtils.isEmpty(params.get(0))) {
                result.hShadow = WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(params.get(0).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
            }
            if (!TextUtils.isEmpty(params.get(1))) {
                result.vShadow = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(params.get(1).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
            }
            for (int i = 2; i < params.size(); i++) {
                result.optionParamParsers.get(i - 2).parse(params.get(i));
            }
            return result;
        } catch (Throwable t) {
            t.printStackTrace();
        }
    }

    public static UniNormalBoxShadowDrawable getNormalBoxShadowDrawable(UniBoxShadowData shadowData, Resources resources) {
        if (shadowData.getNormalShadows().size() <= 0) {
            return null;
        }
        Bitmap bitmap = Bitmap.createBitmap(shadowData.getCanvasWidth(), shadowData.getCanvasHeight(), Bitmap.Config.ARGB_4444);
        if (Build.VERSION.SDK_INT >= 19) {
            Logger.e(TAG, "Allocation memory for box-shadow: " + (bitmap.getAllocationByteCount() / 1024) + " KB");
        }
        Canvas canvas = new Canvas(bitmap);
        canvas.setDrawFilter(new PaintFlagsDrawFilter(0, 3));
        for (UniBoxShadowOptions option : shadowData.getNormalShadows()) {
            drawShadow(canvas, option.scale(shadowData.getQuality()), (float) shadowData.getNormalTop(), (float) shadowData.getNormalLeft(), shadowData.getQuality());
        }
        return new UniNormalBoxShadowDrawable(resources, bitmap);
    }

    private static void drawShadow(Canvas canvas, UniBoxShadowOptions options, float normalTop, float normalLeft, float quality) {
        float shadowDx;
        float shadowDy;
        float shadowDx2;
        float f = 0.0f;
        RectF shadowRect = new RectF(0.0f, 0.0f, ((float) options.viewWidth) + (options.spread * 2.0f), ((float) options.viewHeight) + (options.spread * 2.0f));
        float shadowDx3 = options.blur;
        float shadowDy2 = options.blur;
        if (options.hShadow >= 0.0f) {
            shadowDx = shadowDx3 + (options.hShadow * 2.0f);
        } else {
            shadowDx = 0.0f;
        }
        if (options.vShadow >= 0.0f) {
            shadowDy = shadowDy2 + (options.vShadow * 2.0f);
        } else {
            shadowDy = 0.0f;
        }
        shadowRect.offset(shadowDx, shadowDy);
        Path contentPath = new Path();
        RectF clipRect = new RectF(0.0f, 0.0f, (float) options.viewWidth, (float) options.viewHeight);
        float dy = 0.0f;
        float dx = 0.0f;
        if (normalTop > 0.0f) {
            dy = (normalTop * quality) / 2.0f;
        }
        if (normalLeft > 0.0f) {
            dx = (normalLeft * quality) / 2.0f;
        }
        clipRect.offset(dx, dy);
        clipRect.inset(1.0f, 1.0f);
        contentPath.addRoundRect(clipRect, options.radii, Path.Direction.CCW);
        canvas.clipPath(contentPath, Region.Op.DIFFERENCE);
        Paint shadowPaint = new Paint();
        shadowPaint.setAntiAlias(true);
        shadowPaint.setColor(options.color);
        shadowPaint.setStyle(Paint.Style.FILL);
        if (options.blur > 0.0f) {
            shadowPaint.setMaskFilter(new BlurMaskFilter(options.blur, BlurMaskFilter.Blur.NORMAL));
        }
        float borderRadius = options.radii[0];
        if (borderRadius == options.radii[2] && borderRadius == options.radii[4] && borderRadius == options.radii[6]) {
            canvas.drawRoundRect(shadowRect, borderRadius, borderRadius, shadowPaint);
            return;
        }
        Path shadowPath = new Path();
        float[] shadowRadii = new float[8];
        int i = 0;
        while (i < options.radii.length) {
            if (options.radii[i] == f) {
                shadowRadii[i] = f;
                shadowDx2 = shadowDx;
            } else {
                shadowDx2 = shadowDx;
                shadowRadii[i] = options.radii[i] + options.spread;
            }
            i++;
            shadowDx = shadowDx2;
            f = 0.0f;
        }
        shadowPath.addRoundRect(shadowRect, shadowRadii, Path.Direction.CW);
        canvas.drawPath(shadowPath, shadowPaint);
    }

    public static UniInsetBoxShadowLayer getInsetBoxShadowDrawable(UniBoxShadowData shadowData) {
        if (shadowData.getInsetShadows().size() <= 0) {
            return null;
        }
        if (Build.VERSION.SDK_INT >= 18) {
            Drawable[] drawables = new Drawable[shadowData.getInsetShadows().size()];
            for (int i = 0; i < shadowData.getInsetShadows().size(); i++) {
                UniBoxShadowOptions option = shadowData.getInsetShadows().get(i);
                drawables[i] = new UniInsetBoxShadowDrawable(shadowData.getContentWidth(), shadowData.getContentHeight(), option.hShadow, option.vShadow, option.blur, option.spread, option.color, shadowData.getRadii());
            }
            return new UniInsetBoxShadowLayer(drawables);
        }
        WXLogUtils.w(TAG, "Call setInsetBoxShadow() requires API level 18 or higher.");
        return null;
    }
}
