package net.ossrs.yasea;

import android.media.MediaCodec;
import android.media.MediaFormat;
import android.util.Log;
import com.github.faucamp.simplertmp.DefaultRtmpPublisher;
import com.github.faucamp.simplertmp.RtmpHandler;
import com.umeng.analytics.pro.cv;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.atomic.AtomicInteger;
import net.ossrs.yasea.SrsAllocator;

public class SrsFlvMuxer {
    private static final int AUDIO_ALLOC_SIZE = 4096;
    private static final int AUDIO_TRACK = 101;
    private static final String TAG = "SrsFlvMuxer";
    private static final int VIDEO_ALLOC_SIZE = 131072;
    private static final int VIDEO_TRACK = 100;
    private SrsFlv flv = new SrsFlv();
    private SrsAllocator mAudioAllocator = new SrsAllocator(4096);
    private SrsFlvFrame mAudioSequenceHeader;
    private ConcurrentLinkedQueue<SrsFlvFrame> mFlvTagCache = new ConcurrentLinkedQueue<>();
    private SrsAllocator mVideoAllocator = new SrsAllocator(131072);
    private SrsFlvFrame mVideoSequenceHeader;
    private boolean needToFindKeyFrame = true;
    private DefaultRtmpPublisher publisher;
    private volatile boolean started = false;
    private final Object txFrameLock = new Object();
    private Thread worker;

    public SrsFlvMuxer(RtmpHandler handler) {
        this.publisher = new DefaultRtmpPublisher(handler);
    }

    public AtomicInteger getVideoFrameCacheNumber() {
        DefaultRtmpPublisher defaultRtmpPublisher = this.publisher;
        if (defaultRtmpPublisher == null) {
            return null;
        }
        return defaultRtmpPublisher.getVideoFrameCacheNumber();
    }

    public void setVideoResolution(int width, int height) {
        DefaultRtmpPublisher defaultRtmpPublisher = this.publisher;
        if (defaultRtmpPublisher != null) {
            defaultRtmpPublisher.setVideoResolution(width, height);
        }
    }

    public int addTrack(MediaFormat format) {
        if (format.getString("mime").contentEquals("video/avc")) {
            this.flv.setVideoTrack(format);
            return 100;
        }
        this.flv.setAudioTrack(format);
        return 101;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void disconnect() {
        try {
            this.publisher.close();
        } catch (IllegalStateException e) {
        }
        this.mVideoSequenceHeader = null;
        this.mAudioSequenceHeader = null;
        Log.i(TAG, "worker: disconnect ok.");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean connect(String url) {
        boolean connected = false;
        Log.i(TAG, String.format("worker: connecting to RTMP server by url=%s\n", url));
        if (this.publisher.connect(url)) {
            connected = this.publisher.publish("live");
        }
        this.mVideoSequenceHeader = null;
        this.mAudioSequenceHeader = null;
        return connected;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sendFlvTag(SrsFlvFrame frame) {
        if (frame != null) {
            if (frame.isVideo()) {
                if (frame.isKeyFrame()) {
                    Log.i(TAG, String.format("worker: send frame type=%d, dts=%d, size=%dB", Integer.valueOf(frame.type), Integer.valueOf(frame.dts), Integer.valueOf(frame.flvTag.array().length)));
                }
                this.publisher.publishVideoData(frame.flvTag.array(), frame.flvTag.size(), frame.dts);
                this.mVideoAllocator.release(frame.flvTag);
            } else if (frame.isAudio()) {
                this.publisher.publishAudioData(frame.flvTag.array(), frame.flvTag.size(), frame.dts);
                this.mAudioAllocator.release(frame.flvTag);
            }
        }
    }

    public void start(final String rtmpUrl) {
        this.started = true;
        Thread thread = new Thread(new Runnable() {
            /* class net.ossrs.yasea.SrsFlvMuxer.AnonymousClass1 */

            public void run() {
                if (SrsFlvMuxer.this.connect(rtmpUrl)) {
                    while (!Thread.interrupted()) {
                        while (!SrsFlvMuxer.this.mFlvTagCache.isEmpty()) {
                            SrsFlvFrame frame = (SrsFlvFrame) SrsFlvMuxer.this.mFlvTagCache.poll();
                            if (frame.isSequenceHeader()) {
                                if (frame.isVideo()) {
                                    SrsFlvMuxer.this.mVideoSequenceHeader = frame;
                                    SrsFlvMuxer srsFlvMuxer = SrsFlvMuxer.this;
                                    srsFlvMuxer.sendFlvTag(srsFlvMuxer.mVideoSequenceHeader);
                                } else if (frame.isAudio()) {
                                    SrsFlvMuxer.this.mAudioSequenceHeader = frame;
                                    SrsFlvMuxer srsFlvMuxer2 = SrsFlvMuxer.this;
                                    srsFlvMuxer2.sendFlvTag(srsFlvMuxer2.mAudioSequenceHeader);
                                }
                            } else if (frame.isVideo() && SrsFlvMuxer.this.mVideoSequenceHeader != null) {
                                SrsFlvMuxer.this.sendFlvTag(frame);
                            } else if (frame.isAudio() && SrsFlvMuxer.this.mAudioSequenceHeader != null) {
                                SrsFlvMuxer.this.sendFlvTag(frame);
                            }
                        }
                        synchronized (SrsFlvMuxer.this.txFrameLock) {
                            try {
                                SrsFlvMuxer.this.txFrameLock.wait(500);
                            } catch (InterruptedException e) {
                                SrsFlvMuxer.this.worker.interrupt();
                            }
                        }
                    }
                }
            }
        });
        this.worker = thread;
        thread.start();
    }

    public void stop() {
        this.started = false;
        this.mFlvTagCache.clear();
        Thread thread = this.worker;
        if (thread != null) {
            thread.interrupt();
            try {
                this.worker.join();
            } catch (InterruptedException e) {
                e.printStackTrace();
                this.worker.interrupt();
            }
            this.worker = null;
        }
        this.flv.reset();
        this.needToFindKeyFrame = true;
        Log.i(TAG, "SrsFlvMuxer closed");
        new Thread(new Runnable() {
            /* class net.ossrs.yasea.SrsFlvMuxer.AnonymousClass2 */

            public void run() {
                SrsFlvMuxer.this.disconnect();
            }
        }).start();
    }

    public void writeSampleData(int trackIndex, ByteBuffer byteBuf, MediaCodec.BufferInfo bufferInfo) {
        if (bufferInfo.offset > 0) {
            Log.w(TAG, String.format("encoded frame %dB, offset=%d pts=%dms", Integer.valueOf(bufferInfo.size), Integer.valueOf(bufferInfo.offset), Long.valueOf(bufferInfo.presentationTimeUs / 1000)));
        }
        if (100 == trackIndex) {
            this.flv.writeVideoSample(byteBuf, bufferInfo);
        } else {
            this.flv.writeAudioSample(byteBuf, bufferInfo);
        }
    }

    private class SrsCodecVideoAVCFrame {
        public static final int DisposableInterFrame = 3;
        public static final int GeneratedKeyFrame = 4;
        public static final int InterFrame = 2;
        public static final int KeyFrame = 1;
        public static final int Reserved = 0;
        public static final int Reserved1 = 6;
        public static final int VideoInfoFrame = 5;

        private SrsCodecVideoAVCFrame() {
        }
    }

    private class SrsCodecVideoAVCType {
        public static final int NALU = 1;
        public static final int Reserved = 3;
        public static final int SequenceHeader = 0;
        public static final int SequenceHeaderEOF = 2;

        private SrsCodecVideoAVCType() {
        }
    }

    private class SrsCodecFlvTag {
        public static final int Audio = 8;
        public static final int Reserved = 0;
        public static final int Script = 18;
        public static final int Video = 9;

        private SrsCodecFlvTag() {
        }
    }

    private class SrsCodecVideo {
        public static final int AVC = 7;
        public static final int Disabled = 8;
        public static final int On2VP6 = 4;
        public static final int On2VP6WithAlphaChannel = 5;
        public static final int Reserved = 0;
        public static final int Reserved1 = 1;
        public static final int Reserved2 = 9;
        public static final int ScreenVideo = 3;
        public static final int ScreenVideoVersion2 = 6;
        public static final int SorensonH263 = 2;

        private SrsCodecVideo() {
        }
    }

    private class SrsAacObjectType {
        public static final int AacHE = 5;
        public static final int AacHEV2 = 29;
        public static final int AacLC = 2;
        public static final int AacMain = 1;
        public static final int AacSSR = 3;
        public static final int Reserved = 0;

        private SrsAacObjectType() {
        }
    }

    private class SrsAacProfile {
        public static final int LC = 1;
        public static final int Main = 0;
        public static final int Reserved = 3;
        public static final int SSR = 2;

        private SrsAacProfile() {
        }
    }

    private class SrsCodecAudioSampleRate {
        public static final int R11025 = 11025;
        public static final int R16000 = 16000;
        public static final int R22050 = 22050;
        public static final int R32000 = 32000;
        public static final int R44100 = 44100;
        public static final int R5512 = 5512;

        private SrsCodecAudioSampleRate() {
        }
    }

    private class SrsAvcNaluType {
        public static final int AccessUnitDelimiter = 9;
        public static final int CodedSliceExt = 20;
        public static final int DataPartitionA = 2;
        public static final int DataPartitionB = 3;
        public static final int DataPartitionC = 4;
        public static final int EOSequence = 10;
        public static final int EOStream = 11;
        public static final int FilterData = 12;
        public static final int IDR = 5;
        public static final int LayerWithoutPartition = 19;
        public static final int NonIDR = 1;
        public static final int PPS = 8;
        public static final int PrefixNALU = 14;
        public static final int Reserved = 0;
        public static final int SEI = 6;
        public static final int SPS = 7;
        public static final int SPSExt = 13;
        public static final int SubsetSPS = 15;

        private SrsAvcNaluType() {
        }
    }

    /* access modifiers changed from: private */
    public class SrsAnnexbSearch {
        public boolean match;
        public int nb_start_code;

        private SrsAnnexbSearch() {
            this.nb_start_code = 0;
            this.match = false;
        }
    }

    /* access modifiers changed from: private */
    public class SrsFlvFrameBytes {
        public ByteBuffer data;
        public int size;

        private SrsFlvFrameBytes() {
        }
    }

    /* access modifiers changed from: private */
    public class SrsFlvFrame {
        public int avc_aac_type;
        public int dts;
        public SrsAllocator.Allocation flvTag;
        public int frame_type;
        public int type;

        private SrsFlvFrame() {
        }

        public boolean isKeyFrame() {
            return isVideo() && this.frame_type == 1;
        }

        public boolean isSequenceHeader() {
            return this.avc_aac_type == 0;
        }

        public boolean isVideo() {
            return this.type == 9;
        }

        public boolean isAudio() {
            return this.type == 8;
        }
    }

    /* access modifiers changed from: private */
    public class SrsRawH264Stream {
        private static final String TAG = "SrsFlvMuxer";
        private SrsAnnexbSearch annexb;
        private SrsFlvFrameBytes pps_bb;
        private SrsFlvFrameBytes pps_hdr;
        private SrsFlvFrameBytes seq_hdr;
        private SrsFlvFrameBytes sps_bb;
        private SrsFlvFrameBytes sps_hdr;

        private SrsRawH264Stream() {
            this.annexb = new SrsAnnexbSearch();
            this.seq_hdr = new SrsFlvFrameBytes();
            this.sps_hdr = new SrsFlvFrameBytes();
            this.sps_bb = new SrsFlvFrameBytes();
            this.pps_hdr = new SrsFlvFrameBytes();
            this.pps_bb = new SrsFlvFrameBytes();
        }

        public boolean isSps(SrsFlvFrameBytes frame) {
            return frame.size >= 1 && (frame.data.get(0) & 31) == 7;
        }

        public boolean isPps(SrsFlvFrameBytes frame) {
            return frame.size >= 1 && (frame.data.get(0) & 31) == 8;
        }

        public SrsFlvFrameBytes muxNaluHeader(SrsFlvFrameBytes frame) {
            SrsFlvFrameBytes nalu_hdr = new SrsFlvFrameBytes();
            nalu_hdr.data = ByteBuffer.allocate(4);
            nalu_hdr.size = 4;
            nalu_hdr.data.putInt(frame.size);
            nalu_hdr.data.rewind();
            return nalu_hdr;
        }

        public void muxSequenceHeader(ByteBuffer sps, ByteBuffer pps, int dts, int pts, ArrayList<SrsFlvFrameBytes> frames) {
            if (this.seq_hdr.data == null) {
                this.seq_hdr.data = ByteBuffer.allocate(5);
                this.seq_hdr.size = 5;
            }
            this.seq_hdr.data.rewind();
            byte profile_idc = sps.get(1);
            byte level_idc = sps.get(3);
            this.seq_hdr.data.put((byte) 1);
            this.seq_hdr.data.put(profile_idc);
            this.seq_hdr.data.put((byte) 0);
            this.seq_hdr.data.put(level_idc);
            this.seq_hdr.data.put((byte) 3);
            this.seq_hdr.data.rewind();
            frames.add(this.seq_hdr);
            if (this.sps_hdr.data == null) {
                this.sps_hdr.data = ByteBuffer.allocate(3);
                this.sps_hdr.size = 3;
            }
            this.sps_hdr.data.rewind();
            this.sps_hdr.data.put((byte) 1);
            this.sps_hdr.data.putShort((short) sps.array().length);
            this.sps_hdr.data.rewind();
            frames.add(this.sps_hdr);
            this.sps_bb.size = sps.array().length;
            this.sps_bb.data = sps.duplicate();
            frames.add(this.sps_bb);
            if (this.pps_hdr.data == null) {
                this.pps_hdr.data = ByteBuffer.allocate(3);
                this.pps_hdr.size = 3;
            }
            this.pps_hdr.data.rewind();
            this.pps_hdr.data.put((byte) 1);
            this.pps_hdr.data.putShort((short) pps.array().length);
            this.pps_hdr.data.rewind();
            frames.add(this.pps_hdr);
            this.pps_bb.size = pps.array().length;
            this.pps_bb.data = pps.duplicate();
            frames.add(this.pps_bb);
        }

        public SrsAllocator.Allocation muxFlvTag(ArrayList<SrsFlvFrameBytes> frames, int frame_type, int avc_packet_type, int dts, int pts) {
            int size = 5;
            for (int i = 0; i < frames.size(); i++) {
                size += frames.get(i).size;
            }
            SrsAllocator.Allocation allocation = SrsFlvMuxer.this.mVideoAllocator.allocate(size);
            allocation.put((byte) ((frame_type << 4) | 7));
            allocation.put((byte) avc_packet_type);
            int cts = pts - dts;
            allocation.put((byte) (cts >> 16));
            allocation.put((byte) (cts >> 8));
            allocation.put((byte) cts);
            for (int i2 = 0; i2 < frames.size(); i2++) {
                SrsFlvFrameBytes frame = frames.get(i2);
                frame.data.get(allocation.array(), allocation.size(), frame.size);
                allocation.appendOffset(frame.size);
            }
            return allocation;
        }

        private SrsAnnexbSearch searchStartcode(ByteBuffer bb, MediaCodec.BufferInfo bi) {
            this.annexb.match = false;
            this.annexb.nb_start_code = 0;
            if (bi.size - 4 > 0) {
                if (bb.get(0) == 0 && bb.get(1) == 0 && bb.get(2) == 0 && bb.get(3) == 1) {
                    this.annexb.match = true;
                    this.annexb.nb_start_code = 4;
                } else if (bb.get(0) == 0 && bb.get(1) == 0 && bb.get(2) == 1) {
                    this.annexb.match = true;
                    this.annexb.nb_start_code = 3;
                }
            }
            return this.annexb;
        }

        private SrsAnnexbSearch searchAnnexb(ByteBuffer bb, MediaCodec.BufferInfo bi) {
            this.annexb.match = false;
            this.annexb.nb_start_code = 0;
            int i = bb.position();
            while (true) {
                if (i >= bi.size - 4) {
                    break;
                }
                if (bb.get(i) == 0 && bb.get(i + 1) == 0) {
                    if (bb.get(i + 2) != 1) {
                        if (bb.get(i + 2) == 0 && bb.get(i + 3) == 1) {
                            this.annexb.match = true;
                            this.annexb.nb_start_code = (i + 4) - bb.position();
                            break;
                        }
                    } else {
                        this.annexb.match = true;
                        this.annexb.nb_start_code = (i + 3) - bb.position();
                        break;
                    }
                }
                i++;
            }
            return this.annexb;
        }

        public SrsFlvFrameBytes demuxAnnexb(ByteBuffer bb, MediaCodec.BufferInfo bi, boolean isOnlyChkHeader) {
            SrsFlvFrameBytes tbb = new SrsFlvFrameBytes();
            if (bb.position() < bi.size - 4) {
                SrsAnnexbSearch tbbsc = isOnlyChkHeader ? searchStartcode(bb, bi) : searchAnnexb(bb, bi);
                if (!tbbsc.match || tbbsc.nb_start_code < 3) {
                    Log.e(TAG, "annexb not match.");
                } else {
                    for (int i = 0; i < tbbsc.nb_start_code; i++) {
                        bb.get();
                    }
                    tbb.data = bb.slice();
                    tbb.size = bi.size - bb.position();
                }
            }
            return tbb;
        }
    }

    private class SrsRawAacStreamCodec {
        public int aac_object;
        public byte aac_packet_type;
        public byte channel_configuration;
        public byte[] frame;
        public short frame_length;
        public byte protection_absent;
        public byte sampling_frequency_index;
        public byte sound_format;
        public byte sound_rate;
        public byte sound_size;
        public byte sound_type;

        private SrsRawAacStreamCodec() {
        }
    }

    /* access modifiers changed from: private */
    public class SrsFlv {
        private boolean aac_specific_config_got;
        private int achannel;
        private int asample_rate;
        private MediaFormat audioTrack;
        private SrsAllocator.Allocation audio_tag;
        private SrsRawH264Stream avc = new SrsRawH264Stream();
        private ByteBuffer h264_pps;
        private boolean h264_pps_changed;
        private ByteBuffer h264_sps;
        private boolean h264_sps_changed;
        private boolean h264_sps_pps_sent;
        private ArrayList<SrsFlvFrameBytes> ipbs = new ArrayList<>();
        private MediaFormat videoTrack;
        private SrsAllocator.Allocation video_tag;

        public SrsFlv() {
            reset();
        }

        public void reset() {
            this.h264_sps_changed = false;
            this.h264_pps_changed = false;
            this.h264_sps_pps_sent = false;
            this.aac_specific_config_got = false;
            ByteBuffer byteBuffer = this.h264_sps;
            if (byteBuffer != null) {
                Arrays.fill(byteBuffer.array(), (byte) 0);
                this.h264_sps.clear();
            }
            ByteBuffer byteBuffer2 = this.h264_pps;
            if (byteBuffer2 != null) {
                Arrays.fill(byteBuffer2.array(), (byte) 0);
                this.h264_pps.clear();
            }
        }

        public void setVideoTrack(MediaFormat format) {
            this.videoTrack = format;
        }

        public void setAudioTrack(MediaFormat format) {
            this.audioTrack = format;
            this.achannel = format.getInteger("channel-count");
            this.asample_rate = format.getInteger("sample-rate");
        }

        public void writeAudioSample(ByteBuffer bb, MediaCodec.BufferInfo bi) {
            byte aac_packet_type;
            byte sound_type;
            byte sound_rate;
            int pts = (int) (bi.presentationTimeUs / 1000);
            SrsAllocator.Allocation allocate = SrsFlvMuxer.this.mAudioAllocator.allocate(bi.size + 2);
            this.audio_tag = allocate;
            if (!this.aac_specific_config_got) {
                byte ch = (byte) (bb.get(0) & 248);
                byte samplingFrequencyIndex = 4;
                int i = this.asample_rate;
                if (i == 22050) {
                    samplingFrequencyIndex = 7;
                } else if (i == 11025) {
                    samplingFrequencyIndex = 10;
                } else if (i == 32000) {
                    samplingFrequencyIndex = 5;
                } else if (i == 16000) {
                    samplingFrequencyIndex = 8;
                }
                this.audio_tag.put((byte) (((samplingFrequencyIndex >> 1) & 7) | ch), 2);
                byte ch2 = (byte) ((samplingFrequencyIndex << 7) & 128);
                byte channelConfiguration = 1;
                if (this.achannel == 2) {
                    channelConfiguration = 2;
                }
                this.audio_tag.put((byte) (((channelConfiguration << 3) & 120) | ch2), 3);
                this.aac_specific_config_got = true;
                writeAdtsHeader(this.audio_tag.array(), 4);
                this.audio_tag.appendOffset(7);
                aac_packet_type = 0;
            } else {
                bb.get(allocate.array(), 2, bi.size);
                this.audio_tag.appendOffset(bi.size + 2);
                aac_packet_type = 1;
            }
            if (this.achannel == 2) {
                sound_type = 1;
            } else {
                sound_type = 0;
            }
            int i2 = this.asample_rate;
            if (i2 == 22050) {
                sound_rate = 2;
            } else if (i2 == 11025) {
                sound_rate = 1;
            } else if (i2 == 5512) {
                sound_rate = 0;
            } else {
                sound_rate = 3;
            }
            this.audio_tag.put((byte) (((10 << 4) & 240) | ((byte) (((sound_rate << 2) & 12) | ((byte) (((1 << 1) & 2) | ((byte) (sound_type & 1))))))), 0);
            this.audio_tag.put(aac_packet_type, 1);
            writeRtmpPacket(8, pts, 0, aac_packet_type, this.audio_tag);
        }

        private void writeAdtsHeader(byte[] frame, int offset) {
            frame[offset] = -1;
            frame[offset + 1] = -16;
            int i = offset + 1;
            frame[i] = (byte) (frame[i] | 0);
            int i2 = offset + 1;
            frame[i2] = (byte) (frame[i2] | 0);
            int i3 = offset + 1;
            frame[i3] = (byte) (frame[i3] | 1);
            frame[offset + 2] = 64;
            int i4 = offset + 2;
            frame[i4] = (byte) (frame[i4] | cv.n);
            int i5 = offset + 2;
            frame[i5] = (byte) (frame[i5] | 0);
            frame[offset + 3] = Byte.MIN_VALUE;
            int i6 = offset + 3;
            frame[i6] = (byte) (frame[i6] | 0);
            int i7 = offset + 3;
            frame[i7] = (byte) (frame[i7] | 0);
            int i8 = offset + 3;
            frame[i8] = (byte) (frame[i8] | 0);
            int i9 = offset + 3;
            frame[i9] = (byte) (frame[i9] | 0);
            int i10 = offset + 3;
            frame[i10] = (byte) (frame[i10] | (((frame.length - 2) & 6144) >> 11));
            frame[offset + 4] = (byte) (((frame.length - 2) & 2040) >> 3);
            frame[offset + 5] = (byte) (((frame.length - 2) & 7) << 5);
            int i11 = offset + 5;
            frame[i11] = (byte) (frame[i11] | 31);
            frame[offset + 6] = -4;
            int i12 = offset + 6;
            frame[i12] = (byte) (frame[i12] | 0);
        }

        public void writeVideoSample(ByteBuffer bb, MediaCodec.BufferInfo bi) {
            if (bi.size >= 4) {
                int pts = (int) (bi.presentationTimeUs / 1000);
                int type = 2;
                SrsFlvFrameBytes frame = this.avc.demuxAnnexb(bb, bi, true);
                int nal_unit_type = frame.data.get(0) & 31;
                if (nal_unit_type == 5) {
                    type = 1;
                } else if (nal_unit_type == 7 || nal_unit_type == 8) {
                    SrsFlvFrameBytes frame_pps = this.avc.demuxAnnexb(bb, bi, false);
                    frame.size = (frame.size - frame_pps.size) - 4;
                    if (!frame.data.equals(this.h264_sps)) {
                        byte[] sps = new byte[frame.size];
                        frame.data.get(sps);
                        this.h264_sps_changed = true;
                        this.h264_sps = ByteBuffer.wrap(sps);
                    }
                    SrsFlvFrameBytes frame_sei = this.avc.demuxAnnexb(bb, bi, false);
                    if (frame_sei.size > 0 && 6 == (frame_sei.data.get(0) & 31)) {
                        frame_pps.size = (frame_pps.size - frame_sei.size) - 3;
                    }
                    if (!frame_pps.data.equals(this.h264_pps)) {
                        byte[] pps = new byte[frame_pps.size];
                        frame_pps.data.get(pps);
                        this.h264_pps_changed = true;
                        this.h264_pps = ByteBuffer.wrap(pps);
                        writeH264SpsPps(pts, pts);
                        return;
                    }
                    return;
                } else if (nal_unit_type != 1) {
                    return;
                }
                this.ipbs.add(this.avc.muxNaluHeader(frame));
                this.ipbs.add(frame);
                writeH264IpbFrame(this.ipbs, type, pts, pts);
                this.ipbs.clear();
            }
        }

        private void writeH264SpsPps(int dts, int pts) {
            if ((!this.h264_sps_pps_sent || this.h264_sps_changed || this.h264_pps_changed) && this.h264_pps != null && this.h264_sps != null) {
                ArrayList<SrsFlvFrameBytes> frames = new ArrayList<>();
                this.avc.muxSequenceHeader(this.h264_sps, this.h264_pps, dts, pts, frames);
                SrsAllocator.Allocation muxFlvTag = this.avc.muxFlvTag(frames, 1, 0, dts, pts);
                this.video_tag = muxFlvTag;
                writeRtmpPacket(9, dts, 1, 0, muxFlvTag);
                this.h264_sps_changed = false;
                this.h264_pps_changed = false;
                this.h264_sps_pps_sent = true;
                Log.i(SrsFlvMuxer.TAG, String.format("flv: h264 sps/pps sent, sps=%dB, pps=%dB", Integer.valueOf(this.h264_sps.array().length), Integer.valueOf(this.h264_pps.array().length)));
            }
        }

        private void writeH264IpbFrame(ArrayList<SrsFlvFrameBytes> frames, int type, int dts, int pts) {
            if (this.h264_sps_pps_sent) {
                SrsAllocator.Allocation muxFlvTag = this.avc.muxFlvTag(frames, type, 1, dts, pts);
                this.video_tag = muxFlvTag;
                writeRtmpPacket(9, dts, type, 1, muxFlvTag);
            }
        }

        private void writeRtmpPacket(int type, int dts, int frame_type, int avc_aac_type, SrsAllocator.Allocation tag) {
            SrsFlvFrame frame = new SrsFlvFrame();
            frame.flvTag = tag;
            frame.type = type;
            frame.dts = dts;
            frame.frame_type = frame_type;
            frame.avc_aac_type = avc_aac_type;
            if (frame.isVideo()) {
                if (!SrsFlvMuxer.this.needToFindKeyFrame) {
                    flvTagCacheAdd(frame);
                } else if (frame.isKeyFrame()) {
                    SrsFlvMuxer.this.needToFindKeyFrame = false;
                    flvTagCacheAdd(frame);
                }
            } else if (frame.isAudio()) {
                flvTagCacheAdd(frame);
            }
        }

        private void flvTagCacheAdd(SrsFlvFrame frame) {
            if (SrsFlvMuxer.this.started) {
                SrsFlvMuxer.this.mFlvTagCache.add(frame);
                if (frame.isVideo()) {
                    SrsFlvMuxer.this.getVideoFrameCacheNumber().incrementAndGet();
                }
            }
            synchronized (SrsFlvMuxer.this.txFrameLock) {
                SrsFlvMuxer.this.txFrameLock.notifyAll();
            }
        }
    }
}
