package com.facebook.fresco.animation.frame;

import com.facebook.fresco.animation.backend.AnimationInformation;

public class DropFramesFrameScheduler implements FrameScheduler {
    private static final int UNSET = -1;
    private final AnimationInformation mAnimationInformation;
    private long mLoopDurationMs = -1;

    public DropFramesFrameScheduler(AnimationInformation animationInformation) {
        this.mAnimationInformation = animationInformation;
    }

    /* JADX INFO: Multiple debug info for r2v2 long: [D('loopCount' long), D('timeInCurrentLoopMs' long)] */
    @Override // com.facebook.fresco.animation.frame.FrameScheduler
    public int getFrameNumberToRender(long animationTimeMs, long lastFrameTimeMs) {
        long loopDurationMs = getLoopDurationMs();
        if (loopDurationMs == 0) {
            return getFrameNumberWithinLoop(0);
        }
        if (isInfiniteAnimation() || animationTimeMs / loopDurationMs < ((long) this.mAnimationInformation.getLoopCount())) {
            return getFrameNumberWithinLoop(animationTimeMs % loopDurationMs);
        }
        return -1;
    }

    @Override // com.facebook.fresco.animation.frame.FrameScheduler
    public long getLoopDurationMs() {
        long j = this.mLoopDurationMs;
        if (j != -1) {
            return j;
        }
        this.mLoopDurationMs = 0;
        int frameCount = this.mAnimationInformation.getFrameCount();
        for (int i = 0; i < frameCount; i++) {
            this.mLoopDurationMs += (long) this.mAnimationInformation.getFrameDurationMs(i);
        }
        return this.mLoopDurationMs;
    }

    @Override // com.facebook.fresco.animation.frame.FrameScheduler
    public long getTargetRenderTimeMs(int frameNumber) {
        long targetRenderTimeMs = 0;
        for (int i = 0; i < frameNumber; i++) {
            targetRenderTimeMs += (long) this.mAnimationInformation.getFrameDurationMs(frameNumber);
        }
        return targetRenderTimeMs;
    }

    /* JADX INFO: Multiple debug info for r7v2 long: [D('i' int), D('timeUntilNextFrameInLoopMs' long)] */
    @Override // com.facebook.fresco.animation.frame.FrameScheduler
    public long getTargetRenderTimeForNextFrameMs(long animationTimeMs) {
        long loopDurationMs = getLoopDurationMs();
        if (loopDurationMs == 0) {
            return -1;
        }
        if (!isInfiniteAnimation() && animationTimeMs / getLoopDurationMs() >= ((long) this.mAnimationInformation.getLoopCount())) {
            return -1;
        }
        long timePassedInCurrentLoopMs = animationTimeMs % loopDurationMs;
        long timeOfNextFrameInLoopMs = 0;
        int frameCount = this.mAnimationInformation.getFrameCount();
        for (int i = 0; i < frameCount && timeOfNextFrameInLoopMs <= timePassedInCurrentLoopMs; i++) {
            timeOfNextFrameInLoopMs += (long) this.mAnimationInformation.getFrameDurationMs(i);
        }
        return animationTimeMs + (timeOfNextFrameInLoopMs - timePassedInCurrentLoopMs);
    }

    @Override // com.facebook.fresco.animation.frame.FrameScheduler
    public boolean isInfiniteAnimation() {
        return this.mAnimationInformation.getLoopCount() == 0;
    }

    /* access modifiers changed from: package-private */
    public int getFrameNumberWithinLoop(long timeInCurrentLoopMs) {
        int frame = 0;
        long currentDuration = 0;
        do {
            currentDuration += (long) this.mAnimationInformation.getFrameDurationMs(frame);
            frame++;
        } while (timeInCurrentLoopMs >= currentDuration);
        return frame - 1;
    }
}
