package com.facebook.imagepipeline.producers;

import com.alipay.sdk.m.f0.c;
import com.facebook.common.logging.FLog;
import com.facebook.common.time.MonotonicClock;
import com.facebook.common.time.RealtimeSinceBootClock;
import com.facebook.imagepipeline.common.Priority;
import com.facebook.imagepipeline.image.EncodedImage;
import com.facebook.imagepipeline.producers.FetchState;
import com.facebook.imagepipeline.producers.NetworkFetcher;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import javax.annotation.Nullable;

public class PriorityNetworkFetcher<FETCH_STATE extends FetchState> implements NetworkFetcher<PriorityFetchState<FETCH_STATE>> {
    static final int INFINITE_REQUEUE = -1;
    static final int NO_DELAYED_REQUESTS = -1;
    public static final String TAG = PriorityNetworkFetcher.class.getSimpleName();
    private final boolean doNotCancelRequests;
    private long firstDelayedRequestEnqueuedTimeStamp;
    private final int immediateRequeueCount;
    private final boolean inflightFetchesCanBeCancelled;
    private volatile boolean isRunning;
    private final MonotonicClock mClock;
    private final HashSet<PriorityFetchState<FETCH_STATE>> mCurrentlyFetching;
    private final LinkedList<PriorityFetchState<FETCH_STATE>> mDelayedQueue;
    private final NetworkFetcher<FETCH_STATE> mDelegate;
    private final LinkedList<PriorityFetchState<FETCH_STATE>> mHiPriQueue;
    private final boolean mIsHiPriFifo;
    private final Object mLock;
    private final LinkedList<PriorityFetchState<FETCH_STATE>> mLowPriQueue;
    private final int mMaxOutstandingHiPri;
    private final int mMaxOutstandingLowPri;
    private final int maxNumberOfRequeue;
    private final boolean multipleDequeue;
    private final long requeueDelayTimeInMillis;

    @Override // com.facebook.imagepipeline.producers.NetworkFetcher
    public /* bridge */ /* synthetic */ void fetch(FetchState fetchState, NetworkFetcher.Callback callback) {
        fetch((PriorityFetchState) ((PriorityFetchState) fetchState), callback);
    }

    @Override // com.facebook.imagepipeline.producers.NetworkFetcher
    @Nullable
    public /* bridge */ /* synthetic */ Map getExtraMap(FetchState fetchState, int i) {
        return getExtraMap((PriorityFetchState) ((PriorityFetchState) fetchState), i);
    }

    @Override // com.facebook.imagepipeline.producers.NetworkFetcher
    public /* bridge */ /* synthetic */ void onFetchCompletion(FetchState fetchState, int i) {
        onFetchCompletion((PriorityFetchState) ((PriorityFetchState) fetchState), i);
    }

    @Override // com.facebook.imagepipeline.producers.NetworkFetcher
    public /* bridge */ /* synthetic */ boolean shouldPropagate(FetchState fetchState) {
        return shouldPropagate((PriorityFetchState) ((PriorityFetchState) fetchState));
    }

    public PriorityNetworkFetcher(NetworkFetcher<FETCH_STATE> delegate, boolean isHiPriFifo, int maxOutstandingHiPri, int maxOutstandingLowPri, boolean inflightFetchesCanBeCancelled2, int maxNumberOfRequeue2, boolean doNotCancelRequests2, int immediateRequeueCount2, int requeueDelayTimeInMillis2, boolean multipleDequeue2) {
        this(delegate, isHiPriFifo, maxOutstandingHiPri, maxOutstandingLowPri, inflightFetchesCanBeCancelled2, maxNumberOfRequeue2, doNotCancelRequests2, immediateRequeueCount2, requeueDelayTimeInMillis2, multipleDequeue2, RealtimeSinceBootClock.get());
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public PriorityNetworkFetcher(NetworkFetcher<FETCH_STATE> delegate, boolean isHiPriFifo, int maxOutstandingHiPri, int maxOutstandingLowPri, boolean inflightFetchesCanBeCancelled2, boolean infiniteRequeue, boolean doNotCancelRequests2) {
        this(delegate, isHiPriFifo, maxOutstandingHiPri, maxOutstandingLowPri, inflightFetchesCanBeCancelled2, infiniteRequeue ? -1 : 0, doNotCancelRequests2, -1, 0, false, RealtimeSinceBootClock.get());
    }

    public PriorityNetworkFetcher(NetworkFetcher<FETCH_STATE> delegate, boolean isHiPriFifo, int maxOutstandingHiPri, int maxOutstandingLowPri, boolean inflightFetchesCanBeCancelled2, int maxNumberOfRequeue2, boolean doNotCancelRequests2, int immediateRequeueCount2, int requeueDelayTimeInMillis2, boolean multipleDequeue2, MonotonicClock clock) {
        this.mLock = new Object();
        this.mHiPriQueue = new LinkedList<>();
        this.mLowPriQueue = new LinkedList<>();
        this.mCurrentlyFetching = new HashSet<>();
        this.mDelayedQueue = new LinkedList<>();
        this.isRunning = true;
        this.mDelegate = delegate;
        this.mIsHiPriFifo = isHiPriFifo;
        this.mMaxOutstandingHiPri = maxOutstandingHiPri;
        this.mMaxOutstandingLowPri = maxOutstandingLowPri;
        if (maxOutstandingHiPri > maxOutstandingLowPri) {
            this.inflightFetchesCanBeCancelled = inflightFetchesCanBeCancelled2;
            this.maxNumberOfRequeue = maxNumberOfRequeue2;
            this.doNotCancelRequests = doNotCancelRequests2;
            this.immediateRequeueCount = immediateRequeueCount2;
            this.requeueDelayTimeInMillis = (long) requeueDelayTimeInMillis2;
            this.multipleDequeue = multipleDequeue2;
            this.mClock = clock;
            return;
        }
        throw new IllegalArgumentException("maxOutstandingHiPri should be > maxOutstandingLowPri");
    }

    public void pause() {
        this.isRunning = false;
    }

    public void resume() {
        this.isRunning = true;
        dequeueIfAvailableSlots();
    }

    public void fetch(final PriorityFetchState<FETCH_STATE> fetchState, final NetworkFetcher.Callback callback) {
        fetchState.getContext().addCallbacks(new BaseProducerContextCallbacks() {
            /* class com.facebook.imagepipeline.producers.PriorityNetworkFetcher.AnonymousClass1 */

            @Override // com.facebook.imagepipeline.producers.BaseProducerContextCallbacks, com.facebook.imagepipeline.producers.ProducerContextCallbacks
            public void onCancellationRequested() {
                if (!PriorityNetworkFetcher.this.doNotCancelRequests) {
                    if (PriorityNetworkFetcher.this.inflightFetchesCanBeCancelled || !PriorityNetworkFetcher.this.mCurrentlyFetching.contains(fetchState)) {
                        PriorityNetworkFetcher.this.removeFromQueue(fetchState, "CANCEL");
                        callback.onCancellation();
                    }
                }
            }

            @Override // com.facebook.imagepipeline.producers.BaseProducerContextCallbacks, com.facebook.imagepipeline.producers.ProducerContextCallbacks
            public void onPriorityChanged() {
                PriorityNetworkFetcher priorityNetworkFetcher = PriorityNetworkFetcher.this;
                PriorityFetchState priorityFetchState = fetchState;
                priorityNetworkFetcher.changePriority(priorityFetchState, priorityFetchState.getContext().getPriority() == Priority.HIGH);
            }
        });
        synchronized (this.mLock) {
            if (this.mCurrentlyFetching.contains(fetchState)) {
                String str = TAG;
                FLog.e(str, "fetch state was enqueued twice: " + fetchState);
                return;
            }
            boolean isHiPri = fetchState.getContext().getPriority() == Priority.HIGH;
            FLog.v(TAG, "enqueue: %s %s", isHiPri ? "HI-PRI" : "LOW-PRI", fetchState.getUri());
            fetchState.callback = callback;
            putInQueue(fetchState, isHiPri);
            dequeueIfAvailableSlots();
        }
    }

    public void onFetchCompletion(PriorityFetchState<FETCH_STATE> fetchState, int byteSize) {
        removeFromQueue(fetchState, c.p);
        this.mDelegate.onFetchCompletion(fetchState.delegatedState, byteSize);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void removeFromQueue(PriorityFetchState<FETCH_STATE> fetchState, String reasonForLogging) {
        synchronized (this.mLock) {
            FLog.v(TAG, "remove: %s %s", reasonForLogging, fetchState.getUri());
            this.mCurrentlyFetching.remove(fetchState);
            if (!this.mHiPriQueue.remove(fetchState)) {
                this.mLowPriQueue.remove(fetchState);
            }
        }
        dequeueIfAvailableSlots();
    }

    private void moveDelayedRequestsToPriorityQueues() {
        if (!this.mDelayedQueue.isEmpty() && this.mClock.now() - this.firstDelayedRequestEnqueuedTimeStamp > this.requeueDelayTimeInMillis) {
            Iterator<PriorityFetchState<FETCH_STATE>> it = this.mDelayedQueue.iterator();
            while (it.hasNext()) {
                PriorityFetchState<FETCH_STATE> fetchState = it.next();
                putInQueue(fetchState, fetchState.getContext().getPriority() == Priority.HIGH);
            }
            this.mDelayedQueue.clear();
        }
    }

    private void putInDelayedQueue(PriorityFetchState<FETCH_STATE> fetchState) {
        if (this.mDelayedQueue.isEmpty()) {
            this.firstDelayedRequestEnqueuedTimeStamp = this.mClock.now();
        }
        fetchState.delayCount++;
        this.mDelayedQueue.addLast(fetchState);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void requeue(PriorityFetchState<FETCH_STATE> fetchState) {
        synchronized (this.mLock) {
            FLog.v(TAG, "requeue: %s", fetchState.getUri());
            boolean z = true;
            fetchState.requeueCount++;
            fetchState.delegatedState = this.mDelegate.createFetchState(fetchState.getConsumer(), fetchState.getContext());
            this.mCurrentlyFetching.remove(fetchState);
            if (!this.mHiPriQueue.remove(fetchState)) {
                this.mLowPriQueue.remove(fetchState);
            }
            if (this.immediateRequeueCount == -1 || fetchState.requeueCount <= this.immediateRequeueCount) {
                if (fetchState.getContext().getPriority() != Priority.HIGH) {
                    z = false;
                }
                putInQueue(fetchState, z);
            } else {
                putInDelayedQueue(fetchState);
            }
        }
        dequeueIfAvailableSlots();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0063, code lost:
        delegateFetch(r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0068, code lost:
        if (r10.multipleDequeue == false) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x006a, code lost:
        dequeueIfAvailableSlots();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:?, code lost:
        return;
     */
    private void dequeueIfAvailableSlots() {
        if (this.isRunning) {
            PriorityFetchState<FETCH_STATE> toFetch = null;
            synchronized (this.mLock) {
                moveDelayedRequestsToPriorityQueues();
                int outstandingRequests = this.mCurrentlyFetching.size();
                if (outstandingRequests < this.mMaxOutstandingHiPri) {
                    toFetch = this.mHiPriQueue.pollFirst();
                }
                if (toFetch == null && outstandingRequests < this.mMaxOutstandingLowPri) {
                    toFetch = this.mLowPriQueue.pollFirst();
                }
                if (toFetch != null) {
                    toFetch.dequeuedTimestamp = this.mClock.now();
                    this.mCurrentlyFetching.add(toFetch);
                    FLog.v(TAG, "fetching: %s (concurrent: %s hi-pri queue: %s low-pri queue: %s)", toFetch.getUri(), Integer.valueOf(outstandingRequests), Integer.valueOf(this.mHiPriQueue.size()), Integer.valueOf(this.mLowPriQueue.size()));
                }
            }
        }
    }

    private void delegateFetch(final PriorityFetchState<FETCH_STATE> fetchState) {
        try {
            this.mDelegate.fetch(fetchState.delegatedState, new NetworkFetcher.Callback() {
                /* class com.facebook.imagepipeline.producers.PriorityNetworkFetcher.AnonymousClass2 */

                @Override // com.facebook.imagepipeline.producers.NetworkFetcher.Callback
                public void onResponse(InputStream response, int responseLength) throws IOException {
                    NetworkFetcher.Callback callback = fetchState.callback;
                    if (callback != null) {
                        callback.onResponse(response, responseLength);
                    }
                }

                @Override // com.facebook.imagepipeline.producers.NetworkFetcher.Callback
                public void onFailure(Throwable throwable) {
                    if (!(PriorityNetworkFetcher.this.maxNumberOfRequeue == -1 || fetchState.requeueCount < PriorityNetworkFetcher.this.maxNumberOfRequeue) || (throwable instanceof NonrecoverableException)) {
                        PriorityNetworkFetcher.this.removeFromQueue(fetchState, "FAIL");
                        NetworkFetcher.Callback callback = fetchState.callback;
                        if (callback != null) {
                            callback.onFailure(throwable);
                            return;
                        }
                        return;
                    }
                    PriorityNetworkFetcher.this.requeue(fetchState);
                }

                @Override // com.facebook.imagepipeline.producers.NetworkFetcher.Callback
                public void onCancellation() {
                    PriorityNetworkFetcher.this.removeFromQueue(fetchState, "CANCEL");
                    NetworkFetcher.Callback callback = fetchState.callback;
                    if (callback != null) {
                        callback.onCancellation();
                    }
                }
            });
        } catch (Exception e) {
            removeFromQueue(fetchState, "FAIL");
        }
    }

    private void changePriorityInDelayedQueue(PriorityFetchState<FETCH_STATE> fetchState) {
        if (this.mDelayedQueue.remove(fetchState)) {
            fetchState.priorityChangedCount++;
            this.mDelayedQueue.addLast(fetchState);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void changePriority(PriorityFetchState<FETCH_STATE> fetchState, boolean isNewHiPri) {
        LinkedList<PriorityFetchState<FETCH_STATE>> linkedList;
        synchronized (this.mLock) {
            if (isNewHiPri) {
                linkedList = this.mLowPriQueue;
            } else {
                linkedList = this.mHiPriQueue;
            }
            if (!linkedList.remove(fetchState)) {
                changePriorityInDelayedQueue(fetchState);
                return;
            }
            FLog.v(TAG, "change-pri: %s %s", isNewHiPri ? "HIPRI" : "LOWPRI", fetchState.getUri());
            fetchState.priorityChangedCount++;
            putInQueue(fetchState, isNewHiPri);
            dequeueIfAvailableSlots();
        }
    }

    private void putInQueue(PriorityFetchState<FETCH_STATE> entry, boolean isHiPri) {
        if (!isHiPri) {
            this.mLowPriQueue.addLast(entry);
        } else if (this.mIsHiPriFifo) {
            this.mHiPriQueue.addLast(entry);
        } else {
            this.mHiPriQueue.addFirst(entry);
        }
    }

    /* access modifiers changed from: package-private */
    public List<PriorityFetchState<FETCH_STATE>> getHiPriQueue() {
        return this.mHiPriQueue;
    }

    /* access modifiers changed from: package-private */
    public List<PriorityFetchState<FETCH_STATE>> getLowPriQueue() {
        return this.mLowPriQueue;
    }

    /* access modifiers changed from: package-private */
    public List<PriorityFetchState<FETCH_STATE>> getDelayedQeueue() {
        return this.mDelayedQueue;
    }

    /* access modifiers changed from: package-private */
    public HashSet<PriorityFetchState<FETCH_STATE>> getCurrentlyFetching() {
        return this.mCurrentlyFetching;
    }

    public static class PriorityFetchState<FETCH_STATE extends FetchState> extends FetchState {
        @Nullable
        NetworkFetcher.Callback callback;
        final int currentlyFetchingCountWhenCreated;
        int delayCount;
        public FETCH_STATE delegatedState;
        long dequeuedTimestamp;
        final long enqueuedTimestamp;
        final int hiPriCountWhenCreated;
        final boolean isInitialPriorityHigh;
        final int lowPriCountWhenCreated;
        int priorityChangedCount;
        int requeueCount;

        private PriorityFetchState(Consumer<EncodedImage> consumer, ProducerContext producerContext, FETCH_STATE delegatedState2, long enqueuedTimestamp2, int hiPriCountWhenCreated2, int lowPriCountWhenCreated2, int currentlyFetchingCountWhenCreated2) {
            super(consumer, producerContext);
            boolean z = false;
            this.requeueCount = 0;
            this.delayCount = 0;
            this.priorityChangedCount = 0;
            this.delegatedState = delegatedState2;
            this.enqueuedTimestamp = enqueuedTimestamp2;
            this.hiPriCountWhenCreated = hiPriCountWhenCreated2;
            this.lowPriCountWhenCreated = lowPriCountWhenCreated2;
            this.isInitialPriorityHigh = producerContext.getPriority() == Priority.HIGH ? true : z;
            this.currentlyFetchingCountWhenCreated = currentlyFetchingCountWhenCreated2;
        }
    }

    public static class NonrecoverableException extends Throwable {
        public NonrecoverableException(String message) {
            super(message);
        }
    }

    @Override // com.facebook.imagepipeline.producers.NetworkFetcher
    public PriorityFetchState<FETCH_STATE> createFetchState(Consumer<EncodedImage> consumer, ProducerContext producerContext) {
        return new PriorityFetchState<>(consumer, producerContext, this.mDelegate.createFetchState(consumer, producerContext), this.mClock.now(), this.mHiPriQueue.size(), this.mLowPriQueue.size(), this.mCurrentlyFetching.size());
    }

    public boolean shouldPropagate(PriorityFetchState<FETCH_STATE> fetchState) {
        return this.mDelegate.shouldPropagate(fetchState.delegatedState);
    }

    @Nullable
    public Map<String, String> getExtraMap(PriorityFetchState<FETCH_STATE> fetchState, int byteSize) {
        HashMap<String, String> extras;
        if (this.mDelegate.getExtraMap(fetchState.delegatedState, byteSize) == null) {
            extras = new HashMap<>();
        }
        extras.put("pri_queue_time", "" + (fetchState.dequeuedTimestamp - fetchState.enqueuedTimestamp));
        extras.put("hipri_queue_size", "" + fetchState.hiPriCountWhenCreated);
        extras.put("lowpri_queue_size", "" + fetchState.lowPriCountWhenCreated);
        extras.put("requeueCount", "" + fetchState.requeueCount);
        extras.put("priority_changed_count", "" + fetchState.priorityChangedCount);
        extras.put("request_initial_priority_is_high", "" + fetchState.isInitialPriorityHigh);
        extras.put("currently_fetching_size", "" + fetchState.currentlyFetchingCountWhenCreated);
        extras.put("delay_count", "" + fetchState.delayCount);
        return extras;
    }
}
